# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: spaceone/api/statistics/v1/storage.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from spaceone.api.core.v1 import query_pb2 as spaceone_dot_api_dot_core_dot_v1_dot_query__pb2
from spaceone.api.statistics.v1 import resource_pb2 as spaceone_dot_api_dot_statistics_dot_v1_dot_resource__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n(spaceone/api/statistics/v1/storage.proto\x12\x1aspaceone.api.statistics.v1\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1cgoogle/api/annotations.proto\x1a spaceone/api/core/v1/query.proto\x1a)spaceone/api/statistics/v1/resource.proto\"\x9b\x01\n\rPluginRequest\x12\x11\n\tplugin_id\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\t\x12(\n\x07options\x18\x03 \x01(\x0b\x32\x17.google.protobuf.Struct\x12,\n\x0bsecret_data\x18\x04 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x0e\n\x06schema\x18\x05 \x01(\t\"\x98\x01\n\nPluginInfo\x12\x11\n\tplugin_id\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\t\x12(\n\x07options\x18\x03 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x11\n\tsecret_id\x18\x04 \x01(\t\x12)\n\x08metadata\x18\x05 \x01(\x0b\x32\x17.google.protobuf.Struct\"\xb1\x01\n\x16RegisterStorageRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12>\n\x0bplugin_info\x18\x02 \x01(\x0b\x32).spaceone.api.statistics.v1.PluginRequest\x12%\n\x04tags\x18\x03 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x0f\n\x07user_id\x18\x0b \x01(\t\x12\x11\n\tdomain_id\x18\x0c \x01(\t\"r\n\x14UpdateStorageRequest\x12\x12\n\nstorage_id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12%\n\x04tags\x18\x03 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x11\n\tdomain_id\x18\x0b \x01(\t\"\xac\x01\n\x1aUpdateStoragePluginRequest\x12\x12\n\nstorage_id\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\t\x12(\n\x07options\x18\x03 \x01(\x0b\x32\x17.google.protobuf.Struct\x12,\n\x0bsecret_data\x18\x04 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x11\n\tdomain_id\x18\x0b \x01(\t\"7\n\x0eStorageRequest\x12\x12\n\nstorage_id\x18\x01 \x01(\t\x12\x11\n\tdomain_id\x18\x02 \x01(\t\"H\n\x11GetStorageRequest\x12\x12\n\nstorage_id\x18\x01 \x01(\t\x12\x11\n\tdomain_id\x18\x02 \x01(\t\x12\x0c\n\x04only\x18\x03 \x03(\t\"\x8f\x01\n\x0cStorageQuery\x12*\n\x05query\x18\x01 \x01(\x0b\x32\x1b.spaceone.api.core.v1.Query\x12\x12\n\nstorage_id\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\r\n\x05state\x18\x04 \x01(\t\x12\x0f\n\x07user_id\x18\x05 \x01(\t\x12\x11\n\tdomain_id\x18\x06 \x01(\t\"\x8e\x03\n\x0bStorageInfo\x12\x12\n\nstorage_id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12<\n\x05state\x18\x03 \x01(\x0e\x32-.spaceone.api.statistics.v1.StorageInfo.State\x12(\n\x07options\x18\x04 \x01(\x0b\x32\x17.google.protobuf.Struct\x12+\n\ncapability\x18\x05 \x01(\x0b\x32\x17.google.protobuf.Struct\x12;\n\x0bplugin_info\x18\x06 \x01(\x0b\x32&.spaceone.api.statistics.v1.PluginInfo\x12%\n\x04tags\x18\x07 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x0f\n\x07user_id\x18\x08 \x01(\t\x12\x11\n\tdomain_id\x18\t \x01(\t\x12\x12\n\ncreated_at\x18\n \x01(\t\",\n\x05State\x12\x08\n\x04NONE\x10\x00\x12\x0b\n\x07\x45NABLED\x10\x01\x12\x0c\n\x08\x44ISABLED\x10\x02\"]\n\x0cStoragesInfo\x12\x38\n\x07results\x18\x01 \x03(\x0b\x32\'.spaceone.api.statistics.v1.StorageInfo\x12\x13\n\x0btotal_count\x18\x02 \x01(\x05\"[\n\x10StorageStatQuery\x12\x34\n\x05query\x18\x01 \x01(\x0b\x32%.spaceone.api.core.v1.StatisticsQuery\x12\x11\n\tdomain_id\x18\x02 \x01(\t2\xb8\x0b\n\x07Storage\x12\x88\x01\n\x08register\x12\x32.spaceone.api.statistics.v1.RegisterStorageRequest\x1a\'.spaceone.api.statistics.v1.StorageInfo\"\x1f\x82\xd3\xe4\x93\x02\x19\"\x17/statistics/v1/storages\x12\x90\x01\n\x06update\x12\x30.spaceone.api.statistics.v1.UpdateStorageRequest\x1a\'.spaceone.api.statistics.v1.StorageInfo\"+\x82\xd3\xe4\x93\x02%\x1a#/statistics/v1/storage/{storage_id}\x12\xa9\x01\n\rupdate_plugin\x12\x36.spaceone.api.statistics.v1.UpdateStoragePluginRequest\x1a\'.spaceone.api.statistics.v1.StorageInfo\"7\x82\xd3\xe4\x93\x02\x31\x1a//spot-automation/v1/storage/{storage_id}/plugin\x12\x93\x01\n\rverify_plugin\x12*.spaceone.api.statistics.v1.StorageRequest\x1a\x16.google.protobuf.Empty\">\x82\xd3\xe4\x93\x02\x38\"6/spot-automation/v1/storage/{storage_id}/plugin/verify\x12\x92\x01\n\x06\x65nable\x12*.spaceone.api.statistics.v1.StorageRequest\x1a\'.spaceone.api.statistics.v1.StorageInfo\"3\x82\xd3\xe4\x93\x02-\x1a+/statistics/v1/storage/{schedule_id}/enable\x12\x94\x01\n\x07\x64isable\x12*.spaceone.api.statistics.v1.StorageRequest\x1a\'.spaceone.api.statistics.v1.StorageInfo\"4\x82\xd3\xe4\x93\x02.\x1a,/statistics/v1/storage/{schedule_id}/disable\x12~\n\nderegister\x12*.spaceone.api.statistics.v1.StorageRequest\x1a\x16.google.protobuf.Empty\",\x82\xd3\xe4\x93\x02&*$/statistics/v1/storage/{schedule_id}\x12\x8b\x01\n\x03get\x12-.spaceone.api.statistics.v1.GetStorageRequest\x1a\'.spaceone.api.statistics.v1.StorageInfo\",\x82\xd3\xe4\x93\x02&\x12$/statistics/v1/storage/{schedule_id}\x12\x9d\x01\n\x04list\x12(.spaceone.api.statistics.v1.StorageQuery\x1a(.spaceone.api.statistics.v1.StoragesInfo\"A\x82\xd3\xe4\x93\x02;\x12\x17/statistics/v1/storagesZ \"\x1e/statistics/v1/storages/search\x12s\n\x04stat\x12,.spaceone.api.statistics.v1.StorageStatQuery\x1a\x17.google.protobuf.Struct\"$\x82\xd3\xe4\x93\x02\x1e\"\x1c/statistics/v1/storages/statb\x06proto3')



_PLUGINREQUEST = DESCRIPTOR.message_types_by_name['PluginRequest']
_PLUGININFO = DESCRIPTOR.message_types_by_name['PluginInfo']
_REGISTERSTORAGEREQUEST = DESCRIPTOR.message_types_by_name['RegisterStorageRequest']
_UPDATESTORAGEREQUEST = DESCRIPTOR.message_types_by_name['UpdateStorageRequest']
_UPDATESTORAGEPLUGINREQUEST = DESCRIPTOR.message_types_by_name['UpdateStoragePluginRequest']
_STORAGEREQUEST = DESCRIPTOR.message_types_by_name['StorageRequest']
_GETSTORAGEREQUEST = DESCRIPTOR.message_types_by_name['GetStorageRequest']
_STORAGEQUERY = DESCRIPTOR.message_types_by_name['StorageQuery']
_STORAGEINFO = DESCRIPTOR.message_types_by_name['StorageInfo']
_STORAGESINFO = DESCRIPTOR.message_types_by_name['StoragesInfo']
_STORAGESTATQUERY = DESCRIPTOR.message_types_by_name['StorageStatQuery']
_STORAGEINFO_STATE = _STORAGEINFO.enum_types_by_name['State']
PluginRequest = _reflection.GeneratedProtocolMessageType('PluginRequest', (_message.Message,), {
  'DESCRIPTOR' : _PLUGINREQUEST,
  '__module__' : 'spaceone.api.statistics.v1.storage_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.statistics.v1.PluginRequest)
  })
_sym_db.RegisterMessage(PluginRequest)

PluginInfo = _reflection.GeneratedProtocolMessageType('PluginInfo', (_message.Message,), {
  'DESCRIPTOR' : _PLUGININFO,
  '__module__' : 'spaceone.api.statistics.v1.storage_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.statistics.v1.PluginInfo)
  })
_sym_db.RegisterMessage(PluginInfo)

RegisterStorageRequest = _reflection.GeneratedProtocolMessageType('RegisterStorageRequest', (_message.Message,), {
  'DESCRIPTOR' : _REGISTERSTORAGEREQUEST,
  '__module__' : 'spaceone.api.statistics.v1.storage_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.statistics.v1.RegisterStorageRequest)
  })
_sym_db.RegisterMessage(RegisterStorageRequest)

UpdateStorageRequest = _reflection.GeneratedProtocolMessageType('UpdateStorageRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATESTORAGEREQUEST,
  '__module__' : 'spaceone.api.statistics.v1.storage_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.statistics.v1.UpdateStorageRequest)
  })
_sym_db.RegisterMessage(UpdateStorageRequest)

UpdateStoragePluginRequest = _reflection.GeneratedProtocolMessageType('UpdateStoragePluginRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATESTORAGEPLUGINREQUEST,
  '__module__' : 'spaceone.api.statistics.v1.storage_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.statistics.v1.UpdateStoragePluginRequest)
  })
_sym_db.RegisterMessage(UpdateStoragePluginRequest)

StorageRequest = _reflection.GeneratedProtocolMessageType('StorageRequest', (_message.Message,), {
  'DESCRIPTOR' : _STORAGEREQUEST,
  '__module__' : 'spaceone.api.statistics.v1.storage_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.statistics.v1.StorageRequest)
  })
_sym_db.RegisterMessage(StorageRequest)

GetStorageRequest = _reflection.GeneratedProtocolMessageType('GetStorageRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETSTORAGEREQUEST,
  '__module__' : 'spaceone.api.statistics.v1.storage_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.statistics.v1.GetStorageRequest)
  })
_sym_db.RegisterMessage(GetStorageRequest)

StorageQuery = _reflection.GeneratedProtocolMessageType('StorageQuery', (_message.Message,), {
  'DESCRIPTOR' : _STORAGEQUERY,
  '__module__' : 'spaceone.api.statistics.v1.storage_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.statistics.v1.StorageQuery)
  })
_sym_db.RegisterMessage(StorageQuery)

StorageInfo = _reflection.GeneratedProtocolMessageType('StorageInfo', (_message.Message,), {
  'DESCRIPTOR' : _STORAGEINFO,
  '__module__' : 'spaceone.api.statistics.v1.storage_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.statistics.v1.StorageInfo)
  })
_sym_db.RegisterMessage(StorageInfo)

StoragesInfo = _reflection.GeneratedProtocolMessageType('StoragesInfo', (_message.Message,), {
  'DESCRIPTOR' : _STORAGESINFO,
  '__module__' : 'spaceone.api.statistics.v1.storage_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.statistics.v1.StoragesInfo)
  })
_sym_db.RegisterMessage(StoragesInfo)

StorageStatQuery = _reflection.GeneratedProtocolMessageType('StorageStatQuery', (_message.Message,), {
  'DESCRIPTOR' : _STORAGESTATQUERY,
  '__module__' : 'spaceone.api.statistics.v1.storage_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.statistics.v1.StorageStatQuery)
  })
_sym_db.RegisterMessage(StorageStatQuery)

_STORAGE = DESCRIPTOR.services_by_name['Storage']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _STORAGE.methods_by_name['register']._options = None
  _STORAGE.methods_by_name['register']._serialized_options = b'\202\323\344\223\002\031\"\027/statistics/v1/storages'
  _STORAGE.methods_by_name['update']._options = None
  _STORAGE.methods_by_name['update']._serialized_options = b'\202\323\344\223\002%\032#/statistics/v1/storage/{storage_id}'
  _STORAGE.methods_by_name['update_plugin']._options = None
  _STORAGE.methods_by_name['update_plugin']._serialized_options = b'\202\323\344\223\0021\032//spot-automation/v1/storage/{storage_id}/plugin'
  _STORAGE.methods_by_name['verify_plugin']._options = None
  _STORAGE.methods_by_name['verify_plugin']._serialized_options = b'\202\323\344\223\0028\"6/spot-automation/v1/storage/{storage_id}/plugin/verify'
  _STORAGE.methods_by_name['enable']._options = None
  _STORAGE.methods_by_name['enable']._serialized_options = b'\202\323\344\223\002-\032+/statistics/v1/storage/{schedule_id}/enable'
  _STORAGE.methods_by_name['disable']._options = None
  _STORAGE.methods_by_name['disable']._serialized_options = b'\202\323\344\223\002.\032,/statistics/v1/storage/{schedule_id}/disable'
  _STORAGE.methods_by_name['deregister']._options = None
  _STORAGE.methods_by_name['deregister']._serialized_options = b'\202\323\344\223\002&*$/statistics/v1/storage/{schedule_id}'
  _STORAGE.methods_by_name['get']._options = None
  _STORAGE.methods_by_name['get']._serialized_options = b'\202\323\344\223\002&\022$/statistics/v1/storage/{schedule_id}'
  _STORAGE.methods_by_name['list']._options = None
  _STORAGE.methods_by_name['list']._serialized_options = b'\202\323\344\223\002;\022\027/statistics/v1/storagesZ \"\036/statistics/v1/storages/search'
  _STORAGE.methods_by_name['stat']._options = None
  _STORAGE.methods_by_name['stat']._serialized_options = b'\202\323\344\223\002\036\"\034/statistics/v1/storages/stat'
  _PLUGINREQUEST._serialized_start=239
  _PLUGINREQUEST._serialized_end=394
  _PLUGININFO._serialized_start=397
  _PLUGININFO._serialized_end=549
  _REGISTERSTORAGEREQUEST._serialized_start=552
  _REGISTERSTORAGEREQUEST._serialized_end=729
  _UPDATESTORAGEREQUEST._serialized_start=731
  _UPDATESTORAGEREQUEST._serialized_end=845
  _UPDATESTORAGEPLUGINREQUEST._serialized_start=848
  _UPDATESTORAGEPLUGINREQUEST._serialized_end=1020
  _STORAGEREQUEST._serialized_start=1022
  _STORAGEREQUEST._serialized_end=1077
  _GETSTORAGEREQUEST._serialized_start=1079
  _GETSTORAGEREQUEST._serialized_end=1151
  _STORAGEQUERY._serialized_start=1154
  _STORAGEQUERY._serialized_end=1297
  _STORAGEINFO._serialized_start=1300
  _STORAGEINFO._serialized_end=1698
  _STORAGEINFO_STATE._serialized_start=1654
  _STORAGEINFO_STATE._serialized_end=1698
  _STORAGESINFO._serialized_start=1700
  _STORAGESINFO._serialized_end=1793
  _STORAGESTATQUERY._serialized_start=1795
  _STORAGESTATQUERY._serialized_end=1886
  _STORAGE._serialized_start=1889
  _STORAGE._serialized_end=3353
# @@protoc_insertion_point(module_scope)
