# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: spaceone/api/provisioning/v1/transmission_history.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from spaceone.api.core.v1 import query_pb2 as spaceone_dot_api_dot_core_dot_v1_dot_query__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n7spaceone/api/provisioning/v1/transmission_history.proto\x12\x1cspaceone.api.provisioning.v1\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1cgoogle/api/annotations.proto\x1a spaceone/api/core/v1/query.proto\"Y\n\x18TransmissionHistoryQuery\x12*\n\x05query\x18\x01 \x01(\x0b\x32\x1b.spaceone.api.core.v1.Query\x12\x11\n\tdomain_id\x18\x04 \x01(\t\"\xfb\x01\n\x1aTransmissionHistoryRequest\x12\x1f\n\x17transmission_history_id\x18\x01 \x01(\t\x12\x17\n\x0ftransmission_id\x18\x02 \x01(\t\x12\x11\n\tdomain_id\x18\x03 \x01(\t\x12\x0e\n\x06target\x18\x04 \x01(\t\x12\x14\n\x0cpublish_type\x18\x05 \x01(\t\x12\x12\n\nproject_id\x18\x06 \x01(\t\x12\x1a\n\x12service_account_id\x18\x07 \x01(\t\x12\x0e\n\x06status\x18\x08 \x01(\t\x12\x12\n\ncreated_by\x18\t \x01(\t\x12\x16\n\x0etransaction_id\x18\n \x01(\t\"g\n\x1cTransmissionHistoryStatQuery\x12\x34\n\x05query\x18\x01 \x01(\x0b\x32%.spaceone.api.core.v1.StatisticsQuery\x12\x11\n\tdomain_id\x18\x02 \x01(\t\"\xda\x02\n\x17TransmissionHistoryInfo\x12\x1f\n\x17transmission_history_id\x18\x01 \x01(\t\x12\x17\n\x0ftransmission_id\x18\x02 \x01(\t\x12\x11\n\tdomain_id\x18\x03 \x01(\t\x12\x0e\n\x06target\x18\x04 \x01(\t\x12\x14\n\x0cpublish_type\x18\x05 \x01(\t\x12\x12\n\nproject_id\x18\x06 \x01(\t\x12\x1a\n\x12service_account_id\x18\x07 \x01(\t\x12\x16\n\x0eterraform_code\x18\x08 \x01(\t\x12\x0e\n\x06status\x18\t \x01(\t\x12\x0e\n\x06output\x18\n \x01(\t\x12\x12\n\ncreated_by\x18\x0b \x01(\t\x12\x12\n\ncreated_at\x18\x0c \x01(\t\x12\x16\n\x0etransaction_id\x18\r \x01(\t\x12\x12\n\nupdated_at\x18\x0e \x01(\t\x12\x10\n\x08tf_state\x18\x0f \x01(\t\"x\n\x19TransmissionHistoriesInfo\x12\x46\n\x07results\x18\x01 \x03(\x0b\x32\x35.spaceone.api.provisioning.v1.TransmissionHistoryInfo\x12\x13\n\x0btotal_count\x18\x02 \x01(\x05\x32\xd8\x06\n\x13TransmissionHistory\x12\xf1\x01\n\x1aget_transmission_histories\x12\x36.spaceone.api.provisioning.v1.TransmissionHistoryQuery\x1a\x37.spaceone.api.provisioning.v1.TransmissionHistoriesInfo\"b\x82\xd3\xe4\x93\x02\\\x12*/provisioning/v1/transmission-history/listZ.\",/provisioning/v1/transmission-history/search\x12\xd4\x01\n\x18get_transmission_history\x12\x38.spaceone.api.provisioning.v1.TransmissionHistoryRequest\x1a\x35.spaceone.api.provisioning.v1.TransmissionHistoryInfo\"G\x82\xd3\xe4\x93\x02\x41\x12?/provisioning/v1/transmission-history/{transmission_history_id}\x12\x90\x01\n\x04stat\x12:.spaceone.api.provisioning.v1.TransmissionHistoryStatQuery\x1a\x17.google.protobuf.Struct\"3\x82\xd3\xe4\x93\x02-\"+/inventory/v1/catalog-resource/history/stat\x12\xe2\x01\n\x1fget_latest_transmission_history\x12\x38.spaceone.api.provisioning.v1.TransmissionHistoryRequest\x1a\x35.spaceone.api.provisioning.v1.TransmissionHistoryInfo\"N\x82\xd3\xe4\x93\x02H\x12\x46/provisioning/v1/transmission-history/latest/{transmission_history_id}b\x06proto3')



_TRANSMISSIONHISTORYQUERY = DESCRIPTOR.message_types_by_name['TransmissionHistoryQuery']
_TRANSMISSIONHISTORYREQUEST = DESCRIPTOR.message_types_by_name['TransmissionHistoryRequest']
_TRANSMISSIONHISTORYSTATQUERY = DESCRIPTOR.message_types_by_name['TransmissionHistoryStatQuery']
_TRANSMISSIONHISTORYINFO = DESCRIPTOR.message_types_by_name['TransmissionHistoryInfo']
_TRANSMISSIONHISTORIESINFO = DESCRIPTOR.message_types_by_name['TransmissionHistoriesInfo']
TransmissionHistoryQuery = _reflection.GeneratedProtocolMessageType('TransmissionHistoryQuery', (_message.Message,), {
  'DESCRIPTOR' : _TRANSMISSIONHISTORYQUERY,
  '__module__' : 'spaceone.api.provisioning.v1.transmission_history_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.provisioning.v1.TransmissionHistoryQuery)
  })
_sym_db.RegisterMessage(TransmissionHistoryQuery)

TransmissionHistoryRequest = _reflection.GeneratedProtocolMessageType('TransmissionHistoryRequest', (_message.Message,), {
  'DESCRIPTOR' : _TRANSMISSIONHISTORYREQUEST,
  '__module__' : 'spaceone.api.provisioning.v1.transmission_history_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.provisioning.v1.TransmissionHistoryRequest)
  })
_sym_db.RegisterMessage(TransmissionHistoryRequest)

TransmissionHistoryStatQuery = _reflection.GeneratedProtocolMessageType('TransmissionHistoryStatQuery', (_message.Message,), {
  'DESCRIPTOR' : _TRANSMISSIONHISTORYSTATQUERY,
  '__module__' : 'spaceone.api.provisioning.v1.transmission_history_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.provisioning.v1.TransmissionHistoryStatQuery)
  })
_sym_db.RegisterMessage(TransmissionHistoryStatQuery)

TransmissionHistoryInfo = _reflection.GeneratedProtocolMessageType('TransmissionHistoryInfo', (_message.Message,), {
  'DESCRIPTOR' : _TRANSMISSIONHISTORYINFO,
  '__module__' : 'spaceone.api.provisioning.v1.transmission_history_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.provisioning.v1.TransmissionHistoryInfo)
  })
_sym_db.RegisterMessage(TransmissionHistoryInfo)

TransmissionHistoriesInfo = _reflection.GeneratedProtocolMessageType('TransmissionHistoriesInfo', (_message.Message,), {
  'DESCRIPTOR' : _TRANSMISSIONHISTORIESINFO,
  '__module__' : 'spaceone.api.provisioning.v1.transmission_history_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.provisioning.v1.TransmissionHistoriesInfo)
  })
_sym_db.RegisterMessage(TransmissionHistoriesInfo)

_TRANSMISSIONHISTORY = DESCRIPTOR.services_by_name['TransmissionHistory']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _TRANSMISSIONHISTORY.methods_by_name['get_transmission_histories']._options = None
  _TRANSMISSIONHISTORY.methods_by_name['get_transmission_histories']._serialized_options = b'\202\323\344\223\002\\\022*/provisioning/v1/transmission-history/listZ.\",/provisioning/v1/transmission-history/search'
  _TRANSMISSIONHISTORY.methods_by_name['get_transmission_history']._options = None
  _TRANSMISSIONHISTORY.methods_by_name['get_transmission_history']._serialized_options = b'\202\323\344\223\002A\022?/provisioning/v1/transmission-history/{transmission_history_id}'
  _TRANSMISSIONHISTORY.methods_by_name['stat']._options = None
  _TRANSMISSIONHISTORY.methods_by_name['stat']._serialized_options = b'\202\323\344\223\002-\"+/inventory/v1/catalog-resource/history/stat'
  _TRANSMISSIONHISTORY.methods_by_name['get_latest_transmission_history']._options = None
  _TRANSMISSIONHISTORY.methods_by_name['get_latest_transmission_history']._serialized_options = b'\202\323\344\223\002H\022F/provisioning/v1/transmission-history/latest/{transmission_history_id}'
  _TRANSMISSIONHISTORYQUERY._serialized_start=183
  _TRANSMISSIONHISTORYQUERY._serialized_end=272
  _TRANSMISSIONHISTORYREQUEST._serialized_start=275
  _TRANSMISSIONHISTORYREQUEST._serialized_end=526
  _TRANSMISSIONHISTORYSTATQUERY._serialized_start=528
  _TRANSMISSIONHISTORYSTATQUERY._serialized_end=631
  _TRANSMISSIONHISTORYINFO._serialized_start=634
  _TRANSMISSIONHISTORYINFO._serialized_end=980
  _TRANSMISSIONHISTORIESINFO._serialized_start=982
  _TRANSMISSIONHISTORIESINFO._serialized_end=1102
  _TRANSMISSIONHISTORY._serialized_start=1105
  _TRANSMISSIONHISTORY._serialized_end=1961
# @@protoc_insertion_point(module_scope)
