# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: spaceone/api/inventory/v1/cloud_service_type.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from spaceone.api.core.v1 import query_pb2 as spaceone_dot_api_dot_core_dot_v1_dot_query__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n2spaceone/api/inventory/v1/cloud_service_type.proto\x12\x19spaceone.api.inventory.v1\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1cgoogle/api/annotations.proto\x1a spaceone/api/core/v1/query.proto\"\xb2\x02\n\x1d\x43reateCloudServiceTypeRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x10\n\x08provider\x18\x02 \x01(\t\x12\r\n\x05group\x18\x03 \x01(\t\x12\x14\n\x0cservice_code\x18\x04 \x01(\t\x12\x12\n\nis_primary\x18\x05 \x01(\x08\x12\x10\n\x08is_major\x18\x06 \x01(\x08\x12\x15\n\rresource_type\x18\x07 \x01(\t\x12)\n\x08metadata\x18\x0b \x01(\x0b\x32\x17.google.protobuf.Struct\x12*\n\x06labels\x18\x0c \x01(\x0b\x32\x1a.google.protobuf.ListValue\x12%\n\x04tags\x18\r \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x11\n\tdomain_id\x18\x15 \x01(\t\"\xa2\x02\n\x1dUpdateCloudServiceTypeRequest\x12\x1d\n\x15\x63loud_service_type_id\x18\x01 \x01(\t\x12\x14\n\x0cservice_code\x18\x02 \x01(\t\x12\x12\n\nis_primary\x18\x03 \x01(\x08\x12\x10\n\x08is_major\x18\x04 \x01(\x08\x12\x15\n\rresource_type\x18\x05 \x01(\t\x12)\n\x08metadata\x18\x0b \x01(\x0b\x32\x17.google.protobuf.Struct\x12*\n\x06labels\x18\x0c \x01(\x0b\x32\x1a.google.protobuf.ListValue\x12%\n\x04tags\x18\r \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x11\n\tdomain_id\x18\x15 \x01(\t\"K\n\x17\x43loudServiceTypeRequest\x12\x1d\n\x15\x63loud_service_type_id\x18\x01 \x01(\t\x12\x11\n\tdomain_id\x18\x02 \x01(\t\"\\\n\x1aGetCloudServiceTypeRequest\x12\x1d\n\x15\x63loud_service_type_id\x18\x01 \x01(\t\x12\x11\n\tdomain_id\x18\x02 \x01(\t\x12\x0c\n\x04only\x18\x03 \x03(\t\"\x97\x02\n\x15\x43loudServiceTypeQuery\x12*\n\x05query\x18\x01 \x01(\x0b\x32\x1b.spaceone.api.core.v1.Query\x12\x1d\n\x15\x63loud_service_type_id\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x10\n\x08provider\x18\x04 \x01(\t\x12\r\n\x05group\x18\x05 \x01(\t\x12\x1e\n\x16\x63loud_service_type_key\x18\x06 \x01(\t\x12\x14\n\x0cservice_code\x18\x07 \x01(\t\x12\x12\n\nis_primary\x18\x08 \x01(\x08\x12\x10\n\x08is_major\x18\t \x01(\x08\x12\x15\n\rresource_type\x18\n \x01(\t\x12\x11\n\tdomain_id\x18\x0b \x01(\t\"\x90\x03\n\x14\x43loudServiceTypeInfo\x12\x1d\n\x15\x63loud_service_type_id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x10\n\x08provider\x18\x03 \x01(\t\x12\r\n\x05group\x18\x04 \x01(\t\x12\x1e\n\x16\x63loud_service_type_key\x18\x05 \x01(\t\x12\x14\n\x0cservice_code\x18\x06 \x01(\t\x12\x12\n\nis_primary\x18\x07 \x01(\x08\x12\x10\n\x08is_major\x18\x08 \x01(\x08\x12\x15\n\rresource_type\x18\t \x01(\t\x12)\n\x08metadata\x18\x0b \x01(\x0b\x32\x17.google.protobuf.Struct\x12%\n\x04tags\x18\x0c \x01(\x0b\x32\x17.google.protobuf.Struct\x12*\n\x06labels\x18\r \x01(\x0b\x32\x1a.google.protobuf.ListValue\x12\x11\n\tdomain_id\x18\x15 \x01(\t\x12\x12\n\ncreated_at\x18\x1f \x01(\t\x12\x12\n\nupdated_at\x18  \x01(\t\"n\n\x15\x43loudServiceTypesInfo\x12@\n\x07results\x18\x01 \x03(\x0b\x32/.spaceone.api.inventory.v1.CloudServiceTypeInfo\x12\x13\n\x0btotal_count\x18\x02 \x01(\x05\"\x80\x01\n\x19\x43loudServiceTypeStatQuery\x12\x34\n\x05query\x18\x01 \x01(\x0b\x32%.spaceone.api.core.v1.StatisticsQuery\x12\x11\n\tdomain_id\x18\x02 \x01(\t\x12\x1a\n\x12\x61llow_delete_state\x18\x03 \x01(\x08\x32\xa4\t\n\x10\x43loudServiceType\x12\x9e\x01\n\x06\x63reate\x12\x38.spaceone.api.inventory.v1.CreateCloudServiceTypeRequest\x1a/.spaceone.api.inventory.v1.CloudServiceTypeInfo\")\x82\xd3\xe4\x93\x02#\"!/inventory/v1/cloud-service-types\x12\xb5\x01\n\x06update\x12\x38.spaceone.api.inventory.v1.UpdateCloudServiceTypeRequest\x1a/.spaceone.api.inventory.v1.CloudServiceTypeInfo\"@\x82\xd3\xe4\x93\x02:\x1a\x38/inventory/v1/cloud-service-type/{cloud_service_type_id}\x12\x96\x01\n\x06\x64\x65lete\x12\x32.spaceone.api.inventory.v1.CloudServiceTypeRequest\x1a\x16.google.protobuf.Empty\"@\x82\xd3\xe4\x93\x02:*8/inventory/v1/cloud-service-type/{cloud_service_type_id}\x12\xaf\x01\n\x03get\x12\x35.spaceone.api.inventory.v1.GetCloudServiceTypeRequest\x1a/.spaceone.api.inventory.v1.CloudServiceTypeInfo\"@\x82\xd3\xe4\x93\x02:\x12\x38/inventory/v1/cloud-service-type/{cloud_service_type_id}\x12\xc1\x01\n\x04list\x12\x30.spaceone.api.inventory.v1.CloudServiceTypeQuery\x1a\x30.spaceone.api.inventory.v1.CloudServiceTypesInfo\"U\x82\xd3\xe4\x93\x02O\x12!/inventory/v1/cloud-service-typesZ*\"(/inventory/v1/cloud-service-types/search\x12\x85\x01\n\x04stat\x12\x34.spaceone.api.inventory.v1.CloudServiceTypeStatQuery\x1a\x17.google.protobuf.Struct\".\x82\xd3\xe4\x93\x02(\"&/inventory/v1/cloud-service-types/stat\x12\x9f\x01\n\x11\x61llow_delete_stat\x12\x34.spaceone.api.inventory.v1.CloudServiceTypeStatQuery\x1a\x17.google.protobuf.Struct\";\x82\xd3\xe4\x93\x02\x35\"3/inventory/v1/cloud-service-types/allow_delete_statb\x06proto3')



_CREATECLOUDSERVICETYPEREQUEST = DESCRIPTOR.message_types_by_name['CreateCloudServiceTypeRequest']
_UPDATECLOUDSERVICETYPEREQUEST = DESCRIPTOR.message_types_by_name['UpdateCloudServiceTypeRequest']
_CLOUDSERVICETYPEREQUEST = DESCRIPTOR.message_types_by_name['CloudServiceTypeRequest']
_GETCLOUDSERVICETYPEREQUEST = DESCRIPTOR.message_types_by_name['GetCloudServiceTypeRequest']
_CLOUDSERVICETYPEQUERY = DESCRIPTOR.message_types_by_name['CloudServiceTypeQuery']
_CLOUDSERVICETYPEINFO = DESCRIPTOR.message_types_by_name['CloudServiceTypeInfo']
_CLOUDSERVICETYPESINFO = DESCRIPTOR.message_types_by_name['CloudServiceTypesInfo']
_CLOUDSERVICETYPESTATQUERY = DESCRIPTOR.message_types_by_name['CloudServiceTypeStatQuery']
CreateCloudServiceTypeRequest = _reflection.GeneratedProtocolMessageType('CreateCloudServiceTypeRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATECLOUDSERVICETYPEREQUEST,
  '__module__' : 'spaceone.api.inventory.v1.cloud_service_type_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.CreateCloudServiceTypeRequest)
  })
_sym_db.RegisterMessage(CreateCloudServiceTypeRequest)

UpdateCloudServiceTypeRequest = _reflection.GeneratedProtocolMessageType('UpdateCloudServiceTypeRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATECLOUDSERVICETYPEREQUEST,
  '__module__' : 'spaceone.api.inventory.v1.cloud_service_type_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.UpdateCloudServiceTypeRequest)
  })
_sym_db.RegisterMessage(UpdateCloudServiceTypeRequest)

CloudServiceTypeRequest = _reflection.GeneratedProtocolMessageType('CloudServiceTypeRequest', (_message.Message,), {
  'DESCRIPTOR' : _CLOUDSERVICETYPEREQUEST,
  '__module__' : 'spaceone.api.inventory.v1.cloud_service_type_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.CloudServiceTypeRequest)
  })
_sym_db.RegisterMessage(CloudServiceTypeRequest)

GetCloudServiceTypeRequest = _reflection.GeneratedProtocolMessageType('GetCloudServiceTypeRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETCLOUDSERVICETYPEREQUEST,
  '__module__' : 'spaceone.api.inventory.v1.cloud_service_type_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.GetCloudServiceTypeRequest)
  })
_sym_db.RegisterMessage(GetCloudServiceTypeRequest)

CloudServiceTypeQuery = _reflection.GeneratedProtocolMessageType('CloudServiceTypeQuery', (_message.Message,), {
  'DESCRIPTOR' : _CLOUDSERVICETYPEQUERY,
  '__module__' : 'spaceone.api.inventory.v1.cloud_service_type_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.CloudServiceTypeQuery)
  })
_sym_db.RegisterMessage(CloudServiceTypeQuery)

CloudServiceTypeInfo = _reflection.GeneratedProtocolMessageType('CloudServiceTypeInfo', (_message.Message,), {
  'DESCRIPTOR' : _CLOUDSERVICETYPEINFO,
  '__module__' : 'spaceone.api.inventory.v1.cloud_service_type_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.CloudServiceTypeInfo)
  })
_sym_db.RegisterMessage(CloudServiceTypeInfo)

CloudServiceTypesInfo = _reflection.GeneratedProtocolMessageType('CloudServiceTypesInfo', (_message.Message,), {
  'DESCRIPTOR' : _CLOUDSERVICETYPESINFO,
  '__module__' : 'spaceone.api.inventory.v1.cloud_service_type_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.CloudServiceTypesInfo)
  })
_sym_db.RegisterMessage(CloudServiceTypesInfo)

CloudServiceTypeStatQuery = _reflection.GeneratedProtocolMessageType('CloudServiceTypeStatQuery', (_message.Message,), {
  'DESCRIPTOR' : _CLOUDSERVICETYPESTATQUERY,
  '__module__' : 'spaceone.api.inventory.v1.cloud_service_type_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.CloudServiceTypeStatQuery)
  })
_sym_db.RegisterMessage(CloudServiceTypeStatQuery)

_CLOUDSERVICETYPE = DESCRIPTOR.services_by_name['CloudServiceType']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _CLOUDSERVICETYPE.methods_by_name['create']._options = None
  _CLOUDSERVICETYPE.methods_by_name['create']._serialized_options = b'\202\323\344\223\002#\"!/inventory/v1/cloud-service-types'
  _CLOUDSERVICETYPE.methods_by_name['update']._options = None
  _CLOUDSERVICETYPE.methods_by_name['update']._serialized_options = b'\202\323\344\223\002:\0328/inventory/v1/cloud-service-type/{cloud_service_type_id}'
  _CLOUDSERVICETYPE.methods_by_name['delete']._options = None
  _CLOUDSERVICETYPE.methods_by_name['delete']._serialized_options = b'\202\323\344\223\002:*8/inventory/v1/cloud-service-type/{cloud_service_type_id}'
  _CLOUDSERVICETYPE.methods_by_name['get']._options = None
  _CLOUDSERVICETYPE.methods_by_name['get']._serialized_options = b'\202\323\344\223\002:\0228/inventory/v1/cloud-service-type/{cloud_service_type_id}'
  _CLOUDSERVICETYPE.methods_by_name['list']._options = None
  _CLOUDSERVICETYPE.methods_by_name['list']._serialized_options = b'\202\323\344\223\002O\022!/inventory/v1/cloud-service-typesZ*\"(/inventory/v1/cloud-service-types/search'
  _CLOUDSERVICETYPE.methods_by_name['stat']._options = None
  _CLOUDSERVICETYPE.methods_by_name['stat']._serialized_options = b'\202\323\344\223\002(\"&/inventory/v1/cloud-service-types/stat'
  _CLOUDSERVICETYPE.methods_by_name['allow_delete_stat']._options = None
  _CLOUDSERVICETYPE.methods_by_name['allow_delete_stat']._serialized_options = b'\202\323\344\223\0025\"3/inventory/v1/cloud-service-types/allow_delete_stat'
  _CREATECLOUDSERVICETYPEREQUEST._serialized_start=205
  _CREATECLOUDSERVICETYPEREQUEST._serialized_end=511
  _UPDATECLOUDSERVICETYPEREQUEST._serialized_start=514
  _UPDATECLOUDSERVICETYPEREQUEST._serialized_end=804
  _CLOUDSERVICETYPEREQUEST._serialized_start=806
  _CLOUDSERVICETYPEREQUEST._serialized_end=881
  _GETCLOUDSERVICETYPEREQUEST._serialized_start=883
  _GETCLOUDSERVICETYPEREQUEST._serialized_end=975
  _CLOUDSERVICETYPEQUERY._serialized_start=978
  _CLOUDSERVICETYPEQUERY._serialized_end=1257
  _CLOUDSERVICETYPEINFO._serialized_start=1260
  _CLOUDSERVICETYPEINFO._serialized_end=1660
  _CLOUDSERVICETYPESINFO._serialized_start=1662
  _CLOUDSERVICETYPESINFO._serialized_end=1772
  _CLOUDSERVICETYPESTATQUERY._serialized_start=1775
  _CLOUDSERVICETYPESTATQUERY._serialized_end=1903
  _CLOUDSERVICETYPE._serialized_start=1906
  _CLOUDSERVICETYPE._serialized_end=3094
# @@protoc_insertion_point(module_scope)
