# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: spaceone/api/cost_analysis/v1/data_source_rule.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from spaceone.api.core.v1 import query_pb2 as spaceone_dot_api_dot_core_dot_v1_dot_query__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n4spaceone/api/cost_analysis/v1/data_source_rule.proto\x12\x1dspaceone.api.cost_analysis.v1\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1cgoogle/api/annotations.proto\x1a spaceone/api/core/v1/query.proto\"G\n\x17\x44\x61taSourceRuleCondition\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\x12\x10\n\x08operator\x18\x03 \x01(\t\"+\n\tMatchRule\x12\x0e\n\x06source\x18\x01 \x01(\t\x12\x0e\n\x06target\x18\x02 \x01(\t\"\xef\x01\n\x15\x44\x61taSourceRuleActions\x12\x16\n\x0e\x63hange_project\x18\x01 \x01(\t\x12?\n\rmatch_project\x18\x02 \x01(\x0b\x32(.spaceone.api.cost_analysis.v1.MatchRule\x12G\n\x15match_service_account\x18\x03 \x01(\x0b\x32(.spaceone.api.cost_analysis.v1.MatchRule\x12\x34\n\x13\x61\x64\x64_additional_info\x18\x04 \x01(\x0b\x32\x17.google.protobuf.Struct\"0\n\x15\x44\x61taSourceRuleOptions\x12\x17\n\x0fstop_processing\x18\x01 \x01(\x08\"\xa3\x03\n\x1b\x43reateDataSourceRuleRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12J\n\nconditions\x18\x02 \x03(\x0b\x32\x36.spaceone.api.cost_analysis.v1.DataSourceRuleCondition\x12J\n\x11\x63onditions_policy\x18\x03 \x01(\x0e\x32/.spaceone.api.cost_analysis.v1.ConditionsPolicy\x12\x45\n\x07\x61\x63tions\x18\x04 \x01(\x0b\x32\x34.spaceone.api.cost_analysis.v1.DataSourceRuleActions\x12\x45\n\x07options\x18\x05 \x01(\x0b\x32\x34.spaceone.api.cost_analysis.v1.DataSourceRuleOptions\x12%\n\x04tags\x18\x06 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x16\n\x0e\x64\x61ta_source_id\x18\x0b \x01(\t\x12\x11\n\tdomain_id\x18\x0c \x01(\t\"\xa8\x03\n\x1bUpdateDataSourceRuleRequest\x12\x1b\n\x13\x64\x61ta_source_rule_id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12J\n\nconditions\x18\x03 \x03(\x0b\x32\x36.spaceone.api.cost_analysis.v1.DataSourceRuleCondition\x12J\n\x11\x63onditions_policy\x18\x04 \x01(\x0e\x32/.spaceone.api.cost_analysis.v1.ConditionsPolicy\x12\x45\n\x07\x61\x63tions\x18\x05 \x01(\x0b\x32\x34.spaceone.api.cost_analysis.v1.DataSourceRuleActions\x12\x45\n\x07options\x18\x06 \x01(\x0b\x32\x34.spaceone.api.cost_analysis.v1.DataSourceRuleOptions\x12%\n\x04tags\x18\x07 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x11\n\tdomain_id\x18\x0b \x01(\t\"a\n ChangeDataSourceRuleOrderRequest\x12\x1b\n\x13\x64\x61ta_source_rule_id\x18\x01 \x01(\t\x12\r\n\x05order\x18\x02 \x01(\x05\x12\x11\n\tdomain_id\x18\x0b \x01(\t\"G\n\x15\x44\x61taSourceRuleRequest\x12\x1b\n\x13\x64\x61ta_source_rule_id\x18\x01 \x01(\t\x12\x11\n\tdomain_id\x18\x02 \x01(\t\"X\n\x18GetDataSourceRuleRequest\x12\x1b\n\x13\x64\x61ta_source_rule_id\x18\x01 \x01(\t\x12\x11\n\tdomain_id\x18\x02 \x01(\t\x12\x0c\n\x04only\x18\x03 \x03(\t\"\x97\x01\n\x13\x44\x61taSourceRuleQuery\x12*\n\x05query\x18\x01 \x01(\x0b\x32\x1b.spaceone.api.core.v1.Query\x12\x1b\n\x13\x64\x61ta_source_rule_id\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x16\n\x0e\x64\x61ta_source_id\x18\x04 \x01(\t\x12\x11\n\tdomain_id\x18\x0b \x01(\t\"\xda\x03\n\x12\x44\x61taSourceRuleInfo\x12\x1b\n\x13\x64\x61ta_source_rule_id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\r\n\x05order\x18\x03 \x01(\x05\x12J\n\nconditions\x18\x04 \x03(\x0b\x32\x36.spaceone.api.cost_analysis.v1.DataSourceRuleCondition\x12J\n\x11\x63onditions_policy\x18\x05 \x01(\x0e\x32/.spaceone.api.cost_analysis.v1.ConditionsPolicy\x12\x45\n\x07\x61\x63tions\x18\x06 \x01(\x0b\x32\x34.spaceone.api.cost_analysis.v1.DataSourceRuleActions\x12\x45\n\x07options\x18\x07 \x01(\x0b\x32\x34.spaceone.api.cost_analysis.v1.DataSourceRuleOptions\x12%\n\x04tags\x18\x08 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x16\n\x0e\x64\x61ta_source_id\x18\x0b \x01(\t\x12\x11\n\tdomain_id\x18\x0c \x01(\t\x12\x12\n\ncreated_at\x18\x15 \x01(\t\"n\n\x13\x44\x61taSourceRulesInfo\x12\x42\n\x07results\x18\x01 \x03(\x0b\x32\x31.spaceone.api.cost_analysis.v1.DataSourceRuleInfo\x12\x13\n\x0btotal_count\x18\x02 \x01(\x05\"b\n\x17\x44\x61taSourceRuleStatQuery\x12\x34\n\x05query\x18\x01 \x01(\x0b\x32%.spaceone.api.core.v1.StatisticsQuery\x12\x11\n\tdomain_id\x18\x02 \x01(\t*:\n\x10\x43onditionsPolicy\x12\x08\n\x04NONE\x10\x00\x12\x07\n\x03\x41LL\x10\x01\x12\x07\n\x03\x41NY\x10\x02\x12\n\n\x06\x41LWAYS\x10\x03\x32\xe9\t\n\x0e\x44\x61taSourceRule\x12\xa4\x01\n\x06\x63reate\x12:.spaceone.api.cost_analysis.v1.CreateDataSourceRuleRequest\x1a\x31.spaceone.api.cost_analysis.v1.DataSourceRuleInfo\"+\x82\xd3\xe4\x93\x02%\"#/cost-analysis/v1/data_source_rules\x12\xb9\x01\n\x06update\x12:.spaceone.api.cost_analysis.v1.UpdateDataSourceRuleRequest\x1a\x31.spaceone.api.cost_analysis.v1.DataSourceRuleInfo\"@\x82\xd3\xe4\x93\x02:\x1a\x38/cost-analysis/v1/data_source_rule/{data_source_rule_id}\x12\xca\x01\n\x0c\x63hange_order\x12?.spaceone.api.cost_analysis.v1.ChangeDataSourceRuleOrderRequest\x1a\x31.spaceone.api.cost_analysis.v1.DataSourceRuleInfo\"F\x82\xd3\xe4\x93\x02@\x1a>/cost-analysis/v1/data_source_rule/{data_source_rule_id}/order\x12\x98\x01\n\x06\x64\x65lete\x12\x34.spaceone.api.cost_analysis.v1.DataSourceRuleRequest\x1a\x16.google.protobuf.Empty\"@\x82\xd3\xe4\x93\x02:*8/cost-analysis/v1/data_source_rule/{data_source_rule_id}\x12\xb3\x01\n\x03get\x12\x37.spaceone.api.cost_analysis.v1.GetDataSourceRuleRequest\x1a\x31.spaceone.api.cost_analysis.v1.DataSourceRuleInfo\"@\x82\xd3\xe4\x93\x02:\x12\x38/cost-analysis/v1/data_source_rule/{data_source_rule_id}\x12\xc9\x01\n\x04list\x12\x32.spaceone.api.cost_analysis.v1.DataSourceRuleQuery\x1a\x32.spaceone.api.cost_analysis.v1.DataSourceRulesInfo\"Y\x82\xd3\xe4\x93\x02S\x12#/cost-analysis/v1/data_source_rulesZ,\"*/cost-analysis/v1/data_source_rules/search\x12\x89\x01\n\x04stat\x12\x36.spaceone.api.cost_analysis.v1.DataSourceRuleStatQuery\x1a\x17.google.protobuf.Struct\"0\x82\xd3\xe4\x93\x02*\"(/cost-analysis/v1/data_source_rules/statb\x06proto3')

_CONDITIONSPOLICY = DESCRIPTOR.enum_types_by_name['ConditionsPolicy']
ConditionsPolicy = enum_type_wrapper.EnumTypeWrapper(_CONDITIONSPOLICY)
NONE = 0
ALL = 1
ANY = 2
ALWAYS = 3


_DATASOURCERULECONDITION = DESCRIPTOR.message_types_by_name['DataSourceRuleCondition']
_MATCHRULE = DESCRIPTOR.message_types_by_name['MatchRule']
_DATASOURCERULEACTIONS = DESCRIPTOR.message_types_by_name['DataSourceRuleActions']
_DATASOURCERULEOPTIONS = DESCRIPTOR.message_types_by_name['DataSourceRuleOptions']
_CREATEDATASOURCERULEREQUEST = DESCRIPTOR.message_types_by_name['CreateDataSourceRuleRequest']
_UPDATEDATASOURCERULEREQUEST = DESCRIPTOR.message_types_by_name['UpdateDataSourceRuleRequest']
_CHANGEDATASOURCERULEORDERREQUEST = DESCRIPTOR.message_types_by_name['ChangeDataSourceRuleOrderRequest']
_DATASOURCERULEREQUEST = DESCRIPTOR.message_types_by_name['DataSourceRuleRequest']
_GETDATASOURCERULEREQUEST = DESCRIPTOR.message_types_by_name['GetDataSourceRuleRequest']
_DATASOURCERULEQUERY = DESCRIPTOR.message_types_by_name['DataSourceRuleQuery']
_DATASOURCERULEINFO = DESCRIPTOR.message_types_by_name['DataSourceRuleInfo']
_DATASOURCERULESINFO = DESCRIPTOR.message_types_by_name['DataSourceRulesInfo']
_DATASOURCERULESTATQUERY = DESCRIPTOR.message_types_by_name['DataSourceRuleStatQuery']
DataSourceRuleCondition = _reflection.GeneratedProtocolMessageType('DataSourceRuleCondition', (_message.Message,), {
  'DESCRIPTOR' : _DATASOURCERULECONDITION,
  '__module__' : 'spaceone.api.cost_analysis.v1.data_source_rule_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.cost_analysis.v1.DataSourceRuleCondition)
  })
_sym_db.RegisterMessage(DataSourceRuleCondition)

MatchRule = _reflection.GeneratedProtocolMessageType('MatchRule', (_message.Message,), {
  'DESCRIPTOR' : _MATCHRULE,
  '__module__' : 'spaceone.api.cost_analysis.v1.data_source_rule_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.cost_analysis.v1.MatchRule)
  })
_sym_db.RegisterMessage(MatchRule)

DataSourceRuleActions = _reflection.GeneratedProtocolMessageType('DataSourceRuleActions', (_message.Message,), {
  'DESCRIPTOR' : _DATASOURCERULEACTIONS,
  '__module__' : 'spaceone.api.cost_analysis.v1.data_source_rule_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.cost_analysis.v1.DataSourceRuleActions)
  })
_sym_db.RegisterMessage(DataSourceRuleActions)

DataSourceRuleOptions = _reflection.GeneratedProtocolMessageType('DataSourceRuleOptions', (_message.Message,), {
  'DESCRIPTOR' : _DATASOURCERULEOPTIONS,
  '__module__' : 'spaceone.api.cost_analysis.v1.data_source_rule_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.cost_analysis.v1.DataSourceRuleOptions)
  })
_sym_db.RegisterMessage(DataSourceRuleOptions)

CreateDataSourceRuleRequest = _reflection.GeneratedProtocolMessageType('CreateDataSourceRuleRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEDATASOURCERULEREQUEST,
  '__module__' : 'spaceone.api.cost_analysis.v1.data_source_rule_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.cost_analysis.v1.CreateDataSourceRuleRequest)
  })
_sym_db.RegisterMessage(CreateDataSourceRuleRequest)

UpdateDataSourceRuleRequest = _reflection.GeneratedProtocolMessageType('UpdateDataSourceRuleRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEDATASOURCERULEREQUEST,
  '__module__' : 'spaceone.api.cost_analysis.v1.data_source_rule_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.cost_analysis.v1.UpdateDataSourceRuleRequest)
  })
_sym_db.RegisterMessage(UpdateDataSourceRuleRequest)

ChangeDataSourceRuleOrderRequest = _reflection.GeneratedProtocolMessageType('ChangeDataSourceRuleOrderRequest', (_message.Message,), {
  'DESCRIPTOR' : _CHANGEDATASOURCERULEORDERREQUEST,
  '__module__' : 'spaceone.api.cost_analysis.v1.data_source_rule_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.cost_analysis.v1.ChangeDataSourceRuleOrderRequest)
  })
_sym_db.RegisterMessage(ChangeDataSourceRuleOrderRequest)

DataSourceRuleRequest = _reflection.GeneratedProtocolMessageType('DataSourceRuleRequest', (_message.Message,), {
  'DESCRIPTOR' : _DATASOURCERULEREQUEST,
  '__module__' : 'spaceone.api.cost_analysis.v1.data_source_rule_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.cost_analysis.v1.DataSourceRuleRequest)
  })
_sym_db.RegisterMessage(DataSourceRuleRequest)

GetDataSourceRuleRequest = _reflection.GeneratedProtocolMessageType('GetDataSourceRuleRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETDATASOURCERULEREQUEST,
  '__module__' : 'spaceone.api.cost_analysis.v1.data_source_rule_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.cost_analysis.v1.GetDataSourceRuleRequest)
  })
_sym_db.RegisterMessage(GetDataSourceRuleRequest)

DataSourceRuleQuery = _reflection.GeneratedProtocolMessageType('DataSourceRuleQuery', (_message.Message,), {
  'DESCRIPTOR' : _DATASOURCERULEQUERY,
  '__module__' : 'spaceone.api.cost_analysis.v1.data_source_rule_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.cost_analysis.v1.DataSourceRuleQuery)
  })
_sym_db.RegisterMessage(DataSourceRuleQuery)

DataSourceRuleInfo = _reflection.GeneratedProtocolMessageType('DataSourceRuleInfo', (_message.Message,), {
  'DESCRIPTOR' : _DATASOURCERULEINFO,
  '__module__' : 'spaceone.api.cost_analysis.v1.data_source_rule_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.cost_analysis.v1.DataSourceRuleInfo)
  })
_sym_db.RegisterMessage(DataSourceRuleInfo)

DataSourceRulesInfo = _reflection.GeneratedProtocolMessageType('DataSourceRulesInfo', (_message.Message,), {
  'DESCRIPTOR' : _DATASOURCERULESINFO,
  '__module__' : 'spaceone.api.cost_analysis.v1.data_source_rule_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.cost_analysis.v1.DataSourceRulesInfo)
  })
_sym_db.RegisterMessage(DataSourceRulesInfo)

DataSourceRuleStatQuery = _reflection.GeneratedProtocolMessageType('DataSourceRuleStatQuery', (_message.Message,), {
  'DESCRIPTOR' : _DATASOURCERULESTATQUERY,
  '__module__' : 'spaceone.api.cost_analysis.v1.data_source_rule_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.cost_analysis.v1.DataSourceRuleStatQuery)
  })
_sym_db.RegisterMessage(DataSourceRuleStatQuery)

_DATASOURCERULE = DESCRIPTOR.services_by_name['DataSourceRule']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _DATASOURCERULE.methods_by_name['create']._options = None
  _DATASOURCERULE.methods_by_name['create']._serialized_options = b'\202\323\344\223\002%\"#/cost-analysis/v1/data_source_rules'
  _DATASOURCERULE.methods_by_name['update']._options = None
  _DATASOURCERULE.methods_by_name['update']._serialized_options = b'\202\323\344\223\002:\0328/cost-analysis/v1/data_source_rule/{data_source_rule_id}'
  _DATASOURCERULE.methods_by_name['change_order']._options = None
  _DATASOURCERULE.methods_by_name['change_order']._serialized_options = b'\202\323\344\223\002@\032>/cost-analysis/v1/data_source_rule/{data_source_rule_id}/order'
  _DATASOURCERULE.methods_by_name['delete']._options = None
  _DATASOURCERULE.methods_by_name['delete']._serialized_options = b'\202\323\344\223\002:*8/cost-analysis/v1/data_source_rule/{data_source_rule_id}'
  _DATASOURCERULE.methods_by_name['get']._options = None
  _DATASOURCERULE.methods_by_name['get']._serialized_options = b'\202\323\344\223\002:\0228/cost-analysis/v1/data_source_rule/{data_source_rule_id}'
  _DATASOURCERULE.methods_by_name['list']._options = None
  _DATASOURCERULE.methods_by_name['list']._serialized_options = b'\202\323\344\223\002S\022#/cost-analysis/v1/data_source_rulesZ,\"*/cost-analysis/v1/data_source_rules/search'
  _DATASOURCERULE.methods_by_name['stat']._options = None
  _DATASOURCERULE.methods_by_name['stat']._serialized_options = b'\202\323\344\223\002*\"(/cost-analysis/v1/data_source_rules/stat'
  _CONDITIONSPOLICY._serialized_start=2574
  _CONDITIONSPOLICY._serialized_end=2632
  _DATASOURCERULECONDITION._serialized_start=210
  _DATASOURCERULECONDITION._serialized_end=281
  _MATCHRULE._serialized_start=283
  _MATCHRULE._serialized_end=326
  _DATASOURCERULEACTIONS._serialized_start=329
  _DATASOURCERULEACTIONS._serialized_end=568
  _DATASOURCERULEOPTIONS._serialized_start=570
  _DATASOURCERULEOPTIONS._serialized_end=618
  _CREATEDATASOURCERULEREQUEST._serialized_start=621
  _CREATEDATASOURCERULEREQUEST._serialized_end=1040
  _UPDATEDATASOURCERULEREQUEST._serialized_start=1043
  _UPDATEDATASOURCERULEREQUEST._serialized_end=1467
  _CHANGEDATASOURCERULEORDERREQUEST._serialized_start=1469
  _CHANGEDATASOURCERULEORDERREQUEST._serialized_end=1566
  _DATASOURCERULEREQUEST._serialized_start=1568
  _DATASOURCERULEREQUEST._serialized_end=1639
  _GETDATASOURCERULEREQUEST._serialized_start=1641
  _GETDATASOURCERULEREQUEST._serialized_end=1729
  _DATASOURCERULEQUERY._serialized_start=1732
  _DATASOURCERULEQUERY._serialized_end=1883
  _DATASOURCERULEINFO._serialized_start=1886
  _DATASOURCERULEINFO._serialized_end=2360
  _DATASOURCERULESINFO._serialized_start=2362
  _DATASOURCERULESINFO._serialized_end=2472
  _DATASOURCERULESTATQUERY._serialized_start=2474
  _DATASOURCERULESTATQUERY._serialized_end=2572
  _DATASOURCERULE._serialized_start=2635
  _DATASOURCERULE._serialized_end=3892
# @@protoc_insertion_point(module_scope)
