# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: spaceone/api/inventory/v1/job.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from spaceone.api.core.v1 import query_pb2 as spaceone_dot_api_dot_core_dot_v1_dot_query__pb2
from spaceone.api.inventory.v1 import collector_pb2 as spaceone_dot_api_dot_inventory_dot_v1_dot_collector__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#spaceone/api/inventory/v1/job.proto\x12\x19spaceone.api.inventory.v1\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1cgoogle/api/annotations.proto\x1a spaceone/api/core/v1/query.proto\x1a)spaceone/api/inventory/v1/collector.proto\"/\n\nJobRequest\x12\x0e\n\x06job_id\x18\x01 \x01(\t\x12\x11\n\tdomain_id\x18\x02 \x01(\t\"@\n\rGetJobRequest\x12\x0e\n\x06job_id\x18\x01 \x01(\t\x12\x11\n\tdomain_id\x18\x02 \x01(\t\x12\x0c\n\x04only\x18\x03 \x03(\t\"\xb6\x02\n\tJobsQuery\x12*\n\x05query\x18\x01 \x01(\x0b\x32\x1b.spaceone.api.core.v1.Query\x12\x0e\n\x06job_id\x18\x02 \x01(\t\x12>\n\x06status\x18\x03 \x01(\x0e\x32..spaceone.api.inventory.v1.JobsQuery.JobStatus\x12\x14\n\x0c\x63ollector_id\x18\x04 \x01(\t\x12\x12\n\nproject_id\x18\x05 \x01(\t\x12\x11\n\tdomain_id\x18\x06 \x01(\t\"p\n\tJobStatus\x12\x12\n\x0eJOB_STATE_NONE\x10\x00\x12\x0b\n\x07\x43REATED\x10\x01\x12\x0c\n\x08\x43\x41NCELED\x10\x02\x12\x0f\n\x0bIN_PROGRESS\x10\x03\x12\x0b\n\x07SUCCESS\x10\x04\x12\t\n\x05\x45RROR\x10\x05\x12\x0b\n\x07TIMEOUT\x10\x06\"T\n\x08JobsInfo\x12\x33\n\x07results\x18\x01 \x03(\x0b\x32\".spaceone.api.inventory.v1.JobInfo\x12\x13\n\x0btotal_count\x18\x02 \x01(\x05\"W\n\x0cJobStatQuery\x12\x34\n\x05query\x18\x01 \x01(\x0b\x32%.spaceone.api.core.v1.StatisticsQuery\x12\x11\n\tdomain_id\x18\x02 \x01(\t2\xe3\x03\n\x03Job\x12k\n\x06\x64\x65lete\x12%.spaceone.api.inventory.v1.JobRequest\x1a\x16.google.protobuf.Empty\"\"\x82\xd3\xe4\x93\x02\x1c*\x1a/inventory/v1/job/{job_id}\x12w\n\x03get\x12(.spaceone.api.inventory.v1.GetJobRequest\x1a\".spaceone.api.inventory.v1.JobInfo\"\"\x82\xd3\xe4\x93\x02\x1c\x12\x1a/inventory/v1/job/{job_id}\x12\x8a\x01\n\x04list\x12$.spaceone.api.inventory.v1.JobsQuery\x1a#.spaceone.api.inventory.v1.JobsInfo\"7\x82\xd3\xe4\x93\x02\x31\x12\x12/inventory/v1/jobsZ\x1b\"\x19/inventory/v1/jobs/search\x12i\n\x04stat\x12\'.spaceone.api.inventory.v1.JobStatQuery\x1a\x17.google.protobuf.Struct\"\x1f\x82\xd3\xe4\x93\x02\x19\"\x17/inventory/v1/jobs/statb\x06proto3')



_JOBREQUEST = DESCRIPTOR.message_types_by_name['JobRequest']
_GETJOBREQUEST = DESCRIPTOR.message_types_by_name['GetJobRequest']
_JOBSQUERY = DESCRIPTOR.message_types_by_name['JobsQuery']
_JOBSINFO = DESCRIPTOR.message_types_by_name['JobsInfo']
_JOBSTATQUERY = DESCRIPTOR.message_types_by_name['JobStatQuery']
_JOBSQUERY_JOBSTATUS = _JOBSQUERY.enum_types_by_name['JobStatus']
JobRequest = _reflection.GeneratedProtocolMessageType('JobRequest', (_message.Message,), {
  'DESCRIPTOR' : _JOBREQUEST,
  '__module__' : 'spaceone.api.inventory.v1.job_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.JobRequest)
  })
_sym_db.RegisterMessage(JobRequest)

GetJobRequest = _reflection.GeneratedProtocolMessageType('GetJobRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETJOBREQUEST,
  '__module__' : 'spaceone.api.inventory.v1.job_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.GetJobRequest)
  })
_sym_db.RegisterMessage(GetJobRequest)

JobsQuery = _reflection.GeneratedProtocolMessageType('JobsQuery', (_message.Message,), {
  'DESCRIPTOR' : _JOBSQUERY,
  '__module__' : 'spaceone.api.inventory.v1.job_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.JobsQuery)
  })
_sym_db.RegisterMessage(JobsQuery)

JobsInfo = _reflection.GeneratedProtocolMessageType('JobsInfo', (_message.Message,), {
  'DESCRIPTOR' : _JOBSINFO,
  '__module__' : 'spaceone.api.inventory.v1.job_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.JobsInfo)
  })
_sym_db.RegisterMessage(JobsInfo)

JobStatQuery = _reflection.GeneratedProtocolMessageType('JobStatQuery', (_message.Message,), {
  'DESCRIPTOR' : _JOBSTATQUERY,
  '__module__' : 'spaceone.api.inventory.v1.job_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.JobStatQuery)
  })
_sym_db.RegisterMessage(JobStatQuery)

_JOB = DESCRIPTOR.services_by_name['Job']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _JOB.methods_by_name['delete']._options = None
  _JOB.methods_by_name['delete']._serialized_options = b'\202\323\344\223\002\034*\032/inventory/v1/job/{job_id}'
  _JOB.methods_by_name['get']._options = None
  _JOB.methods_by_name['get']._serialized_options = b'\202\323\344\223\002\034\022\032/inventory/v1/job/{job_id}'
  _JOB.methods_by_name['list']._options = None
  _JOB.methods_by_name['list']._serialized_options = b'\202\323\344\223\0021\022\022/inventory/v1/jobsZ\033\"\031/inventory/v1/jobs/search'
  _JOB.methods_by_name['stat']._options = None
  _JOB.methods_by_name['stat']._serialized_options = b'\202\323\344\223\002\031\"\027/inventory/v1/jobs/stat'
  _JOBREQUEST._serialized_start=232
  _JOBREQUEST._serialized_end=279
  _GETJOBREQUEST._serialized_start=281
  _GETJOBREQUEST._serialized_end=345
  _JOBSQUERY._serialized_start=348
  _JOBSQUERY._serialized_end=658
  _JOBSQUERY_JOBSTATUS._serialized_start=546
  _JOBSQUERY_JOBSTATUS._serialized_end=658
  _JOBSINFO._serialized_start=660
  _JOBSINFO._serialized_end=744
  _JOBSTATQUERY._serialized_start=746
  _JOBSTATQUERY._serialized_end=833
  _JOB._serialized_start=836
  _JOB._serialized_end=1319
# @@protoc_insertion_point(module_scope)
