# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from spaceone.api.statistics.v1 import storage_pb2 as spaceone_dot_api_dot_statistics_dot_v1_dot_storage__pb2


class StorageStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.register = channel.unary_unary(
                '/spaceone.api.statistics.v1.Storage/register',
                request_serializer=spaceone_dot_api_dot_statistics_dot_v1_dot_storage__pb2.RegisterStorageRequest.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_statistics_dot_v1_dot_storage__pb2.StorageInfo.FromString,
                )
        self.update = channel.unary_unary(
                '/spaceone.api.statistics.v1.Storage/update',
                request_serializer=spaceone_dot_api_dot_statistics_dot_v1_dot_storage__pb2.UpdateStorageRequest.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_statistics_dot_v1_dot_storage__pb2.StorageInfo.FromString,
                )
        self.update_plugin = channel.unary_unary(
                '/spaceone.api.statistics.v1.Storage/update_plugin',
                request_serializer=spaceone_dot_api_dot_statistics_dot_v1_dot_storage__pb2.UpdateStoragePluginRequest.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_statistics_dot_v1_dot_storage__pb2.StorageInfo.FromString,
                )
        self.verify_plugin = channel.unary_unary(
                '/spaceone.api.statistics.v1.Storage/verify_plugin',
                request_serializer=spaceone_dot_api_dot_statistics_dot_v1_dot_storage__pb2.StorageRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.enable = channel.unary_unary(
                '/spaceone.api.statistics.v1.Storage/enable',
                request_serializer=spaceone_dot_api_dot_statistics_dot_v1_dot_storage__pb2.StorageRequest.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_statistics_dot_v1_dot_storage__pb2.StorageInfo.FromString,
                )
        self.disable = channel.unary_unary(
                '/spaceone.api.statistics.v1.Storage/disable',
                request_serializer=spaceone_dot_api_dot_statistics_dot_v1_dot_storage__pb2.StorageRequest.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_statistics_dot_v1_dot_storage__pb2.StorageInfo.FromString,
                )
        self.deregister = channel.unary_unary(
                '/spaceone.api.statistics.v1.Storage/deregister',
                request_serializer=spaceone_dot_api_dot_statistics_dot_v1_dot_storage__pb2.StorageRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.get = channel.unary_unary(
                '/spaceone.api.statistics.v1.Storage/get',
                request_serializer=spaceone_dot_api_dot_statistics_dot_v1_dot_storage__pb2.GetStorageRequest.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_statistics_dot_v1_dot_storage__pb2.StorageInfo.FromString,
                )
        self.list = channel.unary_unary(
                '/spaceone.api.statistics.v1.Storage/list',
                request_serializer=spaceone_dot_api_dot_statistics_dot_v1_dot_storage__pb2.StorageQuery.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_statistics_dot_v1_dot_storage__pb2.StoragesInfo.FromString,
                )
        self.stat = channel.unary_unary(
                '/spaceone.api.statistics.v1.Storage/stat',
                request_serializer=spaceone_dot_api_dot_statistics_dot_v1_dot_storage__pb2.StorageStatQuery.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_struct__pb2.Struct.FromString,
                )


class StorageServicer(object):
    """Missing associated documentation comment in .proto file."""

    def register(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def update(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def update_plugin(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def verify_plugin(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def enable(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def disable(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def deregister(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def get(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def list(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def stat(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_StorageServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'register': grpc.unary_unary_rpc_method_handler(
                    servicer.register,
                    request_deserializer=spaceone_dot_api_dot_statistics_dot_v1_dot_storage__pb2.RegisterStorageRequest.FromString,
                    response_serializer=spaceone_dot_api_dot_statistics_dot_v1_dot_storage__pb2.StorageInfo.SerializeToString,
            ),
            'update': grpc.unary_unary_rpc_method_handler(
                    servicer.update,
                    request_deserializer=spaceone_dot_api_dot_statistics_dot_v1_dot_storage__pb2.UpdateStorageRequest.FromString,
                    response_serializer=spaceone_dot_api_dot_statistics_dot_v1_dot_storage__pb2.StorageInfo.SerializeToString,
            ),
            'update_plugin': grpc.unary_unary_rpc_method_handler(
                    servicer.update_plugin,
                    request_deserializer=spaceone_dot_api_dot_statistics_dot_v1_dot_storage__pb2.UpdateStoragePluginRequest.FromString,
                    response_serializer=spaceone_dot_api_dot_statistics_dot_v1_dot_storage__pb2.StorageInfo.SerializeToString,
            ),
            'verify_plugin': grpc.unary_unary_rpc_method_handler(
                    servicer.verify_plugin,
                    request_deserializer=spaceone_dot_api_dot_statistics_dot_v1_dot_storage__pb2.StorageRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'enable': grpc.unary_unary_rpc_method_handler(
                    servicer.enable,
                    request_deserializer=spaceone_dot_api_dot_statistics_dot_v1_dot_storage__pb2.StorageRequest.FromString,
                    response_serializer=spaceone_dot_api_dot_statistics_dot_v1_dot_storage__pb2.StorageInfo.SerializeToString,
            ),
            'disable': grpc.unary_unary_rpc_method_handler(
                    servicer.disable,
                    request_deserializer=spaceone_dot_api_dot_statistics_dot_v1_dot_storage__pb2.StorageRequest.FromString,
                    response_serializer=spaceone_dot_api_dot_statistics_dot_v1_dot_storage__pb2.StorageInfo.SerializeToString,
            ),
            'deregister': grpc.unary_unary_rpc_method_handler(
                    servicer.deregister,
                    request_deserializer=spaceone_dot_api_dot_statistics_dot_v1_dot_storage__pb2.StorageRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'get': grpc.unary_unary_rpc_method_handler(
                    servicer.get,
                    request_deserializer=spaceone_dot_api_dot_statistics_dot_v1_dot_storage__pb2.GetStorageRequest.FromString,
                    response_serializer=spaceone_dot_api_dot_statistics_dot_v1_dot_storage__pb2.StorageInfo.SerializeToString,
            ),
            'list': grpc.unary_unary_rpc_method_handler(
                    servicer.list,
                    request_deserializer=spaceone_dot_api_dot_statistics_dot_v1_dot_storage__pb2.StorageQuery.FromString,
                    response_serializer=spaceone_dot_api_dot_statistics_dot_v1_dot_storage__pb2.StoragesInfo.SerializeToString,
            ),
            'stat': grpc.unary_unary_rpc_method_handler(
                    servicer.stat,
                    request_deserializer=spaceone_dot_api_dot_statistics_dot_v1_dot_storage__pb2.StorageStatQuery.FromString,
                    response_serializer=google_dot_protobuf_dot_struct__pb2.Struct.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'spaceone.api.statistics.v1.Storage', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class Storage(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def register(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.statistics.v1.Storage/register',
            spaceone_dot_api_dot_statistics_dot_v1_dot_storage__pb2.RegisterStorageRequest.SerializeToString,
            spaceone_dot_api_dot_statistics_dot_v1_dot_storage__pb2.StorageInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def update(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.statistics.v1.Storage/update',
            spaceone_dot_api_dot_statistics_dot_v1_dot_storage__pb2.UpdateStorageRequest.SerializeToString,
            spaceone_dot_api_dot_statistics_dot_v1_dot_storage__pb2.StorageInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def update_plugin(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.statistics.v1.Storage/update_plugin',
            spaceone_dot_api_dot_statistics_dot_v1_dot_storage__pb2.UpdateStoragePluginRequest.SerializeToString,
            spaceone_dot_api_dot_statistics_dot_v1_dot_storage__pb2.StorageInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def verify_plugin(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.statistics.v1.Storage/verify_plugin',
            spaceone_dot_api_dot_statistics_dot_v1_dot_storage__pb2.StorageRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def enable(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.statistics.v1.Storage/enable',
            spaceone_dot_api_dot_statistics_dot_v1_dot_storage__pb2.StorageRequest.SerializeToString,
            spaceone_dot_api_dot_statistics_dot_v1_dot_storage__pb2.StorageInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def disable(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.statistics.v1.Storage/disable',
            spaceone_dot_api_dot_statistics_dot_v1_dot_storage__pb2.StorageRequest.SerializeToString,
            spaceone_dot_api_dot_statistics_dot_v1_dot_storage__pb2.StorageInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def deregister(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.statistics.v1.Storage/deregister',
            spaceone_dot_api_dot_statistics_dot_v1_dot_storage__pb2.StorageRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def get(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.statistics.v1.Storage/get',
            spaceone_dot_api_dot_statistics_dot_v1_dot_storage__pb2.GetStorageRequest.SerializeToString,
            spaceone_dot_api_dot_statistics_dot_v1_dot_storage__pb2.StorageInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def list(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.statistics.v1.Storage/list',
            spaceone_dot_api_dot_statistics_dot_v1_dot_storage__pb2.StorageQuery.SerializeToString,
            spaceone_dot_api_dot_statistics_dot_v1_dot_storage__pb2.StoragesInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def stat(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.statistics.v1.Storage/stat',
            spaceone_dot_api_dot_statistics_dot_v1_dot_storage__pb2.StorageStatQuery.SerializeToString,
            google_dot_protobuf_dot_struct__pb2.Struct.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
