# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: spaceone/api/provisioning/v1/catalog_resource.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from spaceone.api.core.v1 import query_pb2 as spaceone_dot_api_dot_core_dot_v1_dot_query__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n3spaceone/api/provisioning/v1/catalog_resource.proto\x12\x1cspaceone.api.provisioning.v1\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1cgoogle/api/annotations.proto\x1a spaceone/api/core/v1/query.proto\"\x96\x03\n\x1c\x43reateCatalogResourceRequest\x12\x11\n\tdomain_id\x18\x01 \x01(\t\x12\x12\n\ncatalog_id\x18\x02 \x01(\t\x12\x13\n\x0bresource_id\x18\x03 \x01(\t\x12\x15\n\rresource_name\x18\x04 \x01(\t\x12\x16\n\x0eterraform_code\x18\x05 \x01(\t\x12\x13\n\x0bvalid_value\x18\x06 \x03(\t\x12\x35\n\x14terraform_properties\x18\x07 \x01(\x0b\x32\x17.google.protobuf.Struct\x12$\n\x03tag\x18\x08 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x12\n\ncreated_at\x18\t \x01(\t\x12\x12\n\nupdated_at\x18\n \x01(\t\x12\x14\n\x0c\x61nsible_code\x18\x0b \x01(\t\x12\x0f\n\x07node_id\x18\x0c \x01(\r\x12\x33\n\x12\x61nsible_properties\x18\r \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x15\n\rresource_type\x18\x0e \x01(\t\"\\\n\x16\x43\x61talogResourceRequest\x12\x1b\n\x13\x63\x61talog_resource_id\x18\x01 \x01(\t\x12\x12\n\ncatalog_id\x18\x02 \x01(\t\x12\x11\n\tdomain_id\x18\x03 \x01(\t\"Y\n\x19GetCatalogResourceRequest\x12\x1b\n\x13\x63\x61talog_resource_id\x18\x01 \x01(\t\x12\x11\n\tdomain_id\x18\x02 \x01(\t\x12\x0c\n\x04only\x18\x03 \x03(\t\"\xb3\x03\n\x1cUpdateCatalogResourceRequest\x12\x11\n\tdomain_id\x18\x01 \x01(\t\x12\x1b\n\x13\x63\x61talog_resource_id\x18\x02 \x01(\t\x12\x12\n\ncatalog_id\x18\x03 \x01(\t\x12\x13\n\x0bresource_id\x18\x04 \x01(\t\x12\x15\n\rresource_name\x18\x05 \x01(\t\x12\x16\n\x0eterraform_code\x18\x06 \x01(\t\x12\x13\n\x0bvalid_value\x18\x07 \x03(\t\x12\x35\n\x14terraform_properties\x18\x08 \x01(\x0b\x32\x17.google.protobuf.Struct\x12$\n\x03tag\x18\t \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x12\n\ncreated_at\x18\n \x01(\t\x12\x12\n\nupdated_at\x18\x0b \x01(\t\x12\x14\n\x0c\x61nsible_code\x18\x0c \x01(\t\x12\x0f\n\x07node_id\x18\r \x01(\r\x12\x33\n\x12\x61nsible_properties\x18\x0e \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x15\n\rresource_type\x18\x0f \x01(\t\"\xd8\x01\n\x14\x43\x61talogResourceQuery\x12*\n\x05query\x18\x01 \x01(\x0b\x32\x1b.spaceone.api.core.v1.Query\x12\x1b\n\x13\x63\x61talog_resource_id\x18\x02 \x01(\t\x12\x12\n\ncatalog_id\x18\x03 \x01(\t\x12\x13\n\x0bresource_id\x18\x04 \x01(\t\x12\x15\n\rresource_name\x18\x05 \x01(\t\x12$\n\x03tag\x18\x06 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x11\n\tdomain_id\x18\x07 \x01(\t\"c\n\x18\x43\x61talogResourceStatQuery\x12\x34\n\x05query\x18\x01 \x01(\x0b\x32%.spaceone.api.core.v1.StatisticsQuery\x12\x11\n\tdomain_id\x18\x02 \x01(\t\"\xd2\x03\n\x13\x43\x61talogResourceInfo\x12\x11\n\tdomain_id\x18\x01 \x01(\t\x12\x1b\n\x13\x63\x61talog_resource_id\x18\x02 \x01(\t\x12\x12\n\ncatalog_id\x18\x03 \x01(\t\x12\x13\n\x0bresource_id\x18\x04 \x01(\t\x12\x15\n\rresource_name\x18\x05 \x01(\t\x12\x16\n\x0eterraform_code\x18\x06 \x01(\t\x12\x13\n\x0bvalid_value\x18\x07 \x03(\t\x12\x35\n\x14terraform_properties\x18\x08 \x01(\x0b\x32\x17.google.protobuf.Struct\x12$\n\x03tag\x18\t \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x12\n\ncreated_at\x18\n \x01(\t\x12\x12\n\nupdated_at\x18\x0b \x01(\t\x12\x14\n\x0c\x61nsible_code\x18\x0c \x01(\t\x12\x12\n\ncreated_by\x18\r \x01(\t\x12\x12\n\nupdated_by\x18\x0e \x01(\t\x12\x0f\n\x07node_id\x18\x0f \x01(\r\x12\x33\n\x12\x61nsible_properties\x18\x10 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x15\n\rresource_type\x18\x11 \x01(\t\"o\n\x14\x43\x61talogResourcesInfo\x12\x42\n\x07results\x18\x01 \x03(\x0b\x32\x31.spaceone.api.provisioning.v1.CatalogResourceInfo\x12\x13\n\x0btotal_count\x18\x02 \x01(\x05\x32\xd3\x08\n\x0f\x43\x61talogResource\x12\xb3\x01\n\x17\x63reate_catalog_resource\x12:.spaceone.api.provisioning.v1.CreateCatalogResourceRequest\x1a\x31.spaceone.api.provisioning.v1.CatalogResourceInfo\")\x82\xd3\xe4\x93\x02#\"!/provisioning/v1/catalog-resource\x12\xd8\x01\n\x15get_catalog_resources\x12\x32.spaceone.api.provisioning.v1.CatalogResourceQuery\x1a\x32.spaceone.api.provisioning.v1.CatalogResourcesInfo\"W\x82\xd3\xe4\x93\x02Q\x12\"/provisioning/v1/catalog-resourcesZ+\")/provisioning/v1/catalog-resources/search\x12\xc3\x01\n\x14get_catalog_resource\x12\x37.spaceone.api.provisioning.v1.GetCatalogResourceRequest\x1a\x31.spaceone.api.provisioning.v1.CatalogResourceInfo\"?\x82\xd3\xe4\x93\x02\x39\x12\x37/provisioning/v1/catalog-resource/{catalog_resource_id}\x12\xb3\x01\n\x17update_catalog_resource\x12:.spaceone.api.provisioning.v1.UpdateCatalogResourceRequest\x1a\x31.spaceone.api.provisioning.v1.CatalogResourceInfo\")\x82\xd3\xe4\x93\x02#\x1a!/provisioning/v1/catalog-resource\x12\xa8\x01\n\x17\x64\x65lete_catalog_resource\x12\x34.spaceone.api.provisioning.v1.CatalogResourceRequest\x1a\x16.google.protobuf.Empty\"?\x82\xd3\xe4\x93\x02\x39*7/provisioning/v1/catalog-resource/{catalog_resource_id}\x12\x87\x01\n\x04stat\x12\x36.spaceone.api.provisioning.v1.CatalogResourceStatQuery\x1a\x17.google.protobuf.Struct\".\x82\xd3\xe4\x93\x02(\"&/provisioning/v1/catalog-resource/statb\x06proto3')



_CREATECATALOGRESOURCEREQUEST = DESCRIPTOR.message_types_by_name['CreateCatalogResourceRequest']
_CATALOGRESOURCEREQUEST = DESCRIPTOR.message_types_by_name['CatalogResourceRequest']
_GETCATALOGRESOURCEREQUEST = DESCRIPTOR.message_types_by_name['GetCatalogResourceRequest']
_UPDATECATALOGRESOURCEREQUEST = DESCRIPTOR.message_types_by_name['UpdateCatalogResourceRequest']
_CATALOGRESOURCEQUERY = DESCRIPTOR.message_types_by_name['CatalogResourceQuery']
_CATALOGRESOURCESTATQUERY = DESCRIPTOR.message_types_by_name['CatalogResourceStatQuery']
_CATALOGRESOURCEINFO = DESCRIPTOR.message_types_by_name['CatalogResourceInfo']
_CATALOGRESOURCESINFO = DESCRIPTOR.message_types_by_name['CatalogResourcesInfo']
CreateCatalogResourceRequest = _reflection.GeneratedProtocolMessageType('CreateCatalogResourceRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATECATALOGRESOURCEREQUEST,
  '__module__' : 'spaceone.api.provisioning.v1.catalog_resource_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.provisioning.v1.CreateCatalogResourceRequest)
  })
_sym_db.RegisterMessage(CreateCatalogResourceRequest)

CatalogResourceRequest = _reflection.GeneratedProtocolMessageType('CatalogResourceRequest', (_message.Message,), {
  'DESCRIPTOR' : _CATALOGRESOURCEREQUEST,
  '__module__' : 'spaceone.api.provisioning.v1.catalog_resource_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.provisioning.v1.CatalogResourceRequest)
  })
_sym_db.RegisterMessage(CatalogResourceRequest)

GetCatalogResourceRequest = _reflection.GeneratedProtocolMessageType('GetCatalogResourceRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETCATALOGRESOURCEREQUEST,
  '__module__' : 'spaceone.api.provisioning.v1.catalog_resource_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.provisioning.v1.GetCatalogResourceRequest)
  })
_sym_db.RegisterMessage(GetCatalogResourceRequest)

UpdateCatalogResourceRequest = _reflection.GeneratedProtocolMessageType('UpdateCatalogResourceRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATECATALOGRESOURCEREQUEST,
  '__module__' : 'spaceone.api.provisioning.v1.catalog_resource_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.provisioning.v1.UpdateCatalogResourceRequest)
  })
_sym_db.RegisterMessage(UpdateCatalogResourceRequest)

CatalogResourceQuery = _reflection.GeneratedProtocolMessageType('CatalogResourceQuery', (_message.Message,), {
  'DESCRIPTOR' : _CATALOGRESOURCEQUERY,
  '__module__' : 'spaceone.api.provisioning.v1.catalog_resource_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.provisioning.v1.CatalogResourceQuery)
  })
_sym_db.RegisterMessage(CatalogResourceQuery)

CatalogResourceStatQuery = _reflection.GeneratedProtocolMessageType('CatalogResourceStatQuery', (_message.Message,), {
  'DESCRIPTOR' : _CATALOGRESOURCESTATQUERY,
  '__module__' : 'spaceone.api.provisioning.v1.catalog_resource_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.provisioning.v1.CatalogResourceStatQuery)
  })
_sym_db.RegisterMessage(CatalogResourceStatQuery)

CatalogResourceInfo = _reflection.GeneratedProtocolMessageType('CatalogResourceInfo', (_message.Message,), {
  'DESCRIPTOR' : _CATALOGRESOURCEINFO,
  '__module__' : 'spaceone.api.provisioning.v1.catalog_resource_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.provisioning.v1.CatalogResourceInfo)
  })
_sym_db.RegisterMessage(CatalogResourceInfo)

CatalogResourcesInfo = _reflection.GeneratedProtocolMessageType('CatalogResourcesInfo', (_message.Message,), {
  'DESCRIPTOR' : _CATALOGRESOURCESINFO,
  '__module__' : 'spaceone.api.provisioning.v1.catalog_resource_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.provisioning.v1.CatalogResourcesInfo)
  })
_sym_db.RegisterMessage(CatalogResourcesInfo)

_CATALOGRESOURCE = DESCRIPTOR.services_by_name['CatalogResource']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _CATALOGRESOURCE.methods_by_name['create_catalog_resource']._options = None
  _CATALOGRESOURCE.methods_by_name['create_catalog_resource']._serialized_options = b'\202\323\344\223\002#\"!/provisioning/v1/catalog-resource'
  _CATALOGRESOURCE.methods_by_name['get_catalog_resources']._options = None
  _CATALOGRESOURCE.methods_by_name['get_catalog_resources']._serialized_options = b'\202\323\344\223\002Q\022\"/provisioning/v1/catalog-resourcesZ+\")/provisioning/v1/catalog-resources/search'
  _CATALOGRESOURCE.methods_by_name['get_catalog_resource']._options = None
  _CATALOGRESOURCE.methods_by_name['get_catalog_resource']._serialized_options = b'\202\323\344\223\0029\0227/provisioning/v1/catalog-resource/{catalog_resource_id}'
  _CATALOGRESOURCE.methods_by_name['update_catalog_resource']._options = None
  _CATALOGRESOURCE.methods_by_name['update_catalog_resource']._serialized_options = b'\202\323\344\223\002#\032!/provisioning/v1/catalog-resource'
  _CATALOGRESOURCE.methods_by_name['delete_catalog_resource']._options = None
  _CATALOGRESOURCE.methods_by_name['delete_catalog_resource']._serialized_options = b'\202\323\344\223\0029*7/provisioning/v1/catalog-resource/{catalog_resource_id}'
  _CATALOGRESOURCE.methods_by_name['stat']._options = None
  _CATALOGRESOURCE.methods_by_name['stat']._serialized_options = b'\202\323\344\223\002(\"&/provisioning/v1/catalog-resource/stat'
  _CREATECATALOGRESOURCEREQUEST._serialized_start=209
  _CREATECATALOGRESOURCEREQUEST._serialized_end=615
  _CATALOGRESOURCEREQUEST._serialized_start=617
  _CATALOGRESOURCEREQUEST._serialized_end=709
  _GETCATALOGRESOURCEREQUEST._serialized_start=711
  _GETCATALOGRESOURCEREQUEST._serialized_end=800
  _UPDATECATALOGRESOURCEREQUEST._serialized_start=803
  _UPDATECATALOGRESOURCEREQUEST._serialized_end=1238
  _CATALOGRESOURCEQUERY._serialized_start=1241
  _CATALOGRESOURCEQUERY._serialized_end=1457
  _CATALOGRESOURCESTATQUERY._serialized_start=1459
  _CATALOGRESOURCESTATQUERY._serialized_end=1558
  _CATALOGRESOURCEINFO._serialized_start=1561
  _CATALOGRESOURCEINFO._serialized_end=2027
  _CATALOGRESOURCESINFO._serialized_start=2029
  _CATALOGRESOURCESINFO._serialized_end=2140
  _CATALOGRESOURCE._serialized_start=2143
  _CATALOGRESOURCE._serialized_end=3250
# @@protoc_insertion_point(module_scope)
