# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: spaceone/api/identity/v1/authorization.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from spaceone.api.core.v1 import handler_pb2 as spaceone_dot_api_dot_core_dot_v1_dot_handler__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n,spaceone/api/identity/v1/authorization.proto\x12\x18spaceone.api.identity.v1\x1a\x1cgoogle/api/annotations.proto\x1a\"spaceone/api/core/v1/handler.proto2\x9e\x01\n\rAuthorization\x12\x8c\x01\n\x06verify\x12*.spaceone.api.core.v1.AuthorizationRequest\x1a+.spaceone.api.core.v1.AuthorizationResponse\")\x82\xd3\xe4\x93\x02#\"!/identity/v1/authorization/verifyb\x06proto3')



_AUTHORIZATION = DESCRIPTOR.services_by_name['Authorization']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _AUTHORIZATION.methods_by_name['verify']._options = None
  _AUTHORIZATION.methods_by_name['verify']._serialized_options = b'\202\323\344\223\002#\"!/identity/v1/authorization/verify'
  _AUTHORIZATION._serialized_start=141
  _AUTHORIZATION._serialized_end=299
# @@protoc_insertion_point(module_scope)
