# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: spaceone/api/identity/v1/service_account.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from spaceone.api.core.v1 import query_pb2 as spaceone_dot_api_dot_core_dot_v1_dot_query__pb2
from spaceone.api.identity.v1 import project_pb2 as spaceone_dot_api_dot_identity_dot_v1_dot_project__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n.spaceone/api/identity/v1/service_account.proto\x12\x18spaceone.api.identity.v1\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1cgoogle/api/annotations.proto\x1a spaceone/api/core/v1/query.proto\x1a&spaceone/api/identity/v1/project.proto\"\xf4\x01\n\x1b\x43reateServiceAccountRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12%\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x10\n\x08provider\x18\x03 \x01(\t\x12\x12\n\nproject_id\x18\x04 \x01(\t\x12%\n\x04tags\x18\x05 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x1c\n\x14service_account_type\x18\x0b \x01(\t\x12\"\n\x1atrusted_service_account_id\x18\x0c \x01(\t\x12\x11\n\tdomain_id\x18\x15 \x01(\t\"\x89\x02\n\x1bUpdateServiceAccountRequest\x12\x1a\n\x12service_account_id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12%\n\x04\x64\x61ta\x18\x03 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x12\n\nproject_id\x18\x04 \x01(\t\x12%\n\x04tags\x18\x05 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\"\n\x1atrusted_service_account_id\x18\x06 \x01(\t\x12\'\n\x1frelease_trusted_service_account\x18\x07 \x01(\x08\x12\x11\n\tdomain_id\x18\x0b \x01(\t\"F\n\x15ServiceAccountRequest\x12\x1a\n\x12service_account_id\x18\x01 \x01(\t\x12\x11\n\tdomain_id\x18\x02 \x01(\t\"W\n\x18GetServiceAccountRequest\x12\x1a\n\x12service_account_id\x18\x01 \x01(\t\x12\x11\n\tdomain_id\x18\x02 \x01(\t\x12\x0c\n\x04only\x18\x03 \x03(\t\"\xf5\x01\n\x13ServiceAccountQuery\x12*\n\x05query\x18\x01 \x01(\x0b\x32\x1b.spaceone.api.core.v1.Query\x12\x1a\n\x12service_account_id\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x1c\n\x14service_account_type\x18\x04 \x01(\t\x12\x10\n\x08provider\x18\x05 \x01(\t\x12\"\n\x1atrusted_service_account_id\x18\x06 \x01(\t\x12\x12\n\nproject_id\x18\x07 \x01(\t\x12\r\n\x05scope\x18\x08 \x01(\t\x12\x11\n\tdomain_id\x18\x0b \x01(\t\"\xd3\x02\n\x12ServiceAccountInfo\x12\x1a\n\x12service_account_id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x1c\n\x14service_account_type\x18\x03 \x01(\t\x12%\n\x04\x64\x61ta\x18\x04 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x10\n\x08provider\x18\x05 \x01(\t\x12\"\n\x1atrusted_service_account_id\x18\x06 \x01(\t\x12;\n\x0cproject_info\x18\x07 \x01(\x0b\x32%.spaceone.api.identity.v1.ProjectInfo\x12\r\n\x05scope\x18\x08 \x01(\t\x12\x11\n\tdomain_id\x18\x15 \x01(\t\x12%\n\x04tags\x18\x16 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x12\n\ncreated_at\x18\x17 \x01(\t\"i\n\x13ServiceAccountsInfo\x12=\n\x07results\x18\x01 \x03(\x0b\x32,.spaceone.api.identity.v1.ServiceAccountInfo\x12\x13\n\x0btotal_count\x18\x02 \x01(\x05\"b\n\x17ServiceAccountStatQuery\x12\x34\n\x05query\x18\x01 \x01(\x0b\x32%.spaceone.api.core.v1.StatisticsQuery\x12\x11\n\tdomain_id\x18\x02 \x01(\t\"\x94\x01\n\x11RegionConfigQuery\x12*\n\x05query\x18\x01 \x01(\x0b\x32\x1b.spaceone.api.core.v1.Query\x12\x11\n\tdomain_id\x18\x02 \x01(\t\x12\x12\n\nproject_id\x18\x03 \x01(\t\x12\x10\n\x08provider\x18\x04 \x01(\t\x12\x1a\n\x12service_account_id\x18\x05 \x01(\t\"\xa3\x01\n\x10RegionConfigData\x12\x13\n\x0bregion_name\x18\x01 \x01(\t\x12L\n\x0cis_available\x18\x02 \x01(\x0e\x32\x36.spaceone.api.identity.v1.RegionConfigData.IsAvailable\",\n\x0bIsAvailable\x12\x08\n\x04NONE\x10\x00\x12\t\n\x05\x46\x41LSE\x10\x01\x12\x08\n\x04TRUE\x10\x02\"e\n\x11RegionsConfigInfo\x12;\n\x07results\x18\x01 \x03(\x0b\x32*.spaceone.api.identity.v1.RegionConfigInfo\x12\x13\n\x0btotal_count\x18\x02 \x01(\x05\"\xbe\x01\n\x10RegionConfigInfo\x12\x11\n\tdomain_id\x18\x01 \x01(\t\x12\x12\n\nproject_id\x18\x02 \x01(\t\x12\x10\n\x08provider\x18\x03 \x01(\t\x12\x1a\n\x12service_account_id\x18\x04 \x01(\t\x12\x41\n\rregion_config\x18\x05 \x03(\x0b\x32*.spaceone.api.identity.v1.RegionConfigData\x12\x12\n\ncreated_at\x18\x06 \x01(\t\"\xb3\x01\n\x19UpdateRegionConfigRequest\x12\x11\n\tdomain_id\x18\x01 \x01(\t\x12\x12\n\nproject_id\x18\x02 \x01(\t\x12\x10\n\x08provider\x18\x03 \x01(\t\x12\x1a\n\x12service_account_id\x18\x04 \x01(\t\x12\x41\n\rregion_config\x18\x05 \x03(\x0b\x32*.spaceone.api.identity.v1.RegionConfigData\"m\n\x16GetRegionConfigRequest\x12\x11\n\tdomain_id\x18\x01 \x01(\t\x12\x12\n\nproject_id\x18\x02 \x01(\t\x12\x10\n\x08provider\x18\x03 \x01(\t\x12\x1a\n\x12service_account_id\x18\x04 \x01(\t2\x8e\x0c\n\x0eServiceAccount\x12\x94\x01\n\x06\x63reate\x12\x35.spaceone.api.identity.v1.CreateServiceAccountRequest\x1a,.spaceone.api.identity.v1.ServiceAccountInfo\"%\x82\xd3\xe4\x93\x02\x1f\"\x1d/identity/v1/service-accounts\x12\xa8\x01\n\x06update\x12\x35.spaceone.api.identity.v1.UpdateServiceAccountRequest\x1a,.spaceone.api.identity.v1.ServiceAccountInfo\"9\x82\xd3\xe4\x93\x02\x33\x1a\x31/identity/v1/service-account/{service_account_id}\x12\xb3\x01\n\x14update_region_config\x12\x33.spaceone.api.identity.v1.UpdateRegionConfigRequest\x1a+.spaceone.api.identity.v1.RegionsConfigInfo\"9\x82\xd3\xe4\x93\x02\x33\x1a\x31/identity/v1/service-account/update-region-config\x12\x8c\x01\n\x06\x64\x65lete\x12/.spaceone.api.identity.v1.ServiceAccountRequest\x1a\x16.google.protobuf.Empty\"9\x82\xd3\xe4\x93\x02\x33*1/identity/v1/service-account/{service_account_id}\x12\xaa\x01\n\x11get_region_config\x12\x30.spaceone.api.identity.v1.GetRegionConfigRequest\x1a+.spaceone.api.identity.v1.RegionsConfigInfo\"6\x82\xd3\xe4\x93\x02\x30\x1a./identity/v1/service-account/get-region-config\x12\xa2\x01\n\x03get\x12\x32.spaceone.api.identity.v1.GetServiceAccountRequest\x1a,.spaceone.api.identity.v1.ServiceAccountInfo\"9\x82\xd3\xe4\x93\x02\x33\x12\x31/identity/v1/service-account/{service_account_id}\x12\xb3\x01\n\x04list\x12-.spaceone.api.identity.v1.ServiceAccountQuery\x1a-.spaceone.api.identity.v1.ServiceAccountsInfo\"M\x82\xd3\xe4\x93\x02G\x12\x1d/identity/v1/service-accountsZ&\"$/identity/v1/service-accounts/search\x12\xec\x01\n\x15list_available_region\x12+.spaceone.api.identity.v1.RegionConfigQuery\x1a+.spaceone.api.identity.v1.RegionsConfigInfo\"y\x82\xd3\xe4\x93\x02s\x12\x33/identity/v1/service-accounts/list-available-regionZ<\":/identity/v1/service-accounts/list-available-region/search\x12~\n\x04stat\x12\x31.spaceone.api.identity.v1.ServiceAccountStatQuery\x1a\x17.google.protobuf.Struct\"*\x82\xd3\xe4\x93\x02$\"\"/identity/v1/service-accounts/statb\x06proto3')



_CREATESERVICEACCOUNTREQUEST = DESCRIPTOR.message_types_by_name['CreateServiceAccountRequest']
_UPDATESERVICEACCOUNTREQUEST = DESCRIPTOR.message_types_by_name['UpdateServiceAccountRequest']
_SERVICEACCOUNTREQUEST = DESCRIPTOR.message_types_by_name['ServiceAccountRequest']
_GETSERVICEACCOUNTREQUEST = DESCRIPTOR.message_types_by_name['GetServiceAccountRequest']
_SERVICEACCOUNTQUERY = DESCRIPTOR.message_types_by_name['ServiceAccountQuery']
_SERVICEACCOUNTINFO = DESCRIPTOR.message_types_by_name['ServiceAccountInfo']
_SERVICEACCOUNTSINFO = DESCRIPTOR.message_types_by_name['ServiceAccountsInfo']
_SERVICEACCOUNTSTATQUERY = DESCRIPTOR.message_types_by_name['ServiceAccountStatQuery']
_REGIONCONFIGQUERY = DESCRIPTOR.message_types_by_name['RegionConfigQuery']
_REGIONCONFIGDATA = DESCRIPTOR.message_types_by_name['RegionConfigData']
_REGIONSCONFIGINFO = DESCRIPTOR.message_types_by_name['RegionsConfigInfo']
_REGIONCONFIGINFO = DESCRIPTOR.message_types_by_name['RegionConfigInfo']
_UPDATEREGIONCONFIGREQUEST = DESCRIPTOR.message_types_by_name['UpdateRegionConfigRequest']
_GETREGIONCONFIGREQUEST = DESCRIPTOR.message_types_by_name['GetRegionConfigRequest']
_REGIONCONFIGDATA_ISAVAILABLE = _REGIONCONFIGDATA.enum_types_by_name['IsAvailable']
CreateServiceAccountRequest = _reflection.GeneratedProtocolMessageType('CreateServiceAccountRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATESERVICEACCOUNTREQUEST,
  '__module__' : 'spaceone.api.identity.v1.service_account_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.identity.v1.CreateServiceAccountRequest)
  })
_sym_db.RegisterMessage(CreateServiceAccountRequest)

UpdateServiceAccountRequest = _reflection.GeneratedProtocolMessageType('UpdateServiceAccountRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATESERVICEACCOUNTREQUEST,
  '__module__' : 'spaceone.api.identity.v1.service_account_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.identity.v1.UpdateServiceAccountRequest)
  })
_sym_db.RegisterMessage(UpdateServiceAccountRequest)

ServiceAccountRequest = _reflection.GeneratedProtocolMessageType('ServiceAccountRequest', (_message.Message,), {
  'DESCRIPTOR' : _SERVICEACCOUNTREQUEST,
  '__module__' : 'spaceone.api.identity.v1.service_account_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.identity.v1.ServiceAccountRequest)
  })
_sym_db.RegisterMessage(ServiceAccountRequest)

GetServiceAccountRequest = _reflection.GeneratedProtocolMessageType('GetServiceAccountRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETSERVICEACCOUNTREQUEST,
  '__module__' : 'spaceone.api.identity.v1.service_account_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.identity.v1.GetServiceAccountRequest)
  })
_sym_db.RegisterMessage(GetServiceAccountRequest)

ServiceAccountQuery = _reflection.GeneratedProtocolMessageType('ServiceAccountQuery', (_message.Message,), {
  'DESCRIPTOR' : _SERVICEACCOUNTQUERY,
  '__module__' : 'spaceone.api.identity.v1.service_account_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.identity.v1.ServiceAccountQuery)
  })
_sym_db.RegisterMessage(ServiceAccountQuery)

ServiceAccountInfo = _reflection.GeneratedProtocolMessageType('ServiceAccountInfo', (_message.Message,), {
  'DESCRIPTOR' : _SERVICEACCOUNTINFO,
  '__module__' : 'spaceone.api.identity.v1.service_account_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.identity.v1.ServiceAccountInfo)
  })
_sym_db.RegisterMessage(ServiceAccountInfo)

ServiceAccountsInfo = _reflection.GeneratedProtocolMessageType('ServiceAccountsInfo', (_message.Message,), {
  'DESCRIPTOR' : _SERVICEACCOUNTSINFO,
  '__module__' : 'spaceone.api.identity.v1.service_account_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.identity.v1.ServiceAccountsInfo)
  })
_sym_db.RegisterMessage(ServiceAccountsInfo)

ServiceAccountStatQuery = _reflection.GeneratedProtocolMessageType('ServiceAccountStatQuery', (_message.Message,), {
  'DESCRIPTOR' : _SERVICEACCOUNTSTATQUERY,
  '__module__' : 'spaceone.api.identity.v1.service_account_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.identity.v1.ServiceAccountStatQuery)
  })
_sym_db.RegisterMessage(ServiceAccountStatQuery)

RegionConfigQuery = _reflection.GeneratedProtocolMessageType('RegionConfigQuery', (_message.Message,), {
  'DESCRIPTOR' : _REGIONCONFIGQUERY,
  '__module__' : 'spaceone.api.identity.v1.service_account_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.identity.v1.RegionConfigQuery)
  })
_sym_db.RegisterMessage(RegionConfigQuery)

RegionConfigData = _reflection.GeneratedProtocolMessageType('RegionConfigData', (_message.Message,), {
  'DESCRIPTOR' : _REGIONCONFIGDATA,
  '__module__' : 'spaceone.api.identity.v1.service_account_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.identity.v1.RegionConfigData)
  })
_sym_db.RegisterMessage(RegionConfigData)

RegionsConfigInfo = _reflection.GeneratedProtocolMessageType('RegionsConfigInfo', (_message.Message,), {
  'DESCRIPTOR' : _REGIONSCONFIGINFO,
  '__module__' : 'spaceone.api.identity.v1.service_account_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.identity.v1.RegionsConfigInfo)
  })
_sym_db.RegisterMessage(RegionsConfigInfo)

RegionConfigInfo = _reflection.GeneratedProtocolMessageType('RegionConfigInfo', (_message.Message,), {
  'DESCRIPTOR' : _REGIONCONFIGINFO,
  '__module__' : 'spaceone.api.identity.v1.service_account_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.identity.v1.RegionConfigInfo)
  })
_sym_db.RegisterMessage(RegionConfigInfo)

UpdateRegionConfigRequest = _reflection.GeneratedProtocolMessageType('UpdateRegionConfigRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEREGIONCONFIGREQUEST,
  '__module__' : 'spaceone.api.identity.v1.service_account_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.identity.v1.UpdateRegionConfigRequest)
  })
_sym_db.RegisterMessage(UpdateRegionConfigRequest)

GetRegionConfigRequest = _reflection.GeneratedProtocolMessageType('GetRegionConfigRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETREGIONCONFIGREQUEST,
  '__module__' : 'spaceone.api.identity.v1.service_account_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.identity.v1.GetRegionConfigRequest)
  })
_sym_db.RegisterMessage(GetRegionConfigRequest)

_SERVICEACCOUNT = DESCRIPTOR.services_by_name['ServiceAccount']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _SERVICEACCOUNT.methods_by_name['create']._options = None
  _SERVICEACCOUNT.methods_by_name['create']._serialized_options = b'\202\323\344\223\002\037\"\035/identity/v1/service-accounts'
  _SERVICEACCOUNT.methods_by_name['update']._options = None
  _SERVICEACCOUNT.methods_by_name['update']._serialized_options = b'\202\323\344\223\0023\0321/identity/v1/service-account/{service_account_id}'
  _SERVICEACCOUNT.methods_by_name['update_region_config']._options = None
  _SERVICEACCOUNT.methods_by_name['update_region_config']._serialized_options = b'\202\323\344\223\0023\0321/identity/v1/service-account/update-region-config'
  _SERVICEACCOUNT.methods_by_name['delete']._options = None
  _SERVICEACCOUNT.methods_by_name['delete']._serialized_options = b'\202\323\344\223\0023*1/identity/v1/service-account/{service_account_id}'
  _SERVICEACCOUNT.methods_by_name['get_region_config']._options = None
  _SERVICEACCOUNT.methods_by_name['get_region_config']._serialized_options = b'\202\323\344\223\0020\032./identity/v1/service-account/get-region-config'
  _SERVICEACCOUNT.methods_by_name['get']._options = None
  _SERVICEACCOUNT.methods_by_name['get']._serialized_options = b'\202\323\344\223\0023\0221/identity/v1/service-account/{service_account_id}'
  _SERVICEACCOUNT.methods_by_name['list']._options = None
  _SERVICEACCOUNT.methods_by_name['list']._serialized_options = b'\202\323\344\223\002G\022\035/identity/v1/service-accountsZ&\"$/identity/v1/service-accounts/search'
  _SERVICEACCOUNT.methods_by_name['list_available_region']._options = None
  _SERVICEACCOUNT.methods_by_name['list_available_region']._serialized_options = b'\202\323\344\223\002s\0223/identity/v1/service-accounts/list-available-regionZ<\":/identity/v1/service-accounts/list-available-region/search'
  _SERVICEACCOUNT.methods_by_name['stat']._options = None
  _SERVICEACCOUNT.methods_by_name['stat']._serialized_options = b'\202\323\344\223\002$\"\"/identity/v1/service-accounts/stat'
  _CREATESERVICEACCOUNTREQUEST._serialized_start=240
  _CREATESERVICEACCOUNTREQUEST._serialized_end=484
  _UPDATESERVICEACCOUNTREQUEST._serialized_start=487
  _UPDATESERVICEACCOUNTREQUEST._serialized_end=752
  _SERVICEACCOUNTREQUEST._serialized_start=754
  _SERVICEACCOUNTREQUEST._serialized_end=824
  _GETSERVICEACCOUNTREQUEST._serialized_start=826
  _GETSERVICEACCOUNTREQUEST._serialized_end=913
  _SERVICEACCOUNTQUERY._serialized_start=916
  _SERVICEACCOUNTQUERY._serialized_end=1161
  _SERVICEACCOUNTINFO._serialized_start=1164
  _SERVICEACCOUNTINFO._serialized_end=1503
  _SERVICEACCOUNTSINFO._serialized_start=1505
  _SERVICEACCOUNTSINFO._serialized_end=1610
  _SERVICEACCOUNTSTATQUERY._serialized_start=1612
  _SERVICEACCOUNTSTATQUERY._serialized_end=1710
  _REGIONCONFIGQUERY._serialized_start=1713
  _REGIONCONFIGQUERY._serialized_end=1861
  _REGIONCONFIGDATA._serialized_start=1864
  _REGIONCONFIGDATA._serialized_end=2027
  _REGIONCONFIGDATA_ISAVAILABLE._serialized_start=1983
  _REGIONCONFIGDATA_ISAVAILABLE._serialized_end=2027
  _REGIONSCONFIGINFO._serialized_start=2029
  _REGIONSCONFIGINFO._serialized_end=2130
  _REGIONCONFIGINFO._serialized_start=2133
  _REGIONCONFIGINFO._serialized_end=2323
  _UPDATEREGIONCONFIGREQUEST._serialized_start=2326
  _UPDATEREGIONCONFIGREQUEST._serialized_end=2505
  _GETREGIONCONFIGREQUEST._serialized_start=2507
  _GETREGIONCONFIGREQUEST._serialized_end=2616
  _SERVICEACCOUNT._serialized_start=2619
  _SERVICEACCOUNT._serialized_end=4169
# @@protoc_insertion_point(module_scope)
