# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: spaceone/api/inventory/v1/resource_setting.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from spaceone.api.core.v1 import query_pb2 as spaceone_dot_api_dot_core_dot_v1_dot_query__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n0spaceone/api/inventory/v1/resource_setting.proto\x12\x19spaceone.api.inventory.v1\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1cgoogle/api/annotations.proto\x1a spaceone/api/core/v1/query.proto\"}\n\x16ResourceSettingRequest\x12\x11\n\tdomain_id\x18\x01 \x01(\t\x12\x10\n\x08provider\x18\x02 \x01(\t\x12\x12\n\nsetting_id\x18\x03 \x01(\t\x12*\n\x05query\x18\x04 \x01(\x0b\x32\x1b.spaceone.api.core.v1.Query\"a\n\tCondition\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x0e\n\x06use_yn\x18\x02 \x01(\t\x12\x0e\n\x06parser\x18\x03 \x01(\t\x12\r\n\x05value\x18\x04 \x01(\t\x12\x10\n\x08operator\x18\x05 \x01(\t\"z\n\x06Unused\x12\x0f\n\x07service\x18\x01 \x01(\t\x12\x16\n\x0esub_title_name\x18\x02 \x01(\t\x12\x0e\n\x06use_yn\x18\x03 \x01(\t\x12\x37\n\tcondition\x18\x04 \x03(\x0b\x32$.spaceone.api.inventory.v1.Condition\"\xde\x02\n\x13ResourceSettingInfo\x12\x12\n\nsetting_id\x18\x01 \x01(\t\x12\x11\n\tdomain_id\x18\x02 \x01(\t\x12\x10\n\x08provider\x18\x03 \x01(\t\x12\x14\n\x0c\x64isplay_type\x18\x04 \x01(\t\x12\x1f\n\x17\x64\x65signed_component_name\x18\x05 \x01(\t\x12\x11\n\ttab_title\x18\x06 \x01(\t\x12\x14\n\x0csetting_type\x18\x07 \x01(\t\x12\x12\n\ncreated_at\x18\x08 \x01(\t\x12\x12\n\nupdated_at\x18\t \x01(\t\x12%\n\x04tags\x18\n \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x31\n\x06unused\x18\x0b \x03(\x0b\x32!.spaceone.api.inventory.v1.Unused\x12,\n\x0brightsizing\x18\x0c \x01(\x0b\x32\x17.google.protobuf.Struct\"h\n\x17ResourceSettingListInfo\x12M\n\x15resource_setting_info\x18\x01 \x03(\x0b\x32..spaceone.api.inventory.v1.ResourceSettingInfo\"d\n\x0bTagListInfo\x12\x11\n\tdomain_id\x18\x01 \x01(\t\x12\x10\n\x08provider\x18\x02 \x01(\t\x12\x30\n\x04tags\x18\x03 \x03(\x0b\x32\".spaceone.api.inventory.v1.TagList\")\n\x07TagList\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x11\n\tvalueList\x18\x02 \x03(\t2\xaf\x07\n\x0fResourceSetting\x12\x9a\x01\n\x04list\x12\x31.spaceone.api.inventory.v1.ResourceSettingRequest\x1a\x32.spaceone.api.inventory.v1.ResourceSettingListInfo\"+\x82\xd3\xe4\x93\x02%\"#/inventory/v1/resource-setting/list\x12\x94\x01\n\x03get\x12\x31.spaceone.api.inventory.v1.ResourceSettingRequest\x1a..spaceone.api.inventory.v1.ResourceSettingInfo\"*\x82\xd3\xe4\x93\x02$\"\"/inventory/v1/resource-setting/get\x12\x97\x01\n\x06\x63reate\x12..spaceone.api.inventory.v1.ResourceSettingInfo\x1a..spaceone.api.inventory.v1.ResourceSettingInfo\"-\x82\xd3\xe4\x93\x02\'\"%/inventory/v1/resource-setting/create\x12\x97\x01\n\x06update\x12..spaceone.api.inventory.v1.ResourceSettingInfo\x1a..spaceone.api.inventory.v1.ResourceSettingInfo\"-\x82\xd3\xe4\x93\x02\'\"%/inventory/v1/resource-setting/update\x12\x9a\x01\n\x06\x64\x65lete\x12\x31.spaceone.api.inventory.v1.ResourceSettingRequest\x1a..spaceone.api.inventory.v1.ResourceSettingInfo\"-\x82\xd3\xe4\x93\x02\'\"%/inventory/v1/resource-setting/delete\x12\x96\x01\n\x08tag_list\x12\x31.spaceone.api.inventory.v1.ResourceSettingRequest\x1a&.spaceone.api.inventory.v1.TagListInfo\"/\x82\xd3\xe4\x93\x02)\"\'/inventory/v1/resource-setting/tag/listb\x06proto3')



_RESOURCESETTINGREQUEST = DESCRIPTOR.message_types_by_name['ResourceSettingRequest']
_CONDITION = DESCRIPTOR.message_types_by_name['Condition']
_UNUSED = DESCRIPTOR.message_types_by_name['Unused']
_RESOURCESETTINGINFO = DESCRIPTOR.message_types_by_name['ResourceSettingInfo']
_RESOURCESETTINGLISTINFO = DESCRIPTOR.message_types_by_name['ResourceSettingListInfo']
_TAGLISTINFO = DESCRIPTOR.message_types_by_name['TagListInfo']
_TAGLIST = DESCRIPTOR.message_types_by_name['TagList']
ResourceSettingRequest = _reflection.GeneratedProtocolMessageType('ResourceSettingRequest', (_message.Message,), {
  'DESCRIPTOR' : _RESOURCESETTINGREQUEST,
  '__module__' : 'spaceone.api.inventory.v1.resource_setting_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.ResourceSettingRequest)
  })
_sym_db.RegisterMessage(ResourceSettingRequest)

Condition = _reflection.GeneratedProtocolMessageType('Condition', (_message.Message,), {
  'DESCRIPTOR' : _CONDITION,
  '__module__' : 'spaceone.api.inventory.v1.resource_setting_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.Condition)
  })
_sym_db.RegisterMessage(Condition)

Unused = _reflection.GeneratedProtocolMessageType('Unused', (_message.Message,), {
  'DESCRIPTOR' : _UNUSED,
  '__module__' : 'spaceone.api.inventory.v1.resource_setting_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.Unused)
  })
_sym_db.RegisterMessage(Unused)

ResourceSettingInfo = _reflection.GeneratedProtocolMessageType('ResourceSettingInfo', (_message.Message,), {
  'DESCRIPTOR' : _RESOURCESETTINGINFO,
  '__module__' : 'spaceone.api.inventory.v1.resource_setting_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.ResourceSettingInfo)
  })
_sym_db.RegisterMessage(ResourceSettingInfo)

ResourceSettingListInfo = _reflection.GeneratedProtocolMessageType('ResourceSettingListInfo', (_message.Message,), {
  'DESCRIPTOR' : _RESOURCESETTINGLISTINFO,
  '__module__' : 'spaceone.api.inventory.v1.resource_setting_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.ResourceSettingListInfo)
  })
_sym_db.RegisterMessage(ResourceSettingListInfo)

TagListInfo = _reflection.GeneratedProtocolMessageType('TagListInfo', (_message.Message,), {
  'DESCRIPTOR' : _TAGLISTINFO,
  '__module__' : 'spaceone.api.inventory.v1.resource_setting_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.TagListInfo)
  })
_sym_db.RegisterMessage(TagListInfo)

TagList = _reflection.GeneratedProtocolMessageType('TagList', (_message.Message,), {
  'DESCRIPTOR' : _TAGLIST,
  '__module__' : 'spaceone.api.inventory.v1.resource_setting_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.TagList)
  })
_sym_db.RegisterMessage(TagList)

_RESOURCESETTING = DESCRIPTOR.services_by_name['ResourceSetting']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _RESOURCESETTING.methods_by_name['list']._options = None
  _RESOURCESETTING.methods_by_name['list']._serialized_options = b'\202\323\344\223\002%\"#/inventory/v1/resource-setting/list'
  _RESOURCESETTING.methods_by_name['get']._options = None
  _RESOURCESETTING.methods_by_name['get']._serialized_options = b'\202\323\344\223\002$\"\"/inventory/v1/resource-setting/get'
  _RESOURCESETTING.methods_by_name['create']._options = None
  _RESOURCESETTING.methods_by_name['create']._serialized_options = b'\202\323\344\223\002\'\"%/inventory/v1/resource-setting/create'
  _RESOURCESETTING.methods_by_name['update']._options = None
  _RESOURCESETTING.methods_by_name['update']._serialized_options = b'\202\323\344\223\002\'\"%/inventory/v1/resource-setting/update'
  _RESOURCESETTING.methods_by_name['delete']._options = None
  _RESOURCESETTING.methods_by_name['delete']._serialized_options = b'\202\323\344\223\002\'\"%/inventory/v1/resource-setting/delete'
  _RESOURCESETTING.methods_by_name['tag_list']._options = None
  _RESOURCESETTING.methods_by_name['tag_list']._serialized_options = b'\202\323\344\223\002)\"\'/inventory/v1/resource-setting/tag/list'
  _RESOURCESETTINGREQUEST._serialized_start=202
  _RESOURCESETTINGREQUEST._serialized_end=327
  _CONDITION._serialized_start=329
  _CONDITION._serialized_end=426
  _UNUSED._serialized_start=428
  _UNUSED._serialized_end=550
  _RESOURCESETTINGINFO._serialized_start=553
  _RESOURCESETTINGINFO._serialized_end=903
  _RESOURCESETTINGLISTINFO._serialized_start=905
  _RESOURCESETTINGLISTINFO._serialized_end=1009
  _TAGLISTINFO._serialized_start=1011
  _TAGLISTINFO._serialized_end=1111
  _TAGLIST._serialized_start=1113
  _TAGLIST._serialized_end=1154
  _RESOURCESETTING._serialized_start=1157
  _RESOURCESETTING._serialized_end=2100
# @@protoc_insertion_point(module_scope)
