# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: spaceone/api/file_manager/v1/file.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from spaceone.api.core.v1 import query_pb2 as spaceone_dot_api_dot_core_dot_v1_dot_query__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\'spaceone/api/file_manager/v1/file.proto\x12\x1cspaceone.api.file_manager.v1\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1cgoogle/api/annotations.proto\x1a spaceone/api/core/v1/query.proto\";\n\rFileReference\x12\x15\n\rresource_type\x18\x01 \x01(\t\x12\x13\n\x0bresource_id\x18\x02 \x01(\t\"\xeb\x01\n\x11\x43reateFileRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12%\n\x04tags\x18\x02 \x01(\x0b\x32\x17.google.protobuf.Struct\x12>\n\treference\x18\x03 \x01(\x0b\x32+.spaceone.api.file_manager.v1.FileReference\x12\x11\n\tdomain_id\x18\x0b \x01(\t\x12\x15\n\rfile_src_type\x18\r \x01(\t\x12\x11\n\tfile_size\x18\x0e \x01(\t\x12\x11\n\tfile_path\x18\x0f \x01(\t\x12\x11\n\tlink_name\x18\x10 \x01(\t\"\xee\x01\n\x11UpdateFileRequest\x12\x0f\n\x07\x66ile_id\x18\x01 \x01(\t\x12%\n\x04tags\x18\x02 \x01(\x0b\x32\x17.google.protobuf.Struct\x12>\n\treference\x18\x03 \x01(\x0b\x32+.spaceone.api.file_manager.v1.FileReference\x12\x11\n\tdomain_id\x18\x0b \x01(\t\x12\x15\n\rfile_src_type\x18\r \x01(\t\x12\x11\n\tfile_size\x18\x0e \x01(\t\x12\x11\n\tfile_path\x18\x0f \x01(\t\x12\x11\n\tlink_name\x18\x10 \x01(\t\"1\n\x0b\x46ileRequest\x12\x0f\n\x07\x66ile_id\x18\x01 \x01(\t\x12\x11\n\tdomain_id\x18\x02 \x01(\t\"B\n\x0eGetFileRequest\x12\x0f\n\x07\x66ile_id\x18\x01 \x01(\t\x12\x11\n\tdomain_id\x18\x02 \x01(\t\x12\x0c\n\x04only\x18\x03 \x03(\t\"\x80\x03\n\tFileQuery\x12*\n\x05query\x18\x01 \x01(\x0b\x32\x1b.spaceone.api.core.v1.Query\x12\x0f\n\x07\x66ile_id\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x36\n\x05state\x18\x04 \x01(\x0e\x32\'.spaceone.api.file_manager.v1.FileState\x12\x36\n\x05scope\x18\x05 \x01(\x0e\x32\'.spaceone.api.file_manager.v1.FileScope\x12\x11\n\tfile_type\x18\x06 \x01(\t\x12\x15\n\rresource_type\x18\x07 \x01(\t\x12\x13\n\x0bresource_id\x18\x08 \x01(\t\x12\x16\n\x0euser_domain_id\x18\x0b \x01(\t\x12\x11\n\tdomain_id\x18\x0c \x01(\t\x12\x15\n\rfile_src_type\x18\r \x01(\t\x12\x11\n\tfile_size\x18\x0e \x01(\t\x12\x11\n\tfile_path\x18\x0f \x01(\t\x12\x11\n\tlink_name\x18\x10 \x01(\t\"\x8e\x04\n\x08\x46ileInfo\x12\x0f\n\x07\x66ile_id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x36\n\x05state\x18\x03 \x01(\x0e\x32\'.spaceone.api.file_manager.v1.FileState\x12\x36\n\x05scope\x18\x04 \x01(\x0e\x32\'.spaceone.api.file_manager.v1.FileScope\x12\x11\n\tfile_type\x18\x05 \x01(\t\x12\x12\n\nupload_url\x18\x06 \x01(\t\x12/\n\x0eupload_options\x18\x07 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x14\n\x0c\x64ownload_url\x18\x08 \x01(\t\x12%\n\x04tags\x18\t \x01(\x0b\x32\x17.google.protobuf.Struct\x12>\n\treference\x18\n \x01(\x0b\x32+.spaceone.api.file_manager.v1.FileReference\x12\x0f\n\x07user_id\x18\x0b \x01(\t\x12\x16\n\x0euser_domain_id\x18\x0c \x01(\t\x12\x11\n\tdomain_id\x18\r \x01(\t\x12\x15\n\rfile_src_type\x18\x0e \x01(\t\x12\x11\n\tfile_size\x18\x0f \x01(\t\x12\x11\n\tfile_path\x18\x10 \x01(\t\x12\x11\n\tlink_name\x18\x11 \x01(\t\x12\x12\n\ncreated_at\x18\x15 \x01(\t\"Y\n\tFilesInfo\x12\x37\n\x07results\x18\x01 \x03(\x0b\x32&.spaceone.api.file_manager.v1.FileInfo\x12\x13\n\x0btotal_count\x18\x02 \x01(\x05\"X\n\rFileStatQuery\x12\x34\n\x05query\x18\x01 \x01(\x0b\x32%.spaceone.api.core.v1.StatisticsQuery\x12\x11\n\tdomain_id\x18\x02 \x01(\t*2\n\tFileState\x12\x0e\n\nSTATE_NONE\x10\x00\x12\x0b\n\x07PENDING\x10\x01\x12\x08\n\x04\x44ONE\x10\x02*3\n\tFileScope\x12\x0e\n\nSCOPE_NONE\x10\x00\x12\n\n\x06PUBLIC\x10\x01\x12\n\n\x06\x44OMAIN\x10\x02\x32\xbd\x07\n\x04\x46ile\x12~\n\x03\x61\x64\x64\x12/.spaceone.api.file_manager.v1.CreateFileRequest\x1a&.spaceone.api.file_manager.v1.FileInfo\"\x1e\x82\xd3\xe4\x93\x02\x18\"\x16/file-manager/v1/files\x12\x8a\x01\n\x06update\x12/.spaceone.api.file_manager.v1.UpdateFileRequest\x1a&.spaceone.api.file_manager.v1.FileInfo\"\'\x82\xd3\xe4\x93\x02!\x1a\x1f/file-manager/v1/file/{file_id}\x12t\n\x06\x64\x65lete\x12).spaceone.api.file_manager.v1.FileRequest\x1a\x16.google.protobuf.Empty\"\'\x82\xd3\xe4\x93\x02!*\x1f/file-manager/v1/file/{file_id}\x12\x9b\x01\n\x10get_download_url\x12).spaceone.api.file_manager.v1.FileRequest\x1a&.spaceone.api.file_manager.v1.FileInfo\"4\x82\xd3\xe4\x93\x02.\x12,/file-manager/v1/file/{file_id}/download-url\x12\x84\x01\n\x03get\x12,.spaceone.api.file_manager.v1.GetFileRequest\x1a&.spaceone.api.file_manager.v1.FileInfo\"\'\x82\xd3\xe4\x93\x02!\x12\x1f/file-manager/v1/file/{file_id}\x12\x99\x01\n\x04list\x12\'.spaceone.api.file_manager.v1.FileQuery\x1a\'.spaceone.api.file_manager.v1.FilesInfo\"?\x82\xd3\xe4\x93\x02\x39\x12\x16/file-manager/v1/filesZ\x1f\"\x1d/file-manager/v1/files/search\x12q\n\x04stat\x12+.spaceone.api.file_manager.v1.FileStatQuery\x1a\x17.google.protobuf.Struct\"#\x82\xd3\xe4\x93\x02\x1d\"\x1b/file-manager/v1/files/statb\x06proto3')

_FILESTATE = DESCRIPTOR.enum_types_by_name['FileState']
FileState = enum_type_wrapper.EnumTypeWrapper(_FILESTATE)
_FILESCOPE = DESCRIPTOR.enum_types_by_name['FileScope']
FileScope = enum_type_wrapper.EnumTypeWrapper(_FILESCOPE)
STATE_NONE = 0
PENDING = 1
DONE = 2
SCOPE_NONE = 0
PUBLIC = 1
DOMAIN = 2


_FILEREFERENCE = DESCRIPTOR.message_types_by_name['FileReference']
_CREATEFILEREQUEST = DESCRIPTOR.message_types_by_name['CreateFileRequest']
_UPDATEFILEREQUEST = DESCRIPTOR.message_types_by_name['UpdateFileRequest']
_FILEREQUEST = DESCRIPTOR.message_types_by_name['FileRequest']
_GETFILEREQUEST = DESCRIPTOR.message_types_by_name['GetFileRequest']
_FILEQUERY = DESCRIPTOR.message_types_by_name['FileQuery']
_FILEINFO = DESCRIPTOR.message_types_by_name['FileInfo']
_FILESINFO = DESCRIPTOR.message_types_by_name['FilesInfo']
_FILESTATQUERY = DESCRIPTOR.message_types_by_name['FileStatQuery']
FileReference = _reflection.GeneratedProtocolMessageType('FileReference', (_message.Message,), {
  'DESCRIPTOR' : _FILEREFERENCE,
  '__module__' : 'spaceone.api.file_manager.v1.file_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.file_manager.v1.FileReference)
  })
_sym_db.RegisterMessage(FileReference)

CreateFileRequest = _reflection.GeneratedProtocolMessageType('CreateFileRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEFILEREQUEST,
  '__module__' : 'spaceone.api.file_manager.v1.file_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.file_manager.v1.CreateFileRequest)
  })
_sym_db.RegisterMessage(CreateFileRequest)

UpdateFileRequest = _reflection.GeneratedProtocolMessageType('UpdateFileRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEFILEREQUEST,
  '__module__' : 'spaceone.api.file_manager.v1.file_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.file_manager.v1.UpdateFileRequest)
  })
_sym_db.RegisterMessage(UpdateFileRequest)

FileRequest = _reflection.GeneratedProtocolMessageType('FileRequest', (_message.Message,), {
  'DESCRIPTOR' : _FILEREQUEST,
  '__module__' : 'spaceone.api.file_manager.v1.file_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.file_manager.v1.FileRequest)
  })
_sym_db.RegisterMessage(FileRequest)

GetFileRequest = _reflection.GeneratedProtocolMessageType('GetFileRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETFILEREQUEST,
  '__module__' : 'spaceone.api.file_manager.v1.file_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.file_manager.v1.GetFileRequest)
  })
_sym_db.RegisterMessage(GetFileRequest)

FileQuery = _reflection.GeneratedProtocolMessageType('FileQuery', (_message.Message,), {
  'DESCRIPTOR' : _FILEQUERY,
  '__module__' : 'spaceone.api.file_manager.v1.file_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.file_manager.v1.FileQuery)
  })
_sym_db.RegisterMessage(FileQuery)

FileInfo = _reflection.GeneratedProtocolMessageType('FileInfo', (_message.Message,), {
  'DESCRIPTOR' : _FILEINFO,
  '__module__' : 'spaceone.api.file_manager.v1.file_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.file_manager.v1.FileInfo)
  })
_sym_db.RegisterMessage(FileInfo)

FilesInfo = _reflection.GeneratedProtocolMessageType('FilesInfo', (_message.Message,), {
  'DESCRIPTOR' : _FILESINFO,
  '__module__' : 'spaceone.api.file_manager.v1.file_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.file_manager.v1.FilesInfo)
  })
_sym_db.RegisterMessage(FilesInfo)

FileStatQuery = _reflection.GeneratedProtocolMessageType('FileStatQuery', (_message.Message,), {
  'DESCRIPTOR' : _FILESTATQUERY,
  '__module__' : 'spaceone.api.file_manager.v1.file_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.file_manager.v1.FileStatQuery)
  })
_sym_db.RegisterMessage(FileStatQuery)

_FILE = DESCRIPTOR.services_by_name['File']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _FILE.methods_by_name['add']._options = None
  _FILE.methods_by_name['add']._serialized_options = b'\202\323\344\223\002\030\"\026/file-manager/v1/files'
  _FILE.methods_by_name['update']._options = None
  _FILE.methods_by_name['update']._serialized_options = b'\202\323\344\223\002!\032\037/file-manager/v1/file/{file_id}'
  _FILE.methods_by_name['delete']._options = None
  _FILE.methods_by_name['delete']._serialized_options = b'\202\323\344\223\002!*\037/file-manager/v1/file/{file_id}'
  _FILE.methods_by_name['get_download_url']._options = None
  _FILE.methods_by_name['get_download_url']._serialized_options = b'\202\323\344\223\002.\022,/file-manager/v1/file/{file_id}/download-url'
  _FILE.methods_by_name['get']._options = None
  _FILE.methods_by_name['get']._serialized_options = b'\202\323\344\223\002!\022\037/file-manager/v1/file/{file_id}'
  _FILE.methods_by_name['list']._options = None
  _FILE.methods_by_name['list']._serialized_options = b'\202\323\344\223\0029\022\026/file-manager/v1/filesZ\037\"\035/file-manager/v1/files/search'
  _FILE.methods_by_name['stat']._options = None
  _FILE.methods_by_name['stat']._serialized_options = b'\202\323\344\223\002\035\"\033/file-manager/v1/files/stat'
  _FILESTATE._serialized_start=1952
  _FILESTATE._serialized_end=2002
  _FILESCOPE._serialized_start=2004
  _FILESCOPE._serialized_end=2055
  _FILEREFERENCE._serialized_start=196
  _FILEREFERENCE._serialized_end=255
  _CREATEFILEREQUEST._serialized_start=258
  _CREATEFILEREQUEST._serialized_end=493
  _UPDATEFILEREQUEST._serialized_start=496
  _UPDATEFILEREQUEST._serialized_end=734
  _FILEREQUEST._serialized_start=736
  _FILEREQUEST._serialized_end=785
  _GETFILEREQUEST._serialized_start=787
  _GETFILEREQUEST._serialized_end=853
  _FILEQUERY._serialized_start=856
  _FILEQUERY._serialized_end=1240
  _FILEINFO._serialized_start=1243
  _FILEINFO._serialized_end=1769
  _FILESINFO._serialized_start=1771
  _FILESINFO._serialized_end=1860
  _FILESTATQUERY._serialized_start=1862
  _FILESTATQUERY._serialized_end=1950
  _FILE._serialized_start=2058
  _FILE._serialized_end=3015
# @@protoc_insertion_point(module_scope)
