# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: spaceone/api/secret/v1/trusted_secret.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from spaceone.api.core.v1 import query_pb2 as spaceone_dot_api_dot_core_dot_v1_dot_query__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n+spaceone/api/secret/v1/trusted_secret.proto\x12\x16spaceone.api.secret.v1\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1cgoogle/api/annotations.proto\x1a spaceone/api/core/v1/query.proto\"\xb7\x01\n\x1a\x43reateTrustedSecretRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12%\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x17.google.protobuf.Struct\x12%\n\x04tags\x18\x03 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x0e\n\x06schema\x18\x04 \x01(\t\x12\x1a\n\x12service_account_id\x18\x05 \x01(\t\x12\x11\n\tdomain_id\x18\x0b \x01(\t\"\x7f\n\x1aUpdateTrustedSecretRequest\x12\x19\n\x11trusted_secret_id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12%\n\x04tags\x18\x03 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x11\n\tdomain_id\x18\x0b \x01(\t\"D\n\x14TrustedSecretRequest\x12\x19\n\x11trusted_secret_id\x18\x01 \x01(\t\x12\x11\n\tdomain_id\x18\x02 \x01(\t\"\x85\x01\n\x1eUpdateTrustedSecretDataRequest\x12\x19\n\x11trusted_secret_id\x18\x01 \x01(\t\x12%\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x0e\n\x06schema\x18\x03 \x01(\t\x12\x11\n\tdomain_id\x18\x0b \x01(\t\"U\n\x17GetTrustedSecretRequest\x12\x19\n\x11trusted_secret_id\x18\x01 \x01(\t\x12\x11\n\tdomain_id\x18\x02 \x01(\t\x12\x0c\n\x04only\x18\x03 \x03(\t\"\xba\x01\n\x12TrustedSecretQuery\x12*\n\x05query\x18\x01 \x01(\x0b\x32\x1b.spaceone.api.core.v1.Query\x12\x19\n\x11trusted_secret_id\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x0e\n\x06schema\x18\x06 \x01(\t\x12\x10\n\x08provider\x18\x07 \x01(\t\x12\x1a\n\x12service_account_id\x18\t \x01(\t\x12\x11\n\tdomain_id\x18\x15 \x01(\t\"\xdc\x01\n\x11TrustedSecretInfo\x12\x19\n\x11trusted_secret_id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12%\n\x04tags\x18\x03 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x0e\n\x06schema\x18\x04 \x01(\t\x12\x10\n\x08provider\x18\x05 \x01(\t\x12\x1a\n\x12service_account_id\x18\x06 \x01(\t\x12\x12\n\nproject_id\x18\x07 \x01(\t\x12\x11\n\tdomain_id\x18\x15 \x01(\t\x12\x12\n\ncreated_at\x18\x16 \x01(\t\"e\n\x12TrustedSecretsInfo\x12:\n\x07results\x18\x01 \x03(\x0b\x32).spaceone.api.secret.v1.TrustedSecretInfo\x12\x13\n\x0btotal_count\x18\x02 \x01(\x05\"a\n\x16TrustedSecretStatQuery\x12\x34\n\x05query\x18\x01 \x01(\x0b\x32%.spaceone.api.core.v1.StatisticsQuery\x12\x11\n\tdomain_id\x18\x02 \x01(\t2\xa1\x08\n\rTrustedSecret\x12\x8b\x01\n\x06\x63reate\x12\x32.spaceone.api.secret.v1.CreateTrustedSecretRequest\x1a).spaceone.api.secret.v1.TrustedSecretInfo\"\"\x82\xd3\xe4\x93\x02\x1c\"\x1a/secret/v1/trusted-secrets\x12\x9e\x01\n\x06update\x12\x32.spaceone.api.secret.v1.UpdateTrustedSecretRequest\x1a).spaceone.api.secret.v1.TrustedSecretInfo\"5\x82\xd3\xe4\x93\x02/\x1a-/secret/v1/trusted-secret/{trusted_secret_id}\x12\x85\x01\n\x06\x64\x65lete\x12,.spaceone.api.secret.v1.TrustedSecretRequest\x1a\x16.google.protobuf.Empty\"5\x82\xd3\xe4\x93\x02/*-/secret/v1/trusted-secret/{trusted_secret_id}\x12\x99\x01\n\x0bupdate_data\x12\x36.spaceone.api.secret.v1.UpdateTrustedSecretDataRequest\x1a\x16.google.protobuf.Empty\":\x82\xd3\xe4\x93\x02\x34\x1a\x32/secret/v1/trusted-secret/{trusted_secret_id}/data\x12\x98\x01\n\x03get\x12/.spaceone.api.secret.v1.GetTrustedSecretRequest\x1a).spaceone.api.secret.v1.TrustedSecretInfo\"5\x82\xd3\xe4\x93\x02/\x12-/secret/v1/trusted-secret/{trusted_secret_id}\x12\xa7\x01\n\x04list\x12*.spaceone.api.secret.v1.TrustedSecretQuery\x1a*.spaceone.api.secret.v1.TrustedSecretsInfo\"G\x82\xd3\xe4\x93\x02\x41\x12\x1a/secret/v1/trusted-secretsZ#\"!/secret/v1/trusted-secrets/search\x12x\n\x04stat\x12..spaceone.api.secret.v1.TrustedSecretStatQuery\x1a\x17.google.protobuf.Struct\"\'\x82\xd3\xe4\x93\x02!\"\x1f/secret/v1/trusted-secrets/statb\x06proto3')



_CREATETRUSTEDSECRETREQUEST = DESCRIPTOR.message_types_by_name['CreateTrustedSecretRequest']
_UPDATETRUSTEDSECRETREQUEST = DESCRIPTOR.message_types_by_name['UpdateTrustedSecretRequest']
_TRUSTEDSECRETREQUEST = DESCRIPTOR.message_types_by_name['TrustedSecretRequest']
_UPDATETRUSTEDSECRETDATAREQUEST = DESCRIPTOR.message_types_by_name['UpdateTrustedSecretDataRequest']
_GETTRUSTEDSECRETREQUEST = DESCRIPTOR.message_types_by_name['GetTrustedSecretRequest']
_TRUSTEDSECRETQUERY = DESCRIPTOR.message_types_by_name['TrustedSecretQuery']
_TRUSTEDSECRETINFO = DESCRIPTOR.message_types_by_name['TrustedSecretInfo']
_TRUSTEDSECRETSINFO = DESCRIPTOR.message_types_by_name['TrustedSecretsInfo']
_TRUSTEDSECRETSTATQUERY = DESCRIPTOR.message_types_by_name['TrustedSecretStatQuery']
CreateTrustedSecretRequest = _reflection.GeneratedProtocolMessageType('CreateTrustedSecretRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATETRUSTEDSECRETREQUEST,
  '__module__' : 'spaceone.api.secret.v1.trusted_secret_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.secret.v1.CreateTrustedSecretRequest)
  })
_sym_db.RegisterMessage(CreateTrustedSecretRequest)

UpdateTrustedSecretRequest = _reflection.GeneratedProtocolMessageType('UpdateTrustedSecretRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATETRUSTEDSECRETREQUEST,
  '__module__' : 'spaceone.api.secret.v1.trusted_secret_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.secret.v1.UpdateTrustedSecretRequest)
  })
_sym_db.RegisterMessage(UpdateTrustedSecretRequest)

TrustedSecretRequest = _reflection.GeneratedProtocolMessageType('TrustedSecretRequest', (_message.Message,), {
  'DESCRIPTOR' : _TRUSTEDSECRETREQUEST,
  '__module__' : 'spaceone.api.secret.v1.trusted_secret_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.secret.v1.TrustedSecretRequest)
  })
_sym_db.RegisterMessage(TrustedSecretRequest)

UpdateTrustedSecretDataRequest = _reflection.GeneratedProtocolMessageType('UpdateTrustedSecretDataRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATETRUSTEDSECRETDATAREQUEST,
  '__module__' : 'spaceone.api.secret.v1.trusted_secret_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.secret.v1.UpdateTrustedSecretDataRequest)
  })
_sym_db.RegisterMessage(UpdateTrustedSecretDataRequest)

GetTrustedSecretRequest = _reflection.GeneratedProtocolMessageType('GetTrustedSecretRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETTRUSTEDSECRETREQUEST,
  '__module__' : 'spaceone.api.secret.v1.trusted_secret_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.secret.v1.GetTrustedSecretRequest)
  })
_sym_db.RegisterMessage(GetTrustedSecretRequest)

TrustedSecretQuery = _reflection.GeneratedProtocolMessageType('TrustedSecretQuery', (_message.Message,), {
  'DESCRIPTOR' : _TRUSTEDSECRETQUERY,
  '__module__' : 'spaceone.api.secret.v1.trusted_secret_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.secret.v1.TrustedSecretQuery)
  })
_sym_db.RegisterMessage(TrustedSecretQuery)

TrustedSecretInfo = _reflection.GeneratedProtocolMessageType('TrustedSecretInfo', (_message.Message,), {
  'DESCRIPTOR' : _TRUSTEDSECRETINFO,
  '__module__' : 'spaceone.api.secret.v1.trusted_secret_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.secret.v1.TrustedSecretInfo)
  })
_sym_db.RegisterMessage(TrustedSecretInfo)

TrustedSecretsInfo = _reflection.GeneratedProtocolMessageType('TrustedSecretsInfo', (_message.Message,), {
  'DESCRIPTOR' : _TRUSTEDSECRETSINFO,
  '__module__' : 'spaceone.api.secret.v1.trusted_secret_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.secret.v1.TrustedSecretsInfo)
  })
_sym_db.RegisterMessage(TrustedSecretsInfo)

TrustedSecretStatQuery = _reflection.GeneratedProtocolMessageType('TrustedSecretStatQuery', (_message.Message,), {
  'DESCRIPTOR' : _TRUSTEDSECRETSTATQUERY,
  '__module__' : 'spaceone.api.secret.v1.trusted_secret_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.secret.v1.TrustedSecretStatQuery)
  })
_sym_db.RegisterMessage(TrustedSecretStatQuery)

_TRUSTEDSECRET = DESCRIPTOR.services_by_name['TrustedSecret']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _TRUSTEDSECRET.methods_by_name['create']._options = None
  _TRUSTEDSECRET.methods_by_name['create']._serialized_options = b'\202\323\344\223\002\034\"\032/secret/v1/trusted-secrets'
  _TRUSTEDSECRET.methods_by_name['update']._options = None
  _TRUSTEDSECRET.methods_by_name['update']._serialized_options = b'\202\323\344\223\002/\032-/secret/v1/trusted-secret/{trusted_secret_id}'
  _TRUSTEDSECRET.methods_by_name['delete']._options = None
  _TRUSTEDSECRET.methods_by_name['delete']._serialized_options = b'\202\323\344\223\002/*-/secret/v1/trusted-secret/{trusted_secret_id}'
  _TRUSTEDSECRET.methods_by_name['update_data']._options = None
  _TRUSTEDSECRET.methods_by_name['update_data']._serialized_options = b'\202\323\344\223\0024\0322/secret/v1/trusted-secret/{trusted_secret_id}/data'
  _TRUSTEDSECRET.methods_by_name['get']._options = None
  _TRUSTEDSECRET.methods_by_name['get']._serialized_options = b'\202\323\344\223\002/\022-/secret/v1/trusted-secret/{trusted_secret_id}'
  _TRUSTEDSECRET.methods_by_name['list']._options = None
  _TRUSTEDSECRET.methods_by_name['list']._serialized_options = b'\202\323\344\223\002A\022\032/secret/v1/trusted-secretsZ#\"!/secret/v1/trusted-secrets/search'
  _TRUSTEDSECRET.methods_by_name['stat']._options = None
  _TRUSTEDSECRET.methods_by_name['stat']._serialized_options = b'\202\323\344\223\002!\"\037/secret/v1/trusted-secrets/stat'
  _CREATETRUSTEDSECRETREQUEST._serialized_start=195
  _CREATETRUSTEDSECRETREQUEST._serialized_end=378
  _UPDATETRUSTEDSECRETREQUEST._serialized_start=380
  _UPDATETRUSTEDSECRETREQUEST._serialized_end=507
  _TRUSTEDSECRETREQUEST._serialized_start=509
  _TRUSTEDSECRETREQUEST._serialized_end=577
  _UPDATETRUSTEDSECRETDATAREQUEST._serialized_start=580
  _UPDATETRUSTEDSECRETDATAREQUEST._serialized_end=713
  _GETTRUSTEDSECRETREQUEST._serialized_start=715
  _GETTRUSTEDSECRETREQUEST._serialized_end=800
  _TRUSTEDSECRETQUERY._serialized_start=803
  _TRUSTEDSECRETQUERY._serialized_end=989
  _TRUSTEDSECRETINFO._serialized_start=992
  _TRUSTEDSECRETINFO._serialized_end=1212
  _TRUSTEDSECRETSINFO._serialized_start=1214
  _TRUSTEDSECRETSINFO._serialized_end=1315
  _TRUSTEDSECRETSTATQUERY._serialized_start=1317
  _TRUSTEDSECRETSTATQUERY._serialized_end=1414
  _TRUSTEDSECRET._serialized_start=1417
  _TRUSTEDSECRET._serialized_end=2474
# @@protoc_insertion_point(module_scope)
