# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: spaceone/api/provisioning/v1/catalog_resource_history.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from spaceone.api.core.v1 import query_pb2 as spaceone_dot_api_dot_core_dot_v1_dot_query__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n;spaceone/api/provisioning/v1/catalog_resource_history.proto\x12\x1cspaceone.api.provisioning.v1\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1cgoogle/api/annotations.proto\x1a spaceone/api/core/v1/query.proto\"\xa5\x03\n\x1b\x43\x61talogResourceHistoryQuery\x12*\n\x05query\x18\x01 \x01(\x0b\x32\x1b.spaceone.api.core.v1.Query\x12\x11\n\tdomain_id\x18\x02 \x01(\t\x12#\n\x1b\x63\x61talog_resource_history_id\x18\x03 \x01(\t\x12\x1a\n\x12\x63\x61talog_history_id\x18\x04 \x01(\t\x12\x1b\n\x13\x63\x61talog_resource_id\x18\x05 \x01(\t\x12\x15\n\rresource_name\x18\x06 \x01(\t\x12P\n\x06\x61\x63tion\x18\x07 \x01(\x0e\x32@.spaceone.api.provisioning.v1.CatalogResourceHistoryQuery.Action\x12\x12\n\ncreated_at\x18\x08 \x01(\t\x12\x0c\n\x04type\x18\t \x01(\t\x12\x12\n\ncatalog_id\x18\n \x01(\t\x12\x12\n\ncreated_by\x18\x0b \x01(\t\"6\n\x06\x41\x63tion\x12\x08\n\x04NONE\x10\x00\x12\n\n\x06\x43REATE\x10\x01\x12\n\n\x06UPDATE\x10\x02\x12\n\n\x06\x44\x45LETE\x10\x03\"\xb5\x03\n\x1a\x43\x61talogResourceHistoryInfo\x12\x11\n\tdomain_id\x18\x01 \x01(\t\x12#\n\x1b\x63\x61talog_resource_history_id\x18\x02 \x01(\t\x12\x1a\n\x12\x63\x61talog_history_id\x18\x03 \x01(\t\x12\x1b\n\x13\x63\x61talog_resource_id\x18\x04 \x01(\t\x12\x15\n\rresource_name\x18\x05 \x01(\t\x12O\n\x06\x61\x63tion\x18\x06 \x01(\x0e\x32?.spaceone.api.provisioning.v1.CatalogResourceHistoryInfo.Action\x12(\n\x04\x64iff\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.ListValue\x12\x12\n\ndiff_count\x18\x08 \x01(\x05\x12\x12\n\ncreated_at\x18\t \x01(\t\x12\x0c\n\x04type\x18\n \x01(\t\x12\x12\n\ncatalog_id\x18\x0b \x01(\t\x12\x12\n\ncreated_by\x18\x0c \x01(\t\"6\n\x06\x41\x63tion\x12\x08\n\x04NONE\x10\x00\x12\n\n\x06\x43REATE\x10\x01\x12\n\n\x06UPDATE\x10\x02\x12\n\n\x06\x44\x45LETE\x10\x03\"~\n\x1c\x43\x61talogResourceHistoriesInfo\x12I\n\x07results\x18\x01 \x03(\x0b\x32\x38.spaceone.api.provisioning.v1.CatalogResourceHistoryInfo\x12\x13\n\x0btotal_count\x18\x02 \x01(\x05\"\x9b\x01\n\x1f\x43\x61talogResourceHistoryStatQuery\x12\x34\n\x05query\x18\x01 \x01(\x0b\x32%.spaceone.api.core.v1.StatisticsQuery\x12\x11\n\tdomain_id\x18\x02 \x01(\t\x12\x1b\n\x13\x63\x61talog_resource_id\x18\x03 \x01(\t\x12\x12\n\ncatalog_id\x18\x04 \x01(\t2\xa9\x05\n\x16\x43\x61talogResourceHistory\x12\x96\x02\n\x1eget_catalog_resource_histories\x12\x39.spaceone.api.provisioning.v1.CatalogResourceHistoryQuery\x1a:.spaceone.api.provisioning.v1.CatalogResourceHistoriesInfo\"}\x82\xd3\xe4\x93\x02w\x12\x41/provisioning/v1/catalog-resource/{catalog_resource_id}/historiesZ2\"0/provisioning/v1/catalog-resource-history/search\x12\xdc\x01\n\x1cget_catalog_resource_history\x12\x39.spaceone.api.provisioning.v1.CatalogResourceHistoryQuery\x1a\x38.spaceone.api.provisioning.v1.CatalogResourceHistoryInfo\"G\x82\xd3\xe4\x93\x02\x41\"?/provisioning/v1/catalog-resource/{catalog_resource_id}/history\x12\x96\x01\n\x04stat\x12=.spaceone.api.provisioning.v1.CatalogResourceHistoryStatQuery\x1a\x17.google.protobuf.Struct\"6\x82\xd3\xe4\x93\x02\x30\"./provisioning/v1/catalog-resource-history/statb\x06proto3')



_CATALOGRESOURCEHISTORYQUERY = DESCRIPTOR.message_types_by_name['CatalogResourceHistoryQuery']
_CATALOGRESOURCEHISTORYINFO = DESCRIPTOR.message_types_by_name['CatalogResourceHistoryInfo']
_CATALOGRESOURCEHISTORIESINFO = DESCRIPTOR.message_types_by_name['CatalogResourceHistoriesInfo']
_CATALOGRESOURCEHISTORYSTATQUERY = DESCRIPTOR.message_types_by_name['CatalogResourceHistoryStatQuery']
_CATALOGRESOURCEHISTORYQUERY_ACTION = _CATALOGRESOURCEHISTORYQUERY.enum_types_by_name['Action']
_CATALOGRESOURCEHISTORYINFO_ACTION = _CATALOGRESOURCEHISTORYINFO.enum_types_by_name['Action']
CatalogResourceHistoryQuery = _reflection.GeneratedProtocolMessageType('CatalogResourceHistoryQuery', (_message.Message,), {
  'DESCRIPTOR' : _CATALOGRESOURCEHISTORYQUERY,
  '__module__' : 'spaceone.api.provisioning.v1.catalog_resource_history_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.provisioning.v1.CatalogResourceHistoryQuery)
  })
_sym_db.RegisterMessage(CatalogResourceHistoryQuery)

CatalogResourceHistoryInfo = _reflection.GeneratedProtocolMessageType('CatalogResourceHistoryInfo', (_message.Message,), {
  'DESCRIPTOR' : _CATALOGRESOURCEHISTORYINFO,
  '__module__' : 'spaceone.api.provisioning.v1.catalog_resource_history_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.provisioning.v1.CatalogResourceHistoryInfo)
  })
_sym_db.RegisterMessage(CatalogResourceHistoryInfo)

CatalogResourceHistoriesInfo = _reflection.GeneratedProtocolMessageType('CatalogResourceHistoriesInfo', (_message.Message,), {
  'DESCRIPTOR' : _CATALOGRESOURCEHISTORIESINFO,
  '__module__' : 'spaceone.api.provisioning.v1.catalog_resource_history_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.provisioning.v1.CatalogResourceHistoriesInfo)
  })
_sym_db.RegisterMessage(CatalogResourceHistoriesInfo)

CatalogResourceHistoryStatQuery = _reflection.GeneratedProtocolMessageType('CatalogResourceHistoryStatQuery', (_message.Message,), {
  'DESCRIPTOR' : _CATALOGRESOURCEHISTORYSTATQUERY,
  '__module__' : 'spaceone.api.provisioning.v1.catalog_resource_history_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.provisioning.v1.CatalogResourceHistoryStatQuery)
  })
_sym_db.RegisterMessage(CatalogResourceHistoryStatQuery)

_CATALOGRESOURCEHISTORY = DESCRIPTOR.services_by_name['CatalogResourceHistory']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _CATALOGRESOURCEHISTORY.methods_by_name['get_catalog_resource_histories']._options = None
  _CATALOGRESOURCEHISTORY.methods_by_name['get_catalog_resource_histories']._serialized_options = b'\202\323\344\223\002w\022A/provisioning/v1/catalog-resource/{catalog_resource_id}/historiesZ2\"0/provisioning/v1/catalog-resource-history/search'
  _CATALOGRESOURCEHISTORY.methods_by_name['get_catalog_resource_history']._options = None
  _CATALOGRESOURCEHISTORY.methods_by_name['get_catalog_resource_history']._serialized_options = b'\202\323\344\223\002A\"?/provisioning/v1/catalog-resource/{catalog_resource_id}/history'
  _CATALOGRESOURCEHISTORY.methods_by_name['stat']._options = None
  _CATALOGRESOURCEHISTORY.methods_by_name['stat']._serialized_options = b'\202\323\344\223\0020\"./provisioning/v1/catalog-resource-history/stat'
  _CATALOGRESOURCEHISTORYQUERY._serialized_start=188
  _CATALOGRESOURCEHISTORYQUERY._serialized_end=609
  _CATALOGRESOURCEHISTORYQUERY_ACTION._serialized_start=555
  _CATALOGRESOURCEHISTORYQUERY_ACTION._serialized_end=609
  _CATALOGRESOURCEHISTORYINFO._serialized_start=612
  _CATALOGRESOURCEHISTORYINFO._serialized_end=1049
  _CATALOGRESOURCEHISTORYINFO_ACTION._serialized_start=555
  _CATALOGRESOURCEHISTORYINFO_ACTION._serialized_end=609
  _CATALOGRESOURCEHISTORIESINFO._serialized_start=1051
  _CATALOGRESOURCEHISTORIESINFO._serialized_end=1177
  _CATALOGRESOURCEHISTORYSTATQUERY._serialized_start=1180
  _CATALOGRESOURCEHISTORYSTATQUERY._serialized_end=1335
  _CATALOGRESOURCEHISTORY._serialized_start=1338
  _CATALOGRESOURCEHISTORY._serialized_end=2019
# @@protoc_insertion_point(module_scope)
