# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: spaceone/api/cost_analysis/v1/exchange_rate.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n1spaceone/api/cost_analysis/v1/exchange_rate.proto\x12\x1dspaceone.api.cost_analysis.v1\x1a\x1cgoogle/api/annotations.proto\"K\n\x16SetExchangeRateRequest\x12\x10\n\x08\x63urrency\x18\x01 \x01(\t\x12\x0c\n\x04rate\x18\x02 \x01(\x02\x12\x11\n\tdomain_id\x18\x0c \x01(\t\":\n\x13\x45xchangeRateRequest\x12\x10\n\x08\x63urrency\x18\x01 \x01(\t\x12\x11\n\tdomain_id\x18\x02 \x01(\t\"&\n\x11\x45xchangeRateQuery\x12\x11\n\tdomain_id\x18\x0b \x01(\t\"\xcd\x01\n\x10\x45xchangeRateInfo\x12\x10\n\x08\x63urrency\x18\x01 \x01(\t\x12\x0c\n\x04rate\x18\x02 \x01(\x02\x12\x44\n\x05state\x18\x03 \x01(\x0e\x32\x35.spaceone.api.cost_analysis.v1.ExchangeRateInfo.State\x12\x12\n\nis_default\x18\x04 \x01(\x08\x12\x11\n\tdomain_id\x18\x0b \x01(\t\",\n\x05State\x12\x08\n\x04NONE\x10\x00\x12\x0b\n\x07\x45NABLED\x10\x01\x12\x0c\n\x08\x44ISABLED\x10\x02\"j\n\x11\x45xchangeRatesInfo\x12@\n\x07results\x18\x01 \x03(\x0b\x32/.spaceone.api.cost_analysis.v1.ExchangeRateInfo\x12\x13\n\x0btotal_count\x18\x02 \x01(\x05\x32\x9a\x08\n\x0c\x45xchangeRate\x12\xa5\x01\n\x03set\x12\x35.spaceone.api.cost_analysis.v1.SetExchangeRateRequest\x1a/.spaceone.api.cost_analysis.v1.ExchangeRateInfo\"6\x82\xd3\xe4\x93\x02\x30\"./cost-analysis/v1/exchange-rate/{currency}/set\x12\xa6\x01\n\x05reset\x12\x32.spaceone.api.cost_analysis.v1.ExchangeRateRequest\x1a/.spaceone.api.cost_analysis.v1.ExchangeRateInfo\"8\x82\xd3\xe4\x93\x02\x32\"0/cost-analysis/v1/exchange-rate/{currency}/reset\x12\xa8\x01\n\x06\x65nable\x12\x32.spaceone.api.cost_analysis.v1.ExchangeRateRequest\x1a/.spaceone.api.cost_analysis.v1.ExchangeRateInfo\"9\x82\xd3\xe4\x93\x02\x33\"1/cost-analysis/v1/exchange-rate/{currency}/enable\x12\xaa\x01\n\x07\x64isable\x12\x32.spaceone.api.cost_analysis.v1.ExchangeRateRequest\x1a/.spaceone.api.cost_analysis.v1.ExchangeRateInfo\":\x82\xd3\xe4\x93\x02\x34\"2/cost-analysis/v1/exchange-rate/{currency}/disable\x12\x9e\x01\n\x03get\x12\x32.spaceone.api.cost_analysis.v1.ExchangeRateRequest\x1a/.spaceone.api.cost_analysis.v1.ExchangeRateInfo\"2\x82\xd3\xe4\x93\x02,\x12*/cost-analysis/v1/exchange-rate/{currency}\x12\xbf\x01\n\x04list\x12\x30.spaceone.api.cost_analysis.v1.ExchangeRateQuery\x1a\x30.spaceone.api.cost_analysis.v1.ExchangeRatesInfo\"S\x82\xd3\xe4\x93\x02M\x12 /cost-analysis/v1/exchange-ratesZ)\"\'/cost-analysis/v1/exchange-rates/searchb\x06proto3')



_SETEXCHANGERATEREQUEST = DESCRIPTOR.message_types_by_name['SetExchangeRateRequest']
_EXCHANGERATEREQUEST = DESCRIPTOR.message_types_by_name['ExchangeRateRequest']
_EXCHANGERATEQUERY = DESCRIPTOR.message_types_by_name['ExchangeRateQuery']
_EXCHANGERATEINFO = DESCRIPTOR.message_types_by_name['ExchangeRateInfo']
_EXCHANGERATESINFO = DESCRIPTOR.message_types_by_name['ExchangeRatesInfo']
_EXCHANGERATEINFO_STATE = _EXCHANGERATEINFO.enum_types_by_name['State']
SetExchangeRateRequest = _reflection.GeneratedProtocolMessageType('SetExchangeRateRequest', (_message.Message,), {
  'DESCRIPTOR' : _SETEXCHANGERATEREQUEST,
  '__module__' : 'spaceone.api.cost_analysis.v1.exchange_rate_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.cost_analysis.v1.SetExchangeRateRequest)
  })
_sym_db.RegisterMessage(SetExchangeRateRequest)

ExchangeRateRequest = _reflection.GeneratedProtocolMessageType('ExchangeRateRequest', (_message.Message,), {
  'DESCRIPTOR' : _EXCHANGERATEREQUEST,
  '__module__' : 'spaceone.api.cost_analysis.v1.exchange_rate_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.cost_analysis.v1.ExchangeRateRequest)
  })
_sym_db.RegisterMessage(ExchangeRateRequest)

ExchangeRateQuery = _reflection.GeneratedProtocolMessageType('ExchangeRateQuery', (_message.Message,), {
  'DESCRIPTOR' : _EXCHANGERATEQUERY,
  '__module__' : 'spaceone.api.cost_analysis.v1.exchange_rate_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.cost_analysis.v1.ExchangeRateQuery)
  })
_sym_db.RegisterMessage(ExchangeRateQuery)

ExchangeRateInfo = _reflection.GeneratedProtocolMessageType('ExchangeRateInfo', (_message.Message,), {
  'DESCRIPTOR' : _EXCHANGERATEINFO,
  '__module__' : 'spaceone.api.cost_analysis.v1.exchange_rate_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.cost_analysis.v1.ExchangeRateInfo)
  })
_sym_db.RegisterMessage(ExchangeRateInfo)

ExchangeRatesInfo = _reflection.GeneratedProtocolMessageType('ExchangeRatesInfo', (_message.Message,), {
  'DESCRIPTOR' : _EXCHANGERATESINFO,
  '__module__' : 'spaceone.api.cost_analysis.v1.exchange_rate_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.cost_analysis.v1.ExchangeRatesInfo)
  })
_sym_db.RegisterMessage(ExchangeRatesInfo)

_EXCHANGERATE = DESCRIPTOR.services_by_name['ExchangeRate']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _EXCHANGERATE.methods_by_name['set']._options = None
  _EXCHANGERATE.methods_by_name['set']._serialized_options = b'\202\323\344\223\0020\"./cost-analysis/v1/exchange-rate/{currency}/set'
  _EXCHANGERATE.methods_by_name['reset']._options = None
  _EXCHANGERATE.methods_by_name['reset']._serialized_options = b'\202\323\344\223\0022\"0/cost-analysis/v1/exchange-rate/{currency}/reset'
  _EXCHANGERATE.methods_by_name['enable']._options = None
  _EXCHANGERATE.methods_by_name['enable']._serialized_options = b'\202\323\344\223\0023\"1/cost-analysis/v1/exchange-rate/{currency}/enable'
  _EXCHANGERATE.methods_by_name['disable']._options = None
  _EXCHANGERATE.methods_by_name['disable']._serialized_options = b'\202\323\344\223\0024\"2/cost-analysis/v1/exchange-rate/{currency}/disable'
  _EXCHANGERATE.methods_by_name['get']._options = None
  _EXCHANGERATE.methods_by_name['get']._serialized_options = b'\202\323\344\223\002,\022*/cost-analysis/v1/exchange-rate/{currency}'
  _EXCHANGERATE.methods_by_name['list']._options = None
  _EXCHANGERATE.methods_by_name['list']._serialized_options = b'\202\323\344\223\002M\022 /cost-analysis/v1/exchange-ratesZ)\"\'/cost-analysis/v1/exchange-rates/search'
  _SETEXCHANGERATEREQUEST._serialized_start=114
  _SETEXCHANGERATEREQUEST._serialized_end=189
  _EXCHANGERATEREQUEST._serialized_start=191
  _EXCHANGERATEREQUEST._serialized_end=249
  _EXCHANGERATEQUERY._serialized_start=251
  _EXCHANGERATEQUERY._serialized_end=289
  _EXCHANGERATEINFO._serialized_start=292
  _EXCHANGERATEINFO._serialized_end=497
  _EXCHANGERATEINFO_STATE._serialized_start=453
  _EXCHANGERATEINFO_STATE._serialized_end=497
  _EXCHANGERATESINFO._serialized_start=499
  _EXCHANGERATESINFO._serialized_end=605
  _EXCHANGERATE._serialized_start=608
  _EXCHANGERATE._serialized_end=1658
# @@protoc_insertion_point(module_scope)
