# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: spaceone/api/monitoring/v1/note.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from spaceone.api.core.v1 import query_pb2 as spaceone_dot_api_dot_core_dot_v1_dot_query__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%spaceone/api/monitoring/v1/note.proto\x12\x1aspaceone.api.monitoring.v1\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1cgoogle/api/annotations.proto\x1a spaceone/api/core/v1/query.proto\"F\n\x11\x43reateNoteRequest\x12\x10\n\x08\x61lert_id\x18\x01 \x01(\t\x12\x0c\n\x04note\x18\x02 \x01(\t\x12\x11\n\tdomain_id\x18\x0b \x01(\t\"E\n\x11UpdateNoteRequest\x12\x0f\n\x07note_id\x18\x01 \x01(\t\x12\x0c\n\x04note\x18\x02 \x01(\t\x12\x11\n\tdomain_id\x18\x0b \x01(\t\"1\n\x0bNoteRequest\x12\x0f\n\x07note_id\x18\x01 \x01(\t\x12\x11\n\tdomain_id\x18\x02 \x01(\t\"B\n\x0eGetNoteRequest\x12\x0f\n\x07note_id\x18\x01 \x01(\t\x12\x11\n\tdomain_id\x18\x02 \x01(\t\x12\x0c\n\x04only\x18\x03 \x03(\t\"\x95\x01\n\tNoteQuery\x12*\n\x05query\x18\x01 \x01(\x0b\x32\x1b.spaceone.api.core.v1.Query\x12\x0f\n\x07note_id\x18\x02 \x01(\t\x12\x10\n\x08\x61lert_id\x18\x03 \x01(\t\x12\x12\n\ncreated_by\x18\x04 \x01(\t\x12\x12\n\nproject_id\x18\x05 \x01(\t\x12\x11\n\tdomain_id\x18\x06 \x01(\t\"\x8a\x01\n\x08NoteInfo\x12\x0f\n\x07note_id\x18\x01 \x01(\t\x12\x10\n\x08\x61lert_id\x18\x02 \x01(\t\x12\x0c\n\x04note\x18\x03 \x01(\t\x12\x12\n\ncreated_by\x18\x0b \x01(\t\x12\x12\n\nproject_id\x18\x0c \x01(\t\x12\x11\n\tdomain_id\x18\r \x01(\t\x12\x12\n\ncreated_at\x18\x15 \x01(\t\"W\n\tNotesInfo\x12\x35\n\x07results\x18\x01 \x03(\x0b\x32$.spaceone.api.monitoring.v1.NoteInfo\x12\x13\n\x0btotal_count\x18\x02 \x01(\x05\"X\n\rNoteStatQuery\x12\x34\n\x05query\x18\x01 \x01(\x0b\x32%.spaceone.api.core.v1.StatisticsQuery\x12\x11\n\tdomain_id\x18\x02 \x01(\t2\xff\x05\n\x04Note\x12{\n\x06\x63reate\x12-.spaceone.api.monitoring.v1.CreateNoteRequest\x1a$.spaceone.api.monitoring.v1.NoteInfo\"\x1c\x82\xd3\xe4\x93\x02\x16\"\x14/monitoring/v1/notes\x12\x84\x01\n\x06update\x12-.spaceone.api.monitoring.v1.UpdateNoteRequest\x1a$.spaceone.api.monitoring.v1.NoteInfo\"%\x82\xd3\xe4\x93\x02\x1f\x1a\x1d/monitoring/v1/note/{note_id}\x12p\n\x06\x64\x65lete\x12\'.spaceone.api.monitoring.v1.NoteRequest\x1a\x16.google.protobuf.Empty\"%\x82\xd3\xe4\x93\x02\x1f*\x1d/monitoring/v1/note/{note_id}\x12~\n\x03get\x12*.spaceone.api.monitoring.v1.GetNoteRequest\x1a$.spaceone.api.monitoring.v1.NoteInfo\"%\x82\xd3\xe4\x93\x02\x1f\x12\x1d/monitoring/v1/note/{note_id}\x12\x91\x01\n\x04list\x12%.spaceone.api.monitoring.v1.NoteQuery\x1a%.spaceone.api.monitoring.v1.NotesInfo\";\x82\xd3\xe4\x93\x02\x35\x12\x14/monitoring/v1/notesZ\x1d\"\x1b/monitoring/v1/notes/search\x12m\n\x04stat\x12).spaceone.api.monitoring.v1.NoteStatQuery\x1a\x17.google.protobuf.Struct\"!\x82\xd3\xe4\x93\x02\x1b\"\x19/monitoring/v1/notes/statb\x06proto3')



_CREATENOTEREQUEST = DESCRIPTOR.message_types_by_name['CreateNoteRequest']
_UPDATENOTEREQUEST = DESCRIPTOR.message_types_by_name['UpdateNoteRequest']
_NOTEREQUEST = DESCRIPTOR.message_types_by_name['NoteRequest']
_GETNOTEREQUEST = DESCRIPTOR.message_types_by_name['GetNoteRequest']
_NOTEQUERY = DESCRIPTOR.message_types_by_name['NoteQuery']
_NOTEINFO = DESCRIPTOR.message_types_by_name['NoteInfo']
_NOTESINFO = DESCRIPTOR.message_types_by_name['NotesInfo']
_NOTESTATQUERY = DESCRIPTOR.message_types_by_name['NoteStatQuery']
CreateNoteRequest = _reflection.GeneratedProtocolMessageType('CreateNoteRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATENOTEREQUEST,
  '__module__' : 'spaceone.api.monitoring.v1.note_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.monitoring.v1.CreateNoteRequest)
  })
_sym_db.RegisterMessage(CreateNoteRequest)

UpdateNoteRequest = _reflection.GeneratedProtocolMessageType('UpdateNoteRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATENOTEREQUEST,
  '__module__' : 'spaceone.api.monitoring.v1.note_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.monitoring.v1.UpdateNoteRequest)
  })
_sym_db.RegisterMessage(UpdateNoteRequest)

NoteRequest = _reflection.GeneratedProtocolMessageType('NoteRequest', (_message.Message,), {
  'DESCRIPTOR' : _NOTEREQUEST,
  '__module__' : 'spaceone.api.monitoring.v1.note_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.monitoring.v1.NoteRequest)
  })
_sym_db.RegisterMessage(NoteRequest)

GetNoteRequest = _reflection.GeneratedProtocolMessageType('GetNoteRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETNOTEREQUEST,
  '__module__' : 'spaceone.api.monitoring.v1.note_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.monitoring.v1.GetNoteRequest)
  })
_sym_db.RegisterMessage(GetNoteRequest)

NoteQuery = _reflection.GeneratedProtocolMessageType('NoteQuery', (_message.Message,), {
  'DESCRIPTOR' : _NOTEQUERY,
  '__module__' : 'spaceone.api.monitoring.v1.note_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.monitoring.v1.NoteQuery)
  })
_sym_db.RegisterMessage(NoteQuery)

NoteInfo = _reflection.GeneratedProtocolMessageType('NoteInfo', (_message.Message,), {
  'DESCRIPTOR' : _NOTEINFO,
  '__module__' : 'spaceone.api.monitoring.v1.note_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.monitoring.v1.NoteInfo)
  })
_sym_db.RegisterMessage(NoteInfo)

NotesInfo = _reflection.GeneratedProtocolMessageType('NotesInfo', (_message.Message,), {
  'DESCRIPTOR' : _NOTESINFO,
  '__module__' : 'spaceone.api.monitoring.v1.note_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.monitoring.v1.NotesInfo)
  })
_sym_db.RegisterMessage(NotesInfo)

NoteStatQuery = _reflection.GeneratedProtocolMessageType('NoteStatQuery', (_message.Message,), {
  'DESCRIPTOR' : _NOTESTATQUERY,
  '__module__' : 'spaceone.api.monitoring.v1.note_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.monitoring.v1.NoteStatQuery)
  })
_sym_db.RegisterMessage(NoteStatQuery)

_NOTE = DESCRIPTOR.services_by_name['Note']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _NOTE.methods_by_name['create']._options = None
  _NOTE.methods_by_name['create']._serialized_options = b'\202\323\344\223\002\026\"\024/monitoring/v1/notes'
  _NOTE.methods_by_name['update']._options = None
  _NOTE.methods_by_name['update']._serialized_options = b'\202\323\344\223\002\037\032\035/monitoring/v1/note/{note_id}'
  _NOTE.methods_by_name['delete']._options = None
  _NOTE.methods_by_name['delete']._serialized_options = b'\202\323\344\223\002\037*\035/monitoring/v1/note/{note_id}'
  _NOTE.methods_by_name['get']._options = None
  _NOTE.methods_by_name['get']._serialized_options = b'\202\323\344\223\002\037\022\035/monitoring/v1/note/{note_id}'
  _NOTE.methods_by_name['list']._options = None
  _NOTE.methods_by_name['list']._serialized_options = b'\202\323\344\223\0025\022\024/monitoring/v1/notesZ\035\"\033/monitoring/v1/notes/search'
  _NOTE.methods_by_name['stat']._options = None
  _NOTE.methods_by_name['stat']._serialized_options = b'\202\323\344\223\002\033\"\031/monitoring/v1/notes/stat'
  _CREATENOTEREQUEST._serialized_start=192
  _CREATENOTEREQUEST._serialized_end=262
  _UPDATENOTEREQUEST._serialized_start=264
  _UPDATENOTEREQUEST._serialized_end=333
  _NOTEREQUEST._serialized_start=335
  _NOTEREQUEST._serialized_end=384
  _GETNOTEREQUEST._serialized_start=386
  _GETNOTEREQUEST._serialized_end=452
  _NOTEQUERY._serialized_start=455
  _NOTEQUERY._serialized_end=604
  _NOTEINFO._serialized_start=607
  _NOTEINFO._serialized_end=745
  _NOTESINFO._serialized_start=747
  _NOTESINFO._serialized_end=834
  _NOTESTATQUERY._serialized_start=836
  _NOTESTATQUERY._serialized_end=924
  _NOTE._serialized_start=927
  _NOTE._serialized_end=1694
# @@protoc_insertion_point(module_scope)
