# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: spaceone/api/provisioning/v1/resource_tag.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from spaceone.api.core.v1 import query_pb2 as spaceone_dot_api_dot_core_dot_v1_dot_query__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n/spaceone/api/provisioning/v1/resource_tag.proto\x12\x1cspaceone.api.provisioning.v1\x1a\x1cgoogle/api/annotations.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a spaceone/api/core/v1/query.proto\"Q\n\x10ResourceTagQuery\x12*\n\x05query\x18\x01 \x01(\x0b\x32\x1b.spaceone.api.core.v1.Query\x12\x11\n\tdomain_id\x18\x02 \x01(\t\"\xa1\x01\n\x18\x43reateResourceTagRequest\x12\x11\n\tdomain_id\x18\x01 \x01(\t\x12\x18\n\x10resource_tag_key\x18\x02 \x01(\t\x12\x1a\n\x12resource_tag_value\x18\x03 \x03(\t\x12\x15\n\rresource_type\x18\x04 \x03(\t\x12\x10\n\x08required\x18\x05 \x01(\x08\x12\x13\n\x0b\x64\x65scription\x18\x06 \x01(\t\"\xba\x01\n\x18UpdateResourceTagRequest\x12\x11\n\tdomain_id\x18\x01 \x01(\t\x12\x17\n\x0fresource_tag_id\x18\x02 \x01(\t\x12\x18\n\x10resource_tag_key\x18\x03 \x01(\t\x12\x1a\n\x12resource_tag_value\x18\x04 \x03(\t\x12\x15\n\rresource_type\x18\x05 \x03(\t\x12\x10\n\x08required\x18\x06 \x01(\x08\x12\x13\n\x0b\x64\x65scription\x18\x07 \x01(\t\"l\n\x12ResourceTagRequest\x12\x11\n\tdomain_id\x18\x01 \x01(\t\x12\x17\n\x0fresource_tag_id\x18\x02 \x01(\t\x12\x18\n\x10resource_tag_key\x18\x03 \x01(\t\x12\x10\n\x08required\x18\x04 \x01(\x08\"_\n\x14ResourceTagStatQuery\x12\x34\n\x05query\x18\x01 \x01(\x0b\x32%.spaceone.api.core.v1.StatisticsQuery\x12\x11\n\tdomain_id\x18\x02 \x01(\t\"\xb1\x01\n\x0fResourceTagInfo\x12\x11\n\tdomain_id\x18\x01 \x01(\t\x12\x17\n\x0fresource_tag_id\x18\x02 \x01(\t\x12\x18\n\x10resource_tag_key\x18\x03 \x01(\t\x12\x1a\n\x12resource_tag_value\x18\x04 \x03(\t\x12\x15\n\rresource_type\x18\x05 \x03(\t\x12\x10\n\x08required\x18\x06 \x01(\x08\x12\x13\n\x0b\x64\x65scription\x18\x07 \x01(\t\"g\n\x10ResourceTagsInfo\x12>\n\x07results\x18\x01 \x03(\x0b\x32-.spaceone.api.provisioning.v1.ResourceTagInfo\x12\x13\n\x0btotal_count\x18\x02 \x01(\x05\x32\xeb\x07\n\x0bResourceTag\x12\xa3\x01\n\x13\x63reate_resource_tag\x12\x36.spaceone.api.provisioning.v1.CreateResourceTagRequest\x1a-.spaceone.api.provisioning.v1.ResourceTagInfo\"%\x82\xd3\xe4\x93\x02\x1f\"\x1d/provisioning/v1/resource-tag\x12\xc4\x01\n\x11get_resource_tags\x12..spaceone.api.provisioning.v1.ResourceTagQuery\x1a..spaceone.api.provisioning.v1.ResourceTagsInfo\"O\x82\xd3\xe4\x93\x02I\x12\x1e/provisioning/v1/resource-tagsZ\'\"%/provisioning/v1/resource-tags/search\x12\xac\x01\n\x10get_resource_tag\x12\x30.spaceone.api.provisioning.v1.ResourceTagRequest\x1a-.spaceone.api.provisioning.v1.ResourceTagInfo\"7\x82\xd3\xe4\x93\x02\x31\x12//provisioning/v1/resource-tag/{resource_tag_id}\x12\xa3\x01\n\x13update_resource_tag\x12\x36.spaceone.api.provisioning.v1.UpdateResourceTagRequest\x1a-.spaceone.api.provisioning.v1.ResourceTagInfo\"%\x82\xd3\xe4\x93\x02\x1f\x1a\x1d/provisioning/v1/resource-tag\x12\x98\x01\n\x13\x64\x65lete_resource_tag\x12\x30.spaceone.api.provisioning.v1.ResourceTagRequest\x1a\x16.google.protobuf.Empty\"7\x82\xd3\xe4\x93\x02\x31*//provisioning/v1/resource-tag/{resource_tag_id}\x12\x7f\n\x04stat\x12\x32.spaceone.api.provisioning.v1.ResourceTagStatQuery\x1a\x17.google.protobuf.Struct\"*\x82\xd3\xe4\x93\x02$\"\"/provisioning/v1/resource-tag/statb\x06proto3')



_RESOURCETAGQUERY = DESCRIPTOR.message_types_by_name['ResourceTagQuery']
_CREATERESOURCETAGREQUEST = DESCRIPTOR.message_types_by_name['CreateResourceTagRequest']
_UPDATERESOURCETAGREQUEST = DESCRIPTOR.message_types_by_name['UpdateResourceTagRequest']
_RESOURCETAGREQUEST = DESCRIPTOR.message_types_by_name['ResourceTagRequest']
_RESOURCETAGSTATQUERY = DESCRIPTOR.message_types_by_name['ResourceTagStatQuery']
_RESOURCETAGINFO = DESCRIPTOR.message_types_by_name['ResourceTagInfo']
_RESOURCETAGSINFO = DESCRIPTOR.message_types_by_name['ResourceTagsInfo']
ResourceTagQuery = _reflection.GeneratedProtocolMessageType('ResourceTagQuery', (_message.Message,), {
  'DESCRIPTOR' : _RESOURCETAGQUERY,
  '__module__' : 'spaceone.api.provisioning.v1.resource_tag_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.provisioning.v1.ResourceTagQuery)
  })
_sym_db.RegisterMessage(ResourceTagQuery)

CreateResourceTagRequest = _reflection.GeneratedProtocolMessageType('CreateResourceTagRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATERESOURCETAGREQUEST,
  '__module__' : 'spaceone.api.provisioning.v1.resource_tag_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.provisioning.v1.CreateResourceTagRequest)
  })
_sym_db.RegisterMessage(CreateResourceTagRequest)

UpdateResourceTagRequest = _reflection.GeneratedProtocolMessageType('UpdateResourceTagRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATERESOURCETAGREQUEST,
  '__module__' : 'spaceone.api.provisioning.v1.resource_tag_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.provisioning.v1.UpdateResourceTagRequest)
  })
_sym_db.RegisterMessage(UpdateResourceTagRequest)

ResourceTagRequest = _reflection.GeneratedProtocolMessageType('ResourceTagRequest', (_message.Message,), {
  'DESCRIPTOR' : _RESOURCETAGREQUEST,
  '__module__' : 'spaceone.api.provisioning.v1.resource_tag_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.provisioning.v1.ResourceTagRequest)
  })
_sym_db.RegisterMessage(ResourceTagRequest)

ResourceTagStatQuery = _reflection.GeneratedProtocolMessageType('ResourceTagStatQuery', (_message.Message,), {
  'DESCRIPTOR' : _RESOURCETAGSTATQUERY,
  '__module__' : 'spaceone.api.provisioning.v1.resource_tag_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.provisioning.v1.ResourceTagStatQuery)
  })
_sym_db.RegisterMessage(ResourceTagStatQuery)

ResourceTagInfo = _reflection.GeneratedProtocolMessageType('ResourceTagInfo', (_message.Message,), {
  'DESCRIPTOR' : _RESOURCETAGINFO,
  '__module__' : 'spaceone.api.provisioning.v1.resource_tag_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.provisioning.v1.ResourceTagInfo)
  })
_sym_db.RegisterMessage(ResourceTagInfo)

ResourceTagsInfo = _reflection.GeneratedProtocolMessageType('ResourceTagsInfo', (_message.Message,), {
  'DESCRIPTOR' : _RESOURCETAGSINFO,
  '__module__' : 'spaceone.api.provisioning.v1.resource_tag_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.provisioning.v1.ResourceTagsInfo)
  })
_sym_db.RegisterMessage(ResourceTagsInfo)

_RESOURCETAG = DESCRIPTOR.services_by_name['ResourceTag']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _RESOURCETAG.methods_by_name['create_resource_tag']._options = None
  _RESOURCETAG.methods_by_name['create_resource_tag']._serialized_options = b'\202\323\344\223\002\037\"\035/provisioning/v1/resource-tag'
  _RESOURCETAG.methods_by_name['get_resource_tags']._options = None
  _RESOURCETAG.methods_by_name['get_resource_tags']._serialized_options = b'\202\323\344\223\002I\022\036/provisioning/v1/resource-tagsZ\'\"%/provisioning/v1/resource-tags/search'
  _RESOURCETAG.methods_by_name['get_resource_tag']._options = None
  _RESOURCETAG.methods_by_name['get_resource_tag']._serialized_options = b'\202\323\344\223\0021\022//provisioning/v1/resource-tag/{resource_tag_id}'
  _RESOURCETAG.methods_by_name['update_resource_tag']._options = None
  _RESOURCETAG.methods_by_name['update_resource_tag']._serialized_options = b'\202\323\344\223\002\037\032\035/provisioning/v1/resource-tag'
  _RESOURCETAG.methods_by_name['delete_resource_tag']._options = None
  _RESOURCETAG.methods_by_name['delete_resource_tag']._serialized_options = b'\202\323\344\223\0021*//provisioning/v1/resource-tag/{resource_tag_id}'
  _RESOURCETAG.methods_by_name['stat']._options = None
  _RESOURCETAG.methods_by_name['stat']._serialized_options = b'\202\323\344\223\002$\"\"/provisioning/v1/resource-tag/stat'
  _RESOURCETAGQUERY._serialized_start=204
  _RESOURCETAGQUERY._serialized_end=285
  _CREATERESOURCETAGREQUEST._serialized_start=288
  _CREATERESOURCETAGREQUEST._serialized_end=449
  _UPDATERESOURCETAGREQUEST._serialized_start=452
  _UPDATERESOURCETAGREQUEST._serialized_end=638
  _RESOURCETAGREQUEST._serialized_start=640
  _RESOURCETAGREQUEST._serialized_end=748
  _RESOURCETAGSTATQUERY._serialized_start=750
  _RESOURCETAGSTATQUERY._serialized_end=845
  _RESOURCETAGINFO._serialized_start=848
  _RESOURCETAGINFO._serialized_end=1025
  _RESOURCETAGSINFO._serialized_start=1027
  _RESOURCETAGSINFO._serialized_end=1130
  _RESOURCETAG._serialized_start=1133
  _RESOURCETAG._serialized_end=2136
# @@protoc_insertion_point(module_scope)
