# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from spaceone.api.identity.v1 import project_pb2 as spaceone_dot_api_dot_identity_dot_v1_dot_project__pb2


class ProjectStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.create = channel.unary_unary(
                '/spaceone.api.identity.v1.Project/create',
                request_serializer=spaceone_dot_api_dot_identity_dot_v1_dot_project__pb2.CreateProjectRequest.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_identity_dot_v1_dot_project__pb2.ProjectInfo.FromString,
                )
        self.update = channel.unary_unary(
                '/spaceone.api.identity.v1.Project/update',
                request_serializer=spaceone_dot_api_dot_identity_dot_v1_dot_project__pb2.UpdateProjectRequest.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_identity_dot_v1_dot_project__pb2.ProjectInfo.FromString,
                )
        self.update_profit_margin = channel.unary_unary(
                '/spaceone.api.identity.v1.Project/update_profit_margin',
                request_serializer=spaceone_dot_api_dot_identity_dot_v1_dot_project__pb2.UpdateProjectRequest.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_identity_dot_v1_dot_project__pb2.ProjectInfo.FromString,
                )
        self.delete = channel.unary_unary(
                '/spaceone.api.identity.v1.Project/delete',
                request_serializer=spaceone_dot_api_dot_identity_dot_v1_dot_project__pb2.ProjectRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.get = channel.unary_unary(
                '/spaceone.api.identity.v1.Project/get',
                request_serializer=spaceone_dot_api_dot_identity_dot_v1_dot_project__pb2.GetProjectRequest.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_identity_dot_v1_dot_project__pb2.ProjectInfo.FromString,
                )
        self.list = channel.unary_unary(
                '/spaceone.api.identity.v1.Project/list',
                request_serializer=spaceone_dot_api_dot_identity_dot_v1_dot_project__pb2.ProjectQuery.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_identity_dot_v1_dot_project__pb2.ProjectsInfo.FromString,
                )
        self.stat = channel.unary_unary(
                '/spaceone.api.identity.v1.Project/stat',
                request_serializer=spaceone_dot_api_dot_identity_dot_v1_dot_project__pb2.ProjectStatQuery.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_struct__pb2.Struct.FromString,
                )
        self.add_member = channel.unary_unary(
                '/spaceone.api.identity.v1.Project/add_member',
                request_serializer=spaceone_dot_api_dot_identity_dot_v1_dot_project__pb2.AddProjectMemberRequest.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_identity_dot_v1_dot_project__pb2.ProjectRoleBindingInfo.FromString,
                )
        self.modify_member = channel.unary_unary(
                '/spaceone.api.identity.v1.Project/modify_member',
                request_serializer=spaceone_dot_api_dot_identity_dot_v1_dot_project__pb2.ModifyProjectMemberRequest.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_identity_dot_v1_dot_project__pb2.ProjectRoleBindingInfo.FromString,
                )
        self.remove_member = channel.unary_unary(
                '/spaceone.api.identity.v1.Project/remove_member',
                request_serializer=spaceone_dot_api_dot_identity_dot_v1_dot_project__pb2.RemoveProjectMemberRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.list_members = channel.unary_unary(
                '/spaceone.api.identity.v1.Project/list_members',
                request_serializer=spaceone_dot_api_dot_identity_dot_v1_dot_project__pb2.ProjectMemberQuery.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_identity_dot_v1_dot_project__pb2.ProjectRoleBindingsInfo.FromString,
                )
        self.list_profit_margin_history = channel.unary_unary(
                '/spaceone.api.identity.v1.Project/list_profit_margin_history',
                request_serializer=spaceone_dot_api_dot_identity_dot_v1_dot_project__pb2.ProjectQuery.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_identity_dot_v1_dot_project__pb2.ProjectsInfo.FromString,
                )
        self.create_profit_margin_history = channel.unary_unary(
                '/spaceone.api.identity.v1.Project/create_profit_margin_history',
                request_serializer=spaceone_dot_api_dot_identity_dot_v1_dot_project__pb2.ProjectInfo.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_identity_dot_v1_dot_project__pb2.ProjectInfo.FromString,
                )
        self.latest_profit_margin_history = channel.unary_unary(
                '/spaceone.api.identity.v1.Project/latest_profit_margin_history',
                request_serializer=spaceone_dot_api_dot_identity_dot_v1_dot_project__pb2.ProjectQuery.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_identity_dot_v1_dot_project__pb2.ProjectInfo.FromString,
                )
        self.stat_profit_margin_history = channel.unary_unary(
                '/spaceone.api.identity.v1.Project/stat_profit_margin_history',
                request_serializer=spaceone_dot_api_dot_identity_dot_v1_dot_project__pb2.ProjectStatQuery.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_struct__pb2.Struct.FromString,
                )
        self.monthly_profit_margin_history = channel.unary_unary(
                '/spaceone.api.identity.v1.Project/monthly_profit_margin_history',
                request_serializer=spaceone_dot_api_dot_identity_dot_v1_dot_project__pb2.ProjectQuery.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_identity_dot_v1_dot_project__pb2.ProjectsInfo.FromString,
                )


class ProjectServicer(object):
    """Missing associated documentation comment in .proto file."""

    def create(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def update(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def update_profit_margin(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def delete(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def get(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def list(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def stat(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def add_member(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def modify_member(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def remove_member(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def list_members(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def list_profit_margin_history(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def create_profit_margin_history(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def latest_profit_margin_history(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def stat_profit_margin_history(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def monthly_profit_margin_history(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_ProjectServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'create': grpc.unary_unary_rpc_method_handler(
                    servicer.create,
                    request_deserializer=spaceone_dot_api_dot_identity_dot_v1_dot_project__pb2.CreateProjectRequest.FromString,
                    response_serializer=spaceone_dot_api_dot_identity_dot_v1_dot_project__pb2.ProjectInfo.SerializeToString,
            ),
            'update': grpc.unary_unary_rpc_method_handler(
                    servicer.update,
                    request_deserializer=spaceone_dot_api_dot_identity_dot_v1_dot_project__pb2.UpdateProjectRequest.FromString,
                    response_serializer=spaceone_dot_api_dot_identity_dot_v1_dot_project__pb2.ProjectInfo.SerializeToString,
            ),
            'update_profit_margin': grpc.unary_unary_rpc_method_handler(
                    servicer.update_profit_margin,
                    request_deserializer=spaceone_dot_api_dot_identity_dot_v1_dot_project__pb2.UpdateProjectRequest.FromString,
                    response_serializer=spaceone_dot_api_dot_identity_dot_v1_dot_project__pb2.ProjectInfo.SerializeToString,
            ),
            'delete': grpc.unary_unary_rpc_method_handler(
                    servicer.delete,
                    request_deserializer=spaceone_dot_api_dot_identity_dot_v1_dot_project__pb2.ProjectRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'get': grpc.unary_unary_rpc_method_handler(
                    servicer.get,
                    request_deserializer=spaceone_dot_api_dot_identity_dot_v1_dot_project__pb2.GetProjectRequest.FromString,
                    response_serializer=spaceone_dot_api_dot_identity_dot_v1_dot_project__pb2.ProjectInfo.SerializeToString,
            ),
            'list': grpc.unary_unary_rpc_method_handler(
                    servicer.list,
                    request_deserializer=spaceone_dot_api_dot_identity_dot_v1_dot_project__pb2.ProjectQuery.FromString,
                    response_serializer=spaceone_dot_api_dot_identity_dot_v1_dot_project__pb2.ProjectsInfo.SerializeToString,
            ),
            'stat': grpc.unary_unary_rpc_method_handler(
                    servicer.stat,
                    request_deserializer=spaceone_dot_api_dot_identity_dot_v1_dot_project__pb2.ProjectStatQuery.FromString,
                    response_serializer=google_dot_protobuf_dot_struct__pb2.Struct.SerializeToString,
            ),
            'add_member': grpc.unary_unary_rpc_method_handler(
                    servicer.add_member,
                    request_deserializer=spaceone_dot_api_dot_identity_dot_v1_dot_project__pb2.AddProjectMemberRequest.FromString,
                    response_serializer=spaceone_dot_api_dot_identity_dot_v1_dot_project__pb2.ProjectRoleBindingInfo.SerializeToString,
            ),
            'modify_member': grpc.unary_unary_rpc_method_handler(
                    servicer.modify_member,
                    request_deserializer=spaceone_dot_api_dot_identity_dot_v1_dot_project__pb2.ModifyProjectMemberRequest.FromString,
                    response_serializer=spaceone_dot_api_dot_identity_dot_v1_dot_project__pb2.ProjectRoleBindingInfo.SerializeToString,
            ),
            'remove_member': grpc.unary_unary_rpc_method_handler(
                    servicer.remove_member,
                    request_deserializer=spaceone_dot_api_dot_identity_dot_v1_dot_project__pb2.RemoveProjectMemberRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'list_members': grpc.unary_unary_rpc_method_handler(
                    servicer.list_members,
                    request_deserializer=spaceone_dot_api_dot_identity_dot_v1_dot_project__pb2.ProjectMemberQuery.FromString,
                    response_serializer=spaceone_dot_api_dot_identity_dot_v1_dot_project__pb2.ProjectRoleBindingsInfo.SerializeToString,
            ),
            'list_profit_margin_history': grpc.unary_unary_rpc_method_handler(
                    servicer.list_profit_margin_history,
                    request_deserializer=spaceone_dot_api_dot_identity_dot_v1_dot_project__pb2.ProjectQuery.FromString,
                    response_serializer=spaceone_dot_api_dot_identity_dot_v1_dot_project__pb2.ProjectsInfo.SerializeToString,
            ),
            'create_profit_margin_history': grpc.unary_unary_rpc_method_handler(
                    servicer.create_profit_margin_history,
                    request_deserializer=spaceone_dot_api_dot_identity_dot_v1_dot_project__pb2.ProjectInfo.FromString,
                    response_serializer=spaceone_dot_api_dot_identity_dot_v1_dot_project__pb2.ProjectInfo.SerializeToString,
            ),
            'latest_profit_margin_history': grpc.unary_unary_rpc_method_handler(
                    servicer.latest_profit_margin_history,
                    request_deserializer=spaceone_dot_api_dot_identity_dot_v1_dot_project__pb2.ProjectQuery.FromString,
                    response_serializer=spaceone_dot_api_dot_identity_dot_v1_dot_project__pb2.ProjectInfo.SerializeToString,
            ),
            'stat_profit_margin_history': grpc.unary_unary_rpc_method_handler(
                    servicer.stat_profit_margin_history,
                    request_deserializer=spaceone_dot_api_dot_identity_dot_v1_dot_project__pb2.ProjectStatQuery.FromString,
                    response_serializer=google_dot_protobuf_dot_struct__pb2.Struct.SerializeToString,
            ),
            'monthly_profit_margin_history': grpc.unary_unary_rpc_method_handler(
                    servicer.monthly_profit_margin_history,
                    request_deserializer=spaceone_dot_api_dot_identity_dot_v1_dot_project__pb2.ProjectQuery.FromString,
                    response_serializer=spaceone_dot_api_dot_identity_dot_v1_dot_project__pb2.ProjectsInfo.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'spaceone.api.identity.v1.Project', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class Project(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def create(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.identity.v1.Project/create',
            spaceone_dot_api_dot_identity_dot_v1_dot_project__pb2.CreateProjectRequest.SerializeToString,
            spaceone_dot_api_dot_identity_dot_v1_dot_project__pb2.ProjectInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def update(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.identity.v1.Project/update',
            spaceone_dot_api_dot_identity_dot_v1_dot_project__pb2.UpdateProjectRequest.SerializeToString,
            spaceone_dot_api_dot_identity_dot_v1_dot_project__pb2.ProjectInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def update_profit_margin(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.identity.v1.Project/update_profit_margin',
            spaceone_dot_api_dot_identity_dot_v1_dot_project__pb2.UpdateProjectRequest.SerializeToString,
            spaceone_dot_api_dot_identity_dot_v1_dot_project__pb2.ProjectInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def delete(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.identity.v1.Project/delete',
            spaceone_dot_api_dot_identity_dot_v1_dot_project__pb2.ProjectRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def get(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.identity.v1.Project/get',
            spaceone_dot_api_dot_identity_dot_v1_dot_project__pb2.GetProjectRequest.SerializeToString,
            spaceone_dot_api_dot_identity_dot_v1_dot_project__pb2.ProjectInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def list(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.identity.v1.Project/list',
            spaceone_dot_api_dot_identity_dot_v1_dot_project__pb2.ProjectQuery.SerializeToString,
            spaceone_dot_api_dot_identity_dot_v1_dot_project__pb2.ProjectsInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def stat(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.identity.v1.Project/stat',
            spaceone_dot_api_dot_identity_dot_v1_dot_project__pb2.ProjectStatQuery.SerializeToString,
            google_dot_protobuf_dot_struct__pb2.Struct.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def add_member(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.identity.v1.Project/add_member',
            spaceone_dot_api_dot_identity_dot_v1_dot_project__pb2.AddProjectMemberRequest.SerializeToString,
            spaceone_dot_api_dot_identity_dot_v1_dot_project__pb2.ProjectRoleBindingInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def modify_member(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.identity.v1.Project/modify_member',
            spaceone_dot_api_dot_identity_dot_v1_dot_project__pb2.ModifyProjectMemberRequest.SerializeToString,
            spaceone_dot_api_dot_identity_dot_v1_dot_project__pb2.ProjectRoleBindingInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def remove_member(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.identity.v1.Project/remove_member',
            spaceone_dot_api_dot_identity_dot_v1_dot_project__pb2.RemoveProjectMemberRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def list_members(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.identity.v1.Project/list_members',
            spaceone_dot_api_dot_identity_dot_v1_dot_project__pb2.ProjectMemberQuery.SerializeToString,
            spaceone_dot_api_dot_identity_dot_v1_dot_project__pb2.ProjectRoleBindingsInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def list_profit_margin_history(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.identity.v1.Project/list_profit_margin_history',
            spaceone_dot_api_dot_identity_dot_v1_dot_project__pb2.ProjectQuery.SerializeToString,
            spaceone_dot_api_dot_identity_dot_v1_dot_project__pb2.ProjectsInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def create_profit_margin_history(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.identity.v1.Project/create_profit_margin_history',
            spaceone_dot_api_dot_identity_dot_v1_dot_project__pb2.ProjectInfo.SerializeToString,
            spaceone_dot_api_dot_identity_dot_v1_dot_project__pb2.ProjectInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def latest_profit_margin_history(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.identity.v1.Project/latest_profit_margin_history',
            spaceone_dot_api_dot_identity_dot_v1_dot_project__pb2.ProjectQuery.SerializeToString,
            spaceone_dot_api_dot_identity_dot_v1_dot_project__pb2.ProjectInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def stat_profit_margin_history(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.identity.v1.Project/stat_profit_margin_history',
            spaceone_dot_api_dot_identity_dot_v1_dot_project__pb2.ProjectStatQuery.SerializeToString,
            google_dot_protobuf_dot_struct__pb2.Struct.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def monthly_profit_margin_history(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.identity.v1.Project/monthly_profit_margin_history',
            spaceone_dot_api_dot_identity_dot_v1_dot_project__pb2.ProjectQuery.SerializeToString,
            spaceone_dot_api_dot_identity_dot_v1_dot_project__pb2.ProjectsInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
