# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from spaceone.api.dashboard.v1 import domain_dashboard_pb2 as spaceone_dot_api_dot_dashboard_dot_v1_dot_domain__dashboard__pb2


class DomainDashboardStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.create = channel.unary_unary(
                '/spaceone.api.dashboard.v1.DomainDashboard/create',
                request_serializer=spaceone_dot_api_dot_dashboard_dot_v1_dot_domain__dashboard__pb2.CreateDomainDashboardRequest.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_dashboard_dot_v1_dot_domain__dashboard__pb2.DomainDashboardInfo.FromString,
                )
        self.update = channel.unary_unary(
                '/spaceone.api.dashboard.v1.DomainDashboard/update',
                request_serializer=spaceone_dot_api_dot_dashboard_dot_v1_dot_domain__dashboard__pb2.UpdateDomainDashboardRequest.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_dashboard_dot_v1_dot_domain__dashboard__pb2.DomainDashboardInfo.FromString,
                )
        self.delete = channel.unary_unary(
                '/spaceone.api.dashboard.v1.DomainDashboard/delete',
                request_serializer=spaceone_dot_api_dot_dashboard_dot_v1_dot_domain__dashboard__pb2.DomainDashboardRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.get = channel.unary_unary(
                '/spaceone.api.dashboard.v1.DomainDashboard/get',
                request_serializer=spaceone_dot_api_dot_dashboard_dot_v1_dot_domain__dashboard__pb2.GetDomainDashboardRequest.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_dashboard_dot_v1_dot_domain__dashboard__pb2.DomainDashboardInfo.FromString,
                )
        self.delete_version = channel.unary_unary(
                '/spaceone.api.dashboard.v1.DomainDashboard/delete_version',
                request_serializer=spaceone_dot_api_dot_dashboard_dot_v1_dot_domain__dashboard__pb2.DomainDashboardVersionRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.revert_version = channel.unary_unary(
                '/spaceone.api.dashboard.v1.DomainDashboard/revert_version',
                request_serializer=spaceone_dot_api_dot_dashboard_dot_v1_dot_domain__dashboard__pb2.DomainDashboardVersionRequest.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_dashboard_dot_v1_dot_domain__dashboard__pb2.DomainDashboardInfo.FromString,
                )
        self.get_version = channel.unary_unary(
                '/spaceone.api.dashboard.v1.DomainDashboard/get_version',
                request_serializer=spaceone_dot_api_dot_dashboard_dot_v1_dot_domain__dashboard__pb2.GetDomainDashboardVersionRequest.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_dashboard_dot_v1_dot_domain__dashboard__pb2.DomainDashboardVersionInfo.FromString,
                )
        self.list_versions = channel.unary_unary(
                '/spaceone.api.dashboard.v1.DomainDashboard/list_versions',
                request_serializer=spaceone_dot_api_dot_dashboard_dot_v1_dot_domain__dashboard__pb2.DomainDashboardVersionQuery.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_dashboard_dot_v1_dot_domain__dashboard__pb2.DomainDashboardVersionsInfo.FromString,
                )
        self.list = channel.unary_unary(
                '/spaceone.api.dashboard.v1.DomainDashboard/list',
                request_serializer=spaceone_dot_api_dot_dashboard_dot_v1_dot_domain__dashboard__pb2.DomainDashboardQuery.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_dashboard_dot_v1_dot_domain__dashboard__pb2.DomainDashboardsInfo.FromString,
                )
        self.stat = channel.unary_unary(
                '/spaceone.api.dashboard.v1.DomainDashboard/stat',
                request_serializer=spaceone_dot_api_dot_dashboard_dot_v1_dot_domain__dashboard__pb2.DomainDashboardStatQuery.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_struct__pb2.Struct.FromString,
                )


class DomainDashboardServicer(object):
    """Missing associated documentation comment in .proto file."""

    def create(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def update(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def delete(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def get(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def delete_version(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def revert_version(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def get_version(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def list_versions(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def list(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def stat(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_DomainDashboardServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'create': grpc.unary_unary_rpc_method_handler(
                    servicer.create,
                    request_deserializer=spaceone_dot_api_dot_dashboard_dot_v1_dot_domain__dashboard__pb2.CreateDomainDashboardRequest.FromString,
                    response_serializer=spaceone_dot_api_dot_dashboard_dot_v1_dot_domain__dashboard__pb2.DomainDashboardInfo.SerializeToString,
            ),
            'update': grpc.unary_unary_rpc_method_handler(
                    servicer.update,
                    request_deserializer=spaceone_dot_api_dot_dashboard_dot_v1_dot_domain__dashboard__pb2.UpdateDomainDashboardRequest.FromString,
                    response_serializer=spaceone_dot_api_dot_dashboard_dot_v1_dot_domain__dashboard__pb2.DomainDashboardInfo.SerializeToString,
            ),
            'delete': grpc.unary_unary_rpc_method_handler(
                    servicer.delete,
                    request_deserializer=spaceone_dot_api_dot_dashboard_dot_v1_dot_domain__dashboard__pb2.DomainDashboardRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'get': grpc.unary_unary_rpc_method_handler(
                    servicer.get,
                    request_deserializer=spaceone_dot_api_dot_dashboard_dot_v1_dot_domain__dashboard__pb2.GetDomainDashboardRequest.FromString,
                    response_serializer=spaceone_dot_api_dot_dashboard_dot_v1_dot_domain__dashboard__pb2.DomainDashboardInfo.SerializeToString,
            ),
            'delete_version': grpc.unary_unary_rpc_method_handler(
                    servicer.delete_version,
                    request_deserializer=spaceone_dot_api_dot_dashboard_dot_v1_dot_domain__dashboard__pb2.DomainDashboardVersionRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'revert_version': grpc.unary_unary_rpc_method_handler(
                    servicer.revert_version,
                    request_deserializer=spaceone_dot_api_dot_dashboard_dot_v1_dot_domain__dashboard__pb2.DomainDashboardVersionRequest.FromString,
                    response_serializer=spaceone_dot_api_dot_dashboard_dot_v1_dot_domain__dashboard__pb2.DomainDashboardInfo.SerializeToString,
            ),
            'get_version': grpc.unary_unary_rpc_method_handler(
                    servicer.get_version,
                    request_deserializer=spaceone_dot_api_dot_dashboard_dot_v1_dot_domain__dashboard__pb2.GetDomainDashboardVersionRequest.FromString,
                    response_serializer=spaceone_dot_api_dot_dashboard_dot_v1_dot_domain__dashboard__pb2.DomainDashboardVersionInfo.SerializeToString,
            ),
            'list_versions': grpc.unary_unary_rpc_method_handler(
                    servicer.list_versions,
                    request_deserializer=spaceone_dot_api_dot_dashboard_dot_v1_dot_domain__dashboard__pb2.DomainDashboardVersionQuery.FromString,
                    response_serializer=spaceone_dot_api_dot_dashboard_dot_v1_dot_domain__dashboard__pb2.DomainDashboardVersionsInfo.SerializeToString,
            ),
            'list': grpc.unary_unary_rpc_method_handler(
                    servicer.list,
                    request_deserializer=spaceone_dot_api_dot_dashboard_dot_v1_dot_domain__dashboard__pb2.DomainDashboardQuery.FromString,
                    response_serializer=spaceone_dot_api_dot_dashboard_dot_v1_dot_domain__dashboard__pb2.DomainDashboardsInfo.SerializeToString,
            ),
            'stat': grpc.unary_unary_rpc_method_handler(
                    servicer.stat,
                    request_deserializer=spaceone_dot_api_dot_dashboard_dot_v1_dot_domain__dashboard__pb2.DomainDashboardStatQuery.FromString,
                    response_serializer=google_dot_protobuf_dot_struct__pb2.Struct.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'spaceone.api.dashboard.v1.DomainDashboard', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class DomainDashboard(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def create(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.dashboard.v1.DomainDashboard/create',
            spaceone_dot_api_dot_dashboard_dot_v1_dot_domain__dashboard__pb2.CreateDomainDashboardRequest.SerializeToString,
            spaceone_dot_api_dot_dashboard_dot_v1_dot_domain__dashboard__pb2.DomainDashboardInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def update(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.dashboard.v1.DomainDashboard/update',
            spaceone_dot_api_dot_dashboard_dot_v1_dot_domain__dashboard__pb2.UpdateDomainDashboardRequest.SerializeToString,
            spaceone_dot_api_dot_dashboard_dot_v1_dot_domain__dashboard__pb2.DomainDashboardInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def delete(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.dashboard.v1.DomainDashboard/delete',
            spaceone_dot_api_dot_dashboard_dot_v1_dot_domain__dashboard__pb2.DomainDashboardRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def get(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.dashboard.v1.DomainDashboard/get',
            spaceone_dot_api_dot_dashboard_dot_v1_dot_domain__dashboard__pb2.GetDomainDashboardRequest.SerializeToString,
            spaceone_dot_api_dot_dashboard_dot_v1_dot_domain__dashboard__pb2.DomainDashboardInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def delete_version(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.dashboard.v1.DomainDashboard/delete_version',
            spaceone_dot_api_dot_dashboard_dot_v1_dot_domain__dashboard__pb2.DomainDashboardVersionRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def revert_version(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.dashboard.v1.DomainDashboard/revert_version',
            spaceone_dot_api_dot_dashboard_dot_v1_dot_domain__dashboard__pb2.DomainDashboardVersionRequest.SerializeToString,
            spaceone_dot_api_dot_dashboard_dot_v1_dot_domain__dashboard__pb2.DomainDashboardInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def get_version(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.dashboard.v1.DomainDashboard/get_version',
            spaceone_dot_api_dot_dashboard_dot_v1_dot_domain__dashboard__pb2.GetDomainDashboardVersionRequest.SerializeToString,
            spaceone_dot_api_dot_dashboard_dot_v1_dot_domain__dashboard__pb2.DomainDashboardVersionInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def list_versions(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.dashboard.v1.DomainDashboard/list_versions',
            spaceone_dot_api_dot_dashboard_dot_v1_dot_domain__dashboard__pb2.DomainDashboardVersionQuery.SerializeToString,
            spaceone_dot_api_dot_dashboard_dot_v1_dot_domain__dashboard__pb2.DomainDashboardVersionsInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def list(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.dashboard.v1.DomainDashboard/list',
            spaceone_dot_api_dot_dashboard_dot_v1_dot_domain__dashboard__pb2.DomainDashboardQuery.SerializeToString,
            spaceone_dot_api_dot_dashboard_dot_v1_dot_domain__dashboard__pb2.DomainDashboardsInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def stat(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.dashboard.v1.DomainDashboard/stat',
            spaceone_dot_api_dot_dashboard_dot_v1_dot_domain__dashboard__pb2.DomainDashboardStatQuery.SerializeToString,
            google_dot_protobuf_dot_struct__pb2.Struct.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
