# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: spaceone/api/identity/v1/domain_owner.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n+spaceone/api/identity/v1/domain_owner.proto\x12\x18spaceone.api.identity.v1\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1cgoogle/api/annotations.proto\"\x8b\x01\n\x11\x43reateDomainOwner\x12\x10\n\x08owner_id\x18\x01 \x01(\t\x12\x10\n\x08password\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\r\n\x05\x65mail\x18\x04 \x01(\t\x12\x10\n\x08language\x18\x07 \x01(\t\x12\x10\n\x08timezone\x18\x08 \x01(\t\x12\x11\n\tdomain_id\x18\n \x01(\t\"\x8b\x01\n\x11UpdateDomainOwner\x12\x10\n\x08owner_id\x18\x01 \x01(\t\x12\x10\n\x08password\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\r\n\x05\x65mail\x18\x04 \x01(\t\x12\x10\n\x08language\x18\x07 \x01(\t\x12\x10\n\x08timezone\x18\x08 \x01(\t\x12\x11\n\tdomain_id\x18\n \x01(\t\"9\n\x12\x44omainOwnerRequest\x12\x11\n\tdomain_id\x18\x01 \x01(\t\x12\x10\n\x08owner_id\x18\x02 \x01(\t\"J\n\x15GetDomainOwnerRequest\x12\x11\n\tdomain_id\x18\x01 \x01(\t\x12\x10\n\x08owner_id\x18\x02 \x01(\t\x12\x0c\n\x04only\x18\x03 \x03(\t\"\xa5\x01\n\x0f\x44omainOwnerInfo\x12\x10\n\x08owner_id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\r\n\x05\x65mail\x18\x03 \x01(\t\x12\x10\n\x08language\x18\x07 \x01(\t\x12\x10\n\x08timezone\x18\x08 \x01(\t\x12\x18\n\x10last_accessed_at\x18\x0b \x01(\t\x12\x12\n\ncreated_at\x18\x0c \x01(\t\x12\x11\n\tdomain_id\x18\r \x01(\t2\xc4\x04\n\x0b\x44omainOwner\x12\x8f\x01\n\x06\x63reate\x12+.spaceone.api.identity.v1.CreateDomainOwner\x1a).spaceone.api.identity.v1.DomainOwnerInfo\"-\x82\xd3\xe4\x93\x02\'\"%/identity/v1/domain/{domain_id}/owner\x12\x90\x01\n\x06update\x12+.spaceone.api.identity.v1.UpdateDomainOwner\x1a).spaceone.api.identity.v1.DomainOwnerInfo\".\x82\xd3\xe4\x93\x02(\x1a& /identity/v1/domain/{domain_id}/owner\x12}\n\x06\x64\x65lete\x12,.spaceone.api.identity.v1.DomainOwnerRequest\x1a\x16.google.protobuf.Empty\"-\x82\xd3\xe4\x93\x02\'*%/identity/v1/domain/{domain_id}/owner\x12\x90\x01\n\x03get\x12/.spaceone.api.identity.v1.GetDomainOwnerRequest\x1a).spaceone.api.identity.v1.DomainOwnerInfo\"-\x82\xd3\xe4\x93\x02\'\x12%/identity/v1/domain/{domain_id}/ownerb\x06proto3')



_CREATEDOMAINOWNER = DESCRIPTOR.message_types_by_name['CreateDomainOwner']
_UPDATEDOMAINOWNER = DESCRIPTOR.message_types_by_name['UpdateDomainOwner']
_DOMAINOWNERREQUEST = DESCRIPTOR.message_types_by_name['DomainOwnerRequest']
_GETDOMAINOWNERREQUEST = DESCRIPTOR.message_types_by_name['GetDomainOwnerRequest']
_DOMAINOWNERINFO = DESCRIPTOR.message_types_by_name['DomainOwnerInfo']
CreateDomainOwner = _reflection.GeneratedProtocolMessageType('CreateDomainOwner', (_message.Message,), {
  'DESCRIPTOR' : _CREATEDOMAINOWNER,
  '__module__' : 'spaceone.api.identity.v1.domain_owner_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.identity.v1.CreateDomainOwner)
  })
_sym_db.RegisterMessage(CreateDomainOwner)

UpdateDomainOwner = _reflection.GeneratedProtocolMessageType('UpdateDomainOwner', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEDOMAINOWNER,
  '__module__' : 'spaceone.api.identity.v1.domain_owner_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.identity.v1.UpdateDomainOwner)
  })
_sym_db.RegisterMessage(UpdateDomainOwner)

DomainOwnerRequest = _reflection.GeneratedProtocolMessageType('DomainOwnerRequest', (_message.Message,), {
  'DESCRIPTOR' : _DOMAINOWNERREQUEST,
  '__module__' : 'spaceone.api.identity.v1.domain_owner_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.identity.v1.DomainOwnerRequest)
  })
_sym_db.RegisterMessage(DomainOwnerRequest)

GetDomainOwnerRequest = _reflection.GeneratedProtocolMessageType('GetDomainOwnerRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETDOMAINOWNERREQUEST,
  '__module__' : 'spaceone.api.identity.v1.domain_owner_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.identity.v1.GetDomainOwnerRequest)
  })
_sym_db.RegisterMessage(GetDomainOwnerRequest)

DomainOwnerInfo = _reflection.GeneratedProtocolMessageType('DomainOwnerInfo', (_message.Message,), {
  'DESCRIPTOR' : _DOMAINOWNERINFO,
  '__module__' : 'spaceone.api.identity.v1.domain_owner_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.identity.v1.DomainOwnerInfo)
  })
_sym_db.RegisterMessage(DomainOwnerInfo)

_DOMAINOWNER = DESCRIPTOR.services_by_name['DomainOwner']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _DOMAINOWNER.methods_by_name['create']._options = None
  _DOMAINOWNER.methods_by_name['create']._serialized_options = b'\202\323\344\223\002\'\"%/identity/v1/domain/{domain_id}/owner'
  _DOMAINOWNER.methods_by_name['update']._options = None
  _DOMAINOWNER.methods_by_name['update']._serialized_options = b'\202\323\344\223\002(\032& /identity/v1/domain/{domain_id}/owner'
  _DOMAINOWNER.methods_by_name['delete']._options = None
  _DOMAINOWNER.methods_by_name['delete']._serialized_options = b'\202\323\344\223\002\'*%/identity/v1/domain/{domain_id}/owner'
  _DOMAINOWNER.methods_by_name['get']._options = None
  _DOMAINOWNER.methods_by_name['get']._serialized_options = b'\202\323\344\223\002\'\022%/identity/v1/domain/{domain_id}/owner'
  _CREATEDOMAINOWNER._serialized_start=133
  _CREATEDOMAINOWNER._serialized_end=272
  _UPDATEDOMAINOWNER._serialized_start=275
  _UPDATEDOMAINOWNER._serialized_end=414
  _DOMAINOWNERREQUEST._serialized_start=416
  _DOMAINOWNERREQUEST._serialized_end=473
  _GETDOMAINOWNERREQUEST._serialized_start=475
  _GETDOMAINOWNERREQUEST._serialized_end=549
  _DOMAINOWNERINFO._serialized_start=552
  _DOMAINOWNERINFO._serialized_end=717
  _DOMAINOWNER._serialized_start=720
  _DOMAINOWNER._serialized_end=1300
# @@protoc_insertion_point(module_scope)
