# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: spaceone/api/inventory/v1/metric.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from spaceone.api.core.v1 import query_pb2 as spaceone_dot_api_dot_core_dot_v1_dot_query__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&spaceone/api/inventory/v1/metric.proto\x12\x19spaceone.api.inventory.v1\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1cgoogle/api/annotations.proto\x1a spaceone/api/core/v1/query.proto\"F\n\x10GetMetricRequest\x12\x11\n\tmetric_id\x18\x01 \x01(\t\x12\x11\n\tdomain_id\x18\x02 \x01(\t\x12\x0c\n\x04only\x18\x03 \x03(\t\"\xac\x01\n\x0bMetricQuery\x12*\n\x05query\x18\x01 \x01(\x0b\x32\x1b.spaceone.api.core.v1.Query\x12\x11\n\tmetric_id\x18\x02 \x01(\t\x12\x11\n\tdomain_id\x18\x03 \x01(\t\x12\x10\n\x08provider\x18\x06 \x01(\t\x12\x0f\n\x07\x61\x63\x63ount\x18\x07 \x01(\t\x12\x13\n\x0bresource_id\x18\x08 \x01(\t\x12\x13\n\x0bmetric_name\x18\t \x01(\t\"\xa1\x02\n\nMetricInfo\x12\x11\n\tmetric_id\x18\x01 \x01(\t\x12\x10\n\x08provider\x18\x02 \x01(\t\x12\x11\n\tdomain_id\x18\x03 \x01(\t\x12\x0f\n\x07\x61\x63\x63ount\x18\x04 \x01(\t\x12\x13\n\x0bresource_id\x18\x05 \x01(\t\x12*\n\tmeta_data\x18\x06 \x01(\x0b\x32\x17.google.protobuf.Struct\x12%\n\x04\x64\x61ta\x18\x07 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x11\n\ttimestamp\x18\x08 \x01(\t\x12\x13\n\x0bmetric_name\x18\t \x01(\t\x12\x12\n\nupdated_at\x18\n \x01(\t\x12\x12\n\ncreated_at\x18\x0b \x01(\t\x12\x12\n\ndeleted_at\x18\x0c \x01(\t\"Z\n\x0bMetricsInfo\x12\x36\n\x07results\x18\x01 \x03(\x0b\x32%.spaceone.api.inventory.v1.MetricInfo\x12\x13\n\x0btotal_count\x18\x02 \x01(\x05\"Z\n\x0fMetricStatQuery\x12\x34\n\x05query\x18\x01 \x01(\x0b\x32%.spaceone.api.core.v1.StatisticsQuery\x12\x11\n\tdomain_id\x18\x02 \x01(\t2\x92\x04\n\x06Metric\x12\x95\x01\n\x04list\x12&.spaceone.api.inventory.v1.MetricQuery\x1a&.spaceone.api.inventory.v1.MetricsInfo\"=\x82\xd3\xe4\x93\x02\x37\x12\x15/inventory/v1/metricsZ\x1e\"\x1c/inventory/v1/metrics/search\x12o\n\x04stat\x12*.spaceone.api.inventory.v1.MetricStatQuery\x1a\x17.google.protobuf.Struct\"\"\x82\xd3\xe4\x93\x02\x1c\"\x1a/inventory/v1/metrics/stat\x12\x83\x01\n\x03get\x12+.spaceone.api.inventory.v1.GetMetricRequest\x1a%.spaceone.api.inventory.v1.MetricInfo\"(\x82\xd3\xe4\x93\x02\"\" /inventory/v1/metric/{metric_id}\x12y\n\tstat_diff\x12*.spaceone.api.inventory.v1.MetricStatQuery\x1a\x17.google.protobuf.Struct\"\'\x82\xd3\xe4\x93\x02!\"\x1f/inventory/v1/metrics/stat_diffb\x06proto3')



_GETMETRICREQUEST = DESCRIPTOR.message_types_by_name['GetMetricRequest']
_METRICQUERY = DESCRIPTOR.message_types_by_name['MetricQuery']
_METRICINFO = DESCRIPTOR.message_types_by_name['MetricInfo']
_METRICSINFO = DESCRIPTOR.message_types_by_name['MetricsInfo']
_METRICSTATQUERY = DESCRIPTOR.message_types_by_name['MetricStatQuery']
GetMetricRequest = _reflection.GeneratedProtocolMessageType('GetMetricRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETMETRICREQUEST,
  '__module__' : 'spaceone.api.inventory.v1.metric_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.GetMetricRequest)
  })
_sym_db.RegisterMessage(GetMetricRequest)

MetricQuery = _reflection.GeneratedProtocolMessageType('MetricQuery', (_message.Message,), {
  'DESCRIPTOR' : _METRICQUERY,
  '__module__' : 'spaceone.api.inventory.v1.metric_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.MetricQuery)
  })
_sym_db.RegisterMessage(MetricQuery)

MetricInfo = _reflection.GeneratedProtocolMessageType('MetricInfo', (_message.Message,), {
  'DESCRIPTOR' : _METRICINFO,
  '__module__' : 'spaceone.api.inventory.v1.metric_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.MetricInfo)
  })
_sym_db.RegisterMessage(MetricInfo)

MetricsInfo = _reflection.GeneratedProtocolMessageType('MetricsInfo', (_message.Message,), {
  'DESCRIPTOR' : _METRICSINFO,
  '__module__' : 'spaceone.api.inventory.v1.metric_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.MetricsInfo)
  })
_sym_db.RegisterMessage(MetricsInfo)

MetricStatQuery = _reflection.GeneratedProtocolMessageType('MetricStatQuery', (_message.Message,), {
  'DESCRIPTOR' : _METRICSTATQUERY,
  '__module__' : 'spaceone.api.inventory.v1.metric_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.MetricStatQuery)
  })
_sym_db.RegisterMessage(MetricStatQuery)

_METRIC = DESCRIPTOR.services_by_name['Metric']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _METRIC.methods_by_name['list']._options = None
  _METRIC.methods_by_name['list']._serialized_options = b'\202\323\344\223\0027\022\025/inventory/v1/metricsZ\036\"\034/inventory/v1/metrics/search'
  _METRIC.methods_by_name['stat']._options = None
  _METRIC.methods_by_name['stat']._serialized_options = b'\202\323\344\223\002\034\"\032/inventory/v1/metrics/stat'
  _METRIC.methods_by_name['get']._options = None
  _METRIC.methods_by_name['get']._serialized_options = b'\202\323\344\223\002\"\" /inventory/v1/metric/{metric_id}'
  _METRIC.methods_by_name['stat_diff']._options = None
  _METRIC.methods_by_name['stat_diff']._serialized_options = b'\202\323\344\223\002!\"\037/inventory/v1/metrics/stat_diff'
  _GETMETRICREQUEST._serialized_start=192
  _GETMETRICREQUEST._serialized_end=262
  _METRICQUERY._serialized_start=265
  _METRICQUERY._serialized_end=437
  _METRICINFO._serialized_start=440
  _METRICINFO._serialized_end=729
  _METRICSINFO._serialized_start=731
  _METRICSINFO._serialized_end=821
  _METRICSTATQUERY._serialized_start=823
  _METRICSTATQUERY._serialized_end=913
  _METRIC._serialized_start=916
  _METRIC._serialized_end=1446
# @@protoc_insertion_point(module_scope)
