# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: spaceone/api/cost_analysis/v1/user_dashboard.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from spaceone.api.core.v1 import query_pb2 as spaceone_dot_api_dot_core_dot_v1_dot_query__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n2spaceone/api/cost_analysis/v1/user_dashboard.proto\x12\x1dspaceone.api.cost_analysis.v1\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1cgoogle/api/annotations.proto\x1a spaceone/api/core/v1/query.proto\"1\n\x13UserDashboardPeriod\x12\r\n\x05start\x18\x01 \x01(\t\x12\x0b\n\x03\x65nd\x18\x02 \x01(\t\"\xb0\x03\n\x1a\x43reateUserDashboardRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x19\n\x11\x64\x65\x66\x61ult_layout_id\x18\x02 \x01(\t\x12\x32\n\x0e\x63ustom_layouts\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.ListValue\x12/\n\x0e\x64\x65\x66\x61ult_filter\x18\x04 \x01(\x0b\x32\x17.google.protobuf.Struct\x12Y\n\x0bperiod_type\x18\x05 \x01(\x0e\x32\x44.spaceone.api.cost_analysis.v1.CreateUserDashboardRequest.PeriodType\x12\x42\n\x06period\x18\x06 \x01(\x0b\x32\x32.spaceone.api.cost_analysis.v1.UserDashboardPeriod\x12%\n\x04tags\x18\x07 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x11\n\tdomain_id\x18\x0b \x01(\t\"+\n\nPeriodType\x12\x08\n\x04NONE\x10\x00\x12\x08\n\x04\x41UTO\x10\x01\x12\t\n\x05\x46IXED\x10\x02\"\xcb\x03\n\x1aUpdateUserDashboardRequest\x12\x19\n\x11user_dashboard_id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x19\n\x11\x64\x65\x66\x61ult_layout_id\x18\x03 \x01(\t\x12\x32\n\x0e\x63ustom_layouts\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.ListValue\x12/\n\x0e\x64\x65\x66\x61ult_filter\x18\x05 \x01(\x0b\x32\x17.google.protobuf.Struct\x12Y\n\x0bperiod_type\x18\x06 \x01(\x0e\x32\x44.spaceone.api.cost_analysis.v1.UpdateUserDashboardRequest.PeriodType\x12\x42\n\x06period\x18\x07 \x01(\x0b\x32\x32.spaceone.api.cost_analysis.v1.UserDashboardPeriod\x12%\n\x04tags\x18\x08 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x11\n\tdomain_id\x18\x0b \x01(\t\"+\n\nPeriodType\x12\x08\n\x04NONE\x10\x00\x12\x08\n\x04\x41UTO\x10\x01\x12\t\n\x05\x46IXED\x10\x02\"D\n\x14UserDashboardRequest\x12\x19\n\x11user_dashboard_id\x18\x01 \x01(\t\x12\x11\n\tdomain_id\x18\x02 \x01(\t\"U\n\x17GetUserDashboardRequest\x12\x19\n\x11user_dashboard_id\x18\x01 \x01(\t\x12\x11\n\tdomain_id\x18\x02 \x01(\t\x12\x0c\n\x04only\x18\x03 \x03(\t\"\x8d\x02\n\x12UserDashboardQuery\x12*\n\x05query\x18\x01 \x01(\x0b\x32\x1b.spaceone.api.core.v1.Query\x12\x19\n\x11user_dashboard_id\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12Q\n\x0bperiod_type\x18\x04 \x01(\x0e\x32<.spaceone.api.cost_analysis.v1.UserDashboardQuery.PeriodType\x12\x0f\n\x07user_id\x18\x05 \x01(\t\x12\x11\n\tdomain_id\x18\x0b \x01(\t\"+\n\nPeriodType\x12\x08\n\x04NONE\x10\x00\x12\x08\n\x04\x41UTO\x10\x01\x12\t\n\x05\x46IXED\x10\x02\"\xf2\x03\n\x11UserDashboardInfo\x12\x19\n\x11user_dashboard_id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x19\n\x11\x64\x65\x66\x61ult_layout_id\x18\x03 \x01(\t\x12\x32\n\x0e\x63ustom_layouts\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.ListValue\x12/\n\x0e\x64\x65\x66\x61ult_filter\x18\x05 \x01(\x0b\x32\x17.google.protobuf.Struct\x12P\n\x0bperiod_type\x18\x06 \x01(\x0e\x32;.spaceone.api.cost_analysis.v1.UserDashboardInfo.PeriodType\x12\x42\n\x06period\x18\x07 \x01(\x0b\x32\x32.spaceone.api.cost_analysis.v1.UserDashboardPeriod\x12%\n\x04tags\x18\x08 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x0f\n\x07user_id\x18\x0b \x01(\t\x12\x11\n\tdomain_id\x18\x0c \x01(\t\x12\x12\n\ncreated_at\x18\x15 \x01(\t\x12\x12\n\nupdated_at\x18\x16 \x01(\t\"+\n\nPeriodType\x12\x08\n\x04NONE\x10\x00\x12\x08\n\x04\x41UTO\x10\x01\x12\t\n\x05\x46IXED\x10\x02\"l\n\x12UserDashboardsInfo\x12\x41\n\x07results\x18\x01 \x03(\x0b\x32\x30.spaceone.api.cost_analysis.v1.UserDashboardInfo\x12\x13\n\x0btotal_count\x18\x02 \x01(\x05\"a\n\x16UserDashboardStatQuery\x12\x34\n\x05query\x18\x01 \x01(\x0b\x32%.spaceone.api.core.v1.StatisticsQuery\x12\x11\n\tdomain_id\x18\x02 \x01(\t2\xfd\x07\n\rUserDashboard\x12\xa0\x01\n\x06\x63reate\x12\x39.spaceone.api.cost_analysis.v1.CreateUserDashboardRequest\x1a\x30.spaceone.api.cost_analysis.v1.UserDashboardInfo\")\x82\xd3\xe4\x93\x02#\"!/cost-analysis/v1/user-dashboards\x12\xb3\x01\n\x06update\x12\x39.spaceone.api.cost_analysis.v1.UpdateUserDashboardRequest\x1a\x30.spaceone.api.cost_analysis.v1.UserDashboardInfo\"<\x82\xd3\xe4\x93\x02\x36\x1a\x34/cost-analysis/v1/user-dashboard/{user_dashboard_id}\x12\x93\x01\n\x06\x64\x65lete\x12\x33.spaceone.api.cost_analysis.v1.UserDashboardRequest\x1a\x16.google.protobuf.Empty\"<\x82\xd3\xe4\x93\x02\x36*4/cost-analysis/v1/user-dashboard/{user_dashboard_id}\x12\xad\x01\n\x03get\x12\x36.spaceone.api.cost_analysis.v1.GetUserDashboardRequest\x1a\x30.spaceone.api.cost_analysis.v1.UserDashboardInfo\"<\x82\xd3\xe4\x93\x02\x36\x12\x34/cost-analysis/v1/user-dashboard/{user_dashboard_id}\x12\xc3\x01\n\x04list\x12\x31.spaceone.api.cost_analysis.v1.UserDashboardQuery\x1a\x31.spaceone.api.cost_analysis.v1.UserDashboardsInfo\"U\x82\xd3\xe4\x93\x02O\x12!/cost-analysis/v1/user-dashboardsZ*\"(/cost-analysis/v1/user-dashboards/search\x12\x86\x01\n\x04stat\x12\x35.spaceone.api.cost_analysis.v1.UserDashboardStatQuery\x1a\x17.google.protobuf.Struct\".\x82\xd3\xe4\x93\x02(\"&/cost-analysis/v1/user-dashboards/statb\x06proto3')



_USERDASHBOARDPERIOD = DESCRIPTOR.message_types_by_name['UserDashboardPeriod']
_CREATEUSERDASHBOARDREQUEST = DESCRIPTOR.message_types_by_name['CreateUserDashboardRequest']
_UPDATEUSERDASHBOARDREQUEST = DESCRIPTOR.message_types_by_name['UpdateUserDashboardRequest']
_USERDASHBOARDREQUEST = DESCRIPTOR.message_types_by_name['UserDashboardRequest']
_GETUSERDASHBOARDREQUEST = DESCRIPTOR.message_types_by_name['GetUserDashboardRequest']
_USERDASHBOARDQUERY = DESCRIPTOR.message_types_by_name['UserDashboardQuery']
_USERDASHBOARDINFO = DESCRIPTOR.message_types_by_name['UserDashboardInfo']
_USERDASHBOARDSINFO = DESCRIPTOR.message_types_by_name['UserDashboardsInfo']
_USERDASHBOARDSTATQUERY = DESCRIPTOR.message_types_by_name['UserDashboardStatQuery']
_CREATEUSERDASHBOARDREQUEST_PERIODTYPE = _CREATEUSERDASHBOARDREQUEST.enum_types_by_name['PeriodType']
_UPDATEUSERDASHBOARDREQUEST_PERIODTYPE = _UPDATEUSERDASHBOARDREQUEST.enum_types_by_name['PeriodType']
_USERDASHBOARDQUERY_PERIODTYPE = _USERDASHBOARDQUERY.enum_types_by_name['PeriodType']
_USERDASHBOARDINFO_PERIODTYPE = _USERDASHBOARDINFO.enum_types_by_name['PeriodType']
UserDashboardPeriod = _reflection.GeneratedProtocolMessageType('UserDashboardPeriod', (_message.Message,), {
  'DESCRIPTOR' : _USERDASHBOARDPERIOD,
  '__module__' : 'spaceone.api.cost_analysis.v1.user_dashboard_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.cost_analysis.v1.UserDashboardPeriod)
  })
_sym_db.RegisterMessage(UserDashboardPeriod)

CreateUserDashboardRequest = _reflection.GeneratedProtocolMessageType('CreateUserDashboardRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEUSERDASHBOARDREQUEST,
  '__module__' : 'spaceone.api.cost_analysis.v1.user_dashboard_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.cost_analysis.v1.CreateUserDashboardRequest)
  })
_sym_db.RegisterMessage(CreateUserDashboardRequest)

UpdateUserDashboardRequest = _reflection.GeneratedProtocolMessageType('UpdateUserDashboardRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEUSERDASHBOARDREQUEST,
  '__module__' : 'spaceone.api.cost_analysis.v1.user_dashboard_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.cost_analysis.v1.UpdateUserDashboardRequest)
  })
_sym_db.RegisterMessage(UpdateUserDashboardRequest)

UserDashboardRequest = _reflection.GeneratedProtocolMessageType('UserDashboardRequest', (_message.Message,), {
  'DESCRIPTOR' : _USERDASHBOARDREQUEST,
  '__module__' : 'spaceone.api.cost_analysis.v1.user_dashboard_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.cost_analysis.v1.UserDashboardRequest)
  })
_sym_db.RegisterMessage(UserDashboardRequest)

GetUserDashboardRequest = _reflection.GeneratedProtocolMessageType('GetUserDashboardRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETUSERDASHBOARDREQUEST,
  '__module__' : 'spaceone.api.cost_analysis.v1.user_dashboard_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.cost_analysis.v1.GetUserDashboardRequest)
  })
_sym_db.RegisterMessage(GetUserDashboardRequest)

UserDashboardQuery = _reflection.GeneratedProtocolMessageType('UserDashboardQuery', (_message.Message,), {
  'DESCRIPTOR' : _USERDASHBOARDQUERY,
  '__module__' : 'spaceone.api.cost_analysis.v1.user_dashboard_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.cost_analysis.v1.UserDashboardQuery)
  })
_sym_db.RegisterMessage(UserDashboardQuery)

UserDashboardInfo = _reflection.GeneratedProtocolMessageType('UserDashboardInfo', (_message.Message,), {
  'DESCRIPTOR' : _USERDASHBOARDINFO,
  '__module__' : 'spaceone.api.cost_analysis.v1.user_dashboard_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.cost_analysis.v1.UserDashboardInfo)
  })
_sym_db.RegisterMessage(UserDashboardInfo)

UserDashboardsInfo = _reflection.GeneratedProtocolMessageType('UserDashboardsInfo', (_message.Message,), {
  'DESCRIPTOR' : _USERDASHBOARDSINFO,
  '__module__' : 'spaceone.api.cost_analysis.v1.user_dashboard_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.cost_analysis.v1.UserDashboardsInfo)
  })
_sym_db.RegisterMessage(UserDashboardsInfo)

UserDashboardStatQuery = _reflection.GeneratedProtocolMessageType('UserDashboardStatQuery', (_message.Message,), {
  'DESCRIPTOR' : _USERDASHBOARDSTATQUERY,
  '__module__' : 'spaceone.api.cost_analysis.v1.user_dashboard_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.cost_analysis.v1.UserDashboardStatQuery)
  })
_sym_db.RegisterMessage(UserDashboardStatQuery)

_USERDASHBOARD = DESCRIPTOR.services_by_name['UserDashboard']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _USERDASHBOARD.methods_by_name['create']._options = None
  _USERDASHBOARD.methods_by_name['create']._serialized_options = b'\202\323\344\223\002#\"!/cost-analysis/v1/user-dashboards'
  _USERDASHBOARD.methods_by_name['update']._options = None
  _USERDASHBOARD.methods_by_name['update']._serialized_options = b'\202\323\344\223\0026\0324/cost-analysis/v1/user-dashboard/{user_dashboard_id}'
  _USERDASHBOARD.methods_by_name['delete']._options = None
  _USERDASHBOARD.methods_by_name['delete']._serialized_options = b'\202\323\344\223\0026*4/cost-analysis/v1/user-dashboard/{user_dashboard_id}'
  _USERDASHBOARD.methods_by_name['get']._options = None
  _USERDASHBOARD.methods_by_name['get']._serialized_options = b'\202\323\344\223\0026\0224/cost-analysis/v1/user-dashboard/{user_dashboard_id}'
  _USERDASHBOARD.methods_by_name['list']._options = None
  _USERDASHBOARD.methods_by_name['list']._serialized_options = b'\202\323\344\223\002O\022!/cost-analysis/v1/user-dashboardsZ*\"(/cost-analysis/v1/user-dashboards/search'
  _USERDASHBOARD.methods_by_name['stat']._options = None
  _USERDASHBOARD.methods_by_name['stat']._serialized_options = b'\202\323\344\223\002(\"&/cost-analysis/v1/user-dashboards/stat'
  _USERDASHBOARDPERIOD._serialized_start=208
  _USERDASHBOARDPERIOD._serialized_end=257
  _CREATEUSERDASHBOARDREQUEST._serialized_start=260
  _CREATEUSERDASHBOARDREQUEST._serialized_end=692
  _CREATEUSERDASHBOARDREQUEST_PERIODTYPE._serialized_start=649
  _CREATEUSERDASHBOARDREQUEST_PERIODTYPE._serialized_end=692
  _UPDATEUSERDASHBOARDREQUEST._serialized_start=695
  _UPDATEUSERDASHBOARDREQUEST._serialized_end=1154
  _UPDATEUSERDASHBOARDREQUEST_PERIODTYPE._serialized_start=649
  _UPDATEUSERDASHBOARDREQUEST_PERIODTYPE._serialized_end=692
  _USERDASHBOARDREQUEST._serialized_start=1156
  _USERDASHBOARDREQUEST._serialized_end=1224
  _GETUSERDASHBOARDREQUEST._serialized_start=1226
  _GETUSERDASHBOARDREQUEST._serialized_end=1311
  _USERDASHBOARDQUERY._serialized_start=1314
  _USERDASHBOARDQUERY._serialized_end=1583
  _USERDASHBOARDQUERY_PERIODTYPE._serialized_start=649
  _USERDASHBOARDQUERY_PERIODTYPE._serialized_end=692
  _USERDASHBOARDINFO._serialized_start=1586
  _USERDASHBOARDINFO._serialized_end=2084
  _USERDASHBOARDINFO_PERIODTYPE._serialized_start=649
  _USERDASHBOARDINFO_PERIODTYPE._serialized_end=692
  _USERDASHBOARDSINFO._serialized_start=2086
  _USERDASHBOARDSINFO._serialized_end=2194
  _USERDASHBOARDSTATQUERY._serialized_start=2196
  _USERDASHBOARDSTATQUERY._serialized_end=2293
  _USERDASHBOARD._serialized_start=2296
  _USERDASHBOARD._serialized_end=3317
# @@protoc_insertion_point(module_scope)
