# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: spaceone/api/notification/v1/protocol.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from spaceone.api.core.v1 import query_pb2 as spaceone_dot_api_dot_core_dot_v1_dot_query__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n+spaceone/api/notification/v1/protocol.proto\x12\x1cspaceone.api.notification.v1\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1cgoogle/api/annotations.proto\x1a spaceone/api/core/v1/query.proto\"\x99\x02\n\rPluginRequest\x12\x11\n\tplugin_id\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\t\x12(\n\x07options\x18\x03 \x01(\x0b\x32\x17.google.protobuf.Struct\x12,\n\x0bsecret_data\x18\x04 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x0e\n\x06schema\x18\x05 \x01(\t\x12M\n\x0cupgrade_mode\x18\x06 \x01(\x0e\x32\x37.spaceone.api.notification.v1.PluginRequest.UpgradeMode\"-\n\x0bUpgradeMode\x12\x08\n\x04NONE\x10\x00\x12\x08\n\x04\x41UTO\x10\x01\x12\n\n\x06MANUAL\x10\x02\"\x93\x02\n\nPluginInfo\x12\x11\n\tplugin_id\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\t\x12(\n\x07options\x18\x03 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x11\n\tsecret_id\x18\x04 \x01(\t\x12)\n\x08metadata\x18\x06 \x01(\x0b\x32\x17.google.protobuf.Struct\x12J\n\x0cupgrade_mode\x18\x07 \x01(\x0e\x32\x34.spaceone.api.notification.v1.PluginInfo.UpgradeMode\"-\n\x0bUpgradeMode\x12\x08\n\x04NONE\x10\x00\x12\x08\n\x04\x41UTO\x10\x01\x12\n\n\x06MANUAL\x10\x02\"\xa1\x01\n\x15\x43reateProtocolRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12@\n\x0bplugin_info\x18\x02 \x01(\x0b\x32+.spaceone.api.notification.v1.PluginRequest\x12%\n\x04tags\x18\x03 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x11\n\tdomain_id\x18\x0c \x01(\t\"t\n\x15UpdateProtocolRequest\x12\x13\n\x0bprotocol_id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12%\n\x04tags\x18\x03 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x11\n\tdomain_id\x18\x0b \x01(\t\"\x80\x01\n\x1bUpdateProtocolPluginRequest\x12\x13\n\x0bprotocol_id\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\t\x12(\n\x07options\x18\x03 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x11\n\tdomain_id\x18\x0b \x01(\t\"9\n\x0fProtocolRequest\x12\x13\n\x0bprotocol_id\x18\x01 \x01(\t\x12\x11\n\tdomain_id\x18\x02 \x01(\t\"J\n\x12GetProtocolRequest\x12\x13\n\x0bprotocol_id\x18\x01 \x01(\t\x12\x11\n\tdomain_id\x18\x02 \x01(\t\x12\x0c\n\x04only\x18\x03 \x03(\t\"\x86\x03\n\rProtocolQuery\x12*\n\x05query\x18\x01 \x01(\x0b\x32\x1b.spaceone.api.core.v1.Query\x12\x13\n\x0bprotocol_id\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12H\n\x05state\x18\x04 \x01(\x0e\x32\x39.spaceone.api.notification.v1.ProtocolQuery.ProtocolState\x12O\n\rprotocol_type\x18\x05 \x01(\x0e\x32\x38.spaceone.api.notification.v1.ProtocolQuery.ProtocolType\x12\x11\n\tdomain_id\x18\x0b \x01(\t\"4\n\rProtocolState\x12\x08\n\x04NONE\x10\x00\x12\x0b\n\x07\x45NABLED\x10\x01\x12\x0c\n\x08\x44ISABLED\x10\x02\"B\n\x0cProtocolType\x12\x16\n\x12PROTOCOL_TYPE_NONE\x10\x00\x12\x0c\n\x08INTERNAL\x10\x01\x12\x0c\n\x08\x45XTERNAL\x10\x02\"\x95\x04\n\x0cProtocolInfo\x12\x13\n\x0bprotocol_id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12G\n\x05state\x18\x03 \x01(\x0e\x32\x38.spaceone.api.notification.v1.ProtocolInfo.ProtocolState\x12N\n\rprotocol_type\x18\x04 \x01(\x0e\x32\x37.spaceone.api.notification.v1.ProtocolInfo.ProtocolType\x12\x15\n\rresource_type\x18\x05 \x01(\t\x12+\n\ncapability\x18\x06 \x01(\x0b\x32\x17.google.protobuf.Struct\x12=\n\x0bplugin_info\x18\x07 \x01(\x0b\x32(.spaceone.api.notification.v1.PluginInfo\x12%\n\x04tags\x18\x08 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x11\n\tdomain_id\x18\x0b \x01(\t\x12\x12\n\ncreated_at\x18\x15 \x01(\t\"4\n\rProtocolState\x12\x08\n\x04NONE\x10\x00\x12\x0b\n\x07\x45NABLED\x10\x01\x12\x0c\n\x08\x44ISABLED\x10\x02\"B\n\x0cProtocolType\x12\x16\n\x12PROTOCOL_TYPE_NONE\x10\x00\x12\x0c\n\x08INTERNAL\x10\x01\x12\x0c\n\x08\x45XTERNAL\x10\x02\"a\n\rProtocolsInfo\x12;\n\x07results\x18\x01 \x03(\x0b\x32*.spaceone.api.notification.v1.ProtocolInfo\x12\x13\n\x0btotal_count\x18\x02 \x01(\x05\"\\\n\x11ProtocolStatQuery\x12\x34\n\x05query\x18\x01 \x01(\x0b\x32%.spaceone.api.core.v1.StatisticsQuery\x12\x11\n\tdomain_id\x18\x02 \x01(\t2\xe7\n\n\x08Protocol\x12\x8d\x01\n\x06\x63reate\x12\x33.spaceone.api.notification.v1.CreateProtocolRequest\x1a*.spaceone.api.notification.v1.ProtocolInfo\"\"\x82\xd3\xe4\x93\x02\x1c\"\x1a/notification/v1/protocols\x12\x9a\x01\n\x06update\x12\x33.spaceone.api.notification.v1.UpdateProtocolRequest\x1a*.spaceone.api.notification.v1.ProtocolInfo\"/\x82\xd3\xe4\x93\x02)\x1a\'/notification/v1/protocol/{protocol_id}\x12\xae\x01\n\rupdate_plugin\x12\x39.spaceone.api.notification.v1.UpdateProtocolPluginRequest\x1a*.spaceone.api.notification.v1.ProtocolInfo\"6\x82\xd3\xe4\x93\x02\x30\x1a./notification/v1/protocol/{protocol_id}/plugin\x12\x9b\x01\n\x06\x65nable\x12-.spaceone.api.notification.v1.ProtocolRequest\x1a*.spaceone.api.notification.v1.ProtocolInfo\"6\x82\xd3\xe4\x93\x02\x30\x1a./notification/v1/protocol/{protocol_id}/enable\x12\x9d\x01\n\x07\x64isable\x12-.spaceone.api.notification.v1.ProtocolRequest\x1a*.spaceone.api.notification.v1.ProtocolInfo\"7\x82\xd3\xe4\x93\x02\x31\x1a//notification/v1/protocol/{protocol_id}/disable\x12\x80\x01\n\x06\x64\x65lete\x12-.spaceone.api.notification.v1.ProtocolRequest\x1a\x16.google.protobuf.Empty\"/\x82\xd3\xe4\x93\x02)*\'/notification/v1/protocol/{protocol_id}\x12\x94\x01\n\x03get\x12\x30.spaceone.api.notification.v1.GetProtocolRequest\x1a*.spaceone.api.notification.v1.ProtocolInfo\"/\x82\xd3\xe4\x93\x02)\x12\'/notification/v1/protocol/{protocol_id}\x12\xa9\x01\n\x04list\x12+.spaceone.api.notification.v1.ProtocolQuery\x1a+.spaceone.api.notification.v1.ProtocolsInfo\"G\x82\xd3\xe4\x93\x02\x41\x12\x1a/notification/v1/protocolsZ#\"!/notification/v1/protocols/search\x12y\n\x04stat\x12/.spaceone.api.notification.v1.ProtocolStatQuery\x1a\x17.google.protobuf.Struct\"\'\x82\xd3\xe4\x93\x02!\"\x1f/notification/v1/protocols/statb\x06proto3')



_PLUGINREQUEST = DESCRIPTOR.message_types_by_name['PluginRequest']
_PLUGININFO = DESCRIPTOR.message_types_by_name['PluginInfo']
_CREATEPROTOCOLREQUEST = DESCRIPTOR.message_types_by_name['CreateProtocolRequest']
_UPDATEPROTOCOLREQUEST = DESCRIPTOR.message_types_by_name['UpdateProtocolRequest']
_UPDATEPROTOCOLPLUGINREQUEST = DESCRIPTOR.message_types_by_name['UpdateProtocolPluginRequest']
_PROTOCOLREQUEST = DESCRIPTOR.message_types_by_name['ProtocolRequest']
_GETPROTOCOLREQUEST = DESCRIPTOR.message_types_by_name['GetProtocolRequest']
_PROTOCOLQUERY = DESCRIPTOR.message_types_by_name['ProtocolQuery']
_PROTOCOLINFO = DESCRIPTOR.message_types_by_name['ProtocolInfo']
_PROTOCOLSINFO = DESCRIPTOR.message_types_by_name['ProtocolsInfo']
_PROTOCOLSTATQUERY = DESCRIPTOR.message_types_by_name['ProtocolStatQuery']
_PLUGINREQUEST_UPGRADEMODE = _PLUGINREQUEST.enum_types_by_name['UpgradeMode']
_PLUGININFO_UPGRADEMODE = _PLUGININFO.enum_types_by_name['UpgradeMode']
_PROTOCOLQUERY_PROTOCOLSTATE = _PROTOCOLQUERY.enum_types_by_name['ProtocolState']
_PROTOCOLQUERY_PROTOCOLTYPE = _PROTOCOLQUERY.enum_types_by_name['ProtocolType']
_PROTOCOLINFO_PROTOCOLSTATE = _PROTOCOLINFO.enum_types_by_name['ProtocolState']
_PROTOCOLINFO_PROTOCOLTYPE = _PROTOCOLINFO.enum_types_by_name['ProtocolType']
PluginRequest = _reflection.GeneratedProtocolMessageType('PluginRequest', (_message.Message,), {
  'DESCRIPTOR' : _PLUGINREQUEST,
  '__module__' : 'spaceone.api.notification.v1.protocol_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.notification.v1.PluginRequest)
  })
_sym_db.RegisterMessage(PluginRequest)

PluginInfo = _reflection.GeneratedProtocolMessageType('PluginInfo', (_message.Message,), {
  'DESCRIPTOR' : _PLUGININFO,
  '__module__' : 'spaceone.api.notification.v1.protocol_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.notification.v1.PluginInfo)
  })
_sym_db.RegisterMessage(PluginInfo)

CreateProtocolRequest = _reflection.GeneratedProtocolMessageType('CreateProtocolRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEPROTOCOLREQUEST,
  '__module__' : 'spaceone.api.notification.v1.protocol_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.notification.v1.CreateProtocolRequest)
  })
_sym_db.RegisterMessage(CreateProtocolRequest)

UpdateProtocolRequest = _reflection.GeneratedProtocolMessageType('UpdateProtocolRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEPROTOCOLREQUEST,
  '__module__' : 'spaceone.api.notification.v1.protocol_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.notification.v1.UpdateProtocolRequest)
  })
_sym_db.RegisterMessage(UpdateProtocolRequest)

UpdateProtocolPluginRequest = _reflection.GeneratedProtocolMessageType('UpdateProtocolPluginRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEPROTOCOLPLUGINREQUEST,
  '__module__' : 'spaceone.api.notification.v1.protocol_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.notification.v1.UpdateProtocolPluginRequest)
  })
_sym_db.RegisterMessage(UpdateProtocolPluginRequest)

ProtocolRequest = _reflection.GeneratedProtocolMessageType('ProtocolRequest', (_message.Message,), {
  'DESCRIPTOR' : _PROTOCOLREQUEST,
  '__module__' : 'spaceone.api.notification.v1.protocol_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.notification.v1.ProtocolRequest)
  })
_sym_db.RegisterMessage(ProtocolRequest)

GetProtocolRequest = _reflection.GeneratedProtocolMessageType('GetProtocolRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETPROTOCOLREQUEST,
  '__module__' : 'spaceone.api.notification.v1.protocol_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.notification.v1.GetProtocolRequest)
  })
_sym_db.RegisterMessage(GetProtocolRequest)

ProtocolQuery = _reflection.GeneratedProtocolMessageType('ProtocolQuery', (_message.Message,), {
  'DESCRIPTOR' : _PROTOCOLQUERY,
  '__module__' : 'spaceone.api.notification.v1.protocol_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.notification.v1.ProtocolQuery)
  })
_sym_db.RegisterMessage(ProtocolQuery)

ProtocolInfo = _reflection.GeneratedProtocolMessageType('ProtocolInfo', (_message.Message,), {
  'DESCRIPTOR' : _PROTOCOLINFO,
  '__module__' : 'spaceone.api.notification.v1.protocol_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.notification.v1.ProtocolInfo)
  })
_sym_db.RegisterMessage(ProtocolInfo)

ProtocolsInfo = _reflection.GeneratedProtocolMessageType('ProtocolsInfo', (_message.Message,), {
  'DESCRIPTOR' : _PROTOCOLSINFO,
  '__module__' : 'spaceone.api.notification.v1.protocol_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.notification.v1.ProtocolsInfo)
  })
_sym_db.RegisterMessage(ProtocolsInfo)

ProtocolStatQuery = _reflection.GeneratedProtocolMessageType('ProtocolStatQuery', (_message.Message,), {
  'DESCRIPTOR' : _PROTOCOLSTATQUERY,
  '__module__' : 'spaceone.api.notification.v1.protocol_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.notification.v1.ProtocolStatQuery)
  })
_sym_db.RegisterMessage(ProtocolStatQuery)

_PROTOCOL = DESCRIPTOR.services_by_name['Protocol']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _PROTOCOL.methods_by_name['create']._options = None
  _PROTOCOL.methods_by_name['create']._serialized_options = b'\202\323\344\223\002\034\"\032/notification/v1/protocols'
  _PROTOCOL.methods_by_name['update']._options = None
  _PROTOCOL.methods_by_name['update']._serialized_options = b'\202\323\344\223\002)\032\'/notification/v1/protocol/{protocol_id}'
  _PROTOCOL.methods_by_name['update_plugin']._options = None
  _PROTOCOL.methods_by_name['update_plugin']._serialized_options = b'\202\323\344\223\0020\032./notification/v1/protocol/{protocol_id}/plugin'
  _PROTOCOL.methods_by_name['enable']._options = None
  _PROTOCOL.methods_by_name['enable']._serialized_options = b'\202\323\344\223\0020\032./notification/v1/protocol/{protocol_id}/enable'
  _PROTOCOL.methods_by_name['disable']._options = None
  _PROTOCOL.methods_by_name['disable']._serialized_options = b'\202\323\344\223\0021\032//notification/v1/protocol/{protocol_id}/disable'
  _PROTOCOL.methods_by_name['delete']._options = None
  _PROTOCOL.methods_by_name['delete']._serialized_options = b'\202\323\344\223\002)*\'/notification/v1/protocol/{protocol_id}'
  _PROTOCOL.methods_by_name['get']._options = None
  _PROTOCOL.methods_by_name['get']._serialized_options = b'\202\323\344\223\002)\022\'/notification/v1/protocol/{protocol_id}'
  _PROTOCOL.methods_by_name['list']._options = None
  _PROTOCOL.methods_by_name['list']._serialized_options = b'\202\323\344\223\002A\022\032/notification/v1/protocolsZ#\"!/notification/v1/protocols/search'
  _PROTOCOL.methods_by_name['stat']._options = None
  _PROTOCOL.methods_by_name['stat']._serialized_options = b'\202\323\344\223\002!\"\037/notification/v1/protocols/stat'
  _PLUGINREQUEST._serialized_start=201
  _PLUGINREQUEST._serialized_end=482
  _PLUGINREQUEST_UPGRADEMODE._serialized_start=437
  _PLUGINREQUEST_UPGRADEMODE._serialized_end=482
  _PLUGININFO._serialized_start=485
  _PLUGININFO._serialized_end=760
  _PLUGININFO_UPGRADEMODE._serialized_start=437
  _PLUGININFO_UPGRADEMODE._serialized_end=482
  _CREATEPROTOCOLREQUEST._serialized_start=763
  _CREATEPROTOCOLREQUEST._serialized_end=924
  _UPDATEPROTOCOLREQUEST._serialized_start=926
  _UPDATEPROTOCOLREQUEST._serialized_end=1042
  _UPDATEPROTOCOLPLUGINREQUEST._serialized_start=1045
  _UPDATEPROTOCOLPLUGINREQUEST._serialized_end=1173
  _PROTOCOLREQUEST._serialized_start=1175
  _PROTOCOLREQUEST._serialized_end=1232
  _GETPROTOCOLREQUEST._serialized_start=1234
  _GETPROTOCOLREQUEST._serialized_end=1308
  _PROTOCOLQUERY._serialized_start=1311
  _PROTOCOLQUERY._serialized_end=1701
  _PROTOCOLQUERY_PROTOCOLSTATE._serialized_start=1581
  _PROTOCOLQUERY_PROTOCOLSTATE._serialized_end=1633
  _PROTOCOLQUERY_PROTOCOLTYPE._serialized_start=1635
  _PROTOCOLQUERY_PROTOCOLTYPE._serialized_end=1701
  _PROTOCOLINFO._serialized_start=1704
  _PROTOCOLINFO._serialized_end=2237
  _PROTOCOLINFO_PROTOCOLSTATE._serialized_start=1581
  _PROTOCOLINFO_PROTOCOLSTATE._serialized_end=1633
  _PROTOCOLINFO_PROTOCOLTYPE._serialized_start=1635
  _PROTOCOLINFO_PROTOCOLTYPE._serialized_end=1701
  _PROTOCOLSINFO._serialized_start=2239
  _PROTOCOLSINFO._serialized_end=2336
  _PROTOCOLSTATQUERY._serialized_start=2338
  _PROTOCOLSTATQUERY._serialized_end=2430
  _PROTOCOL._serialized_start=2433
  _PROTOCOL._serialized_end=3816
# @@protoc_insertion_point(module_scope)
