# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: spaceone/api/provisioning/v1/resource_group.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from spaceone.api.core.v1 import query_pb2 as spaceone_dot_api_dot_core_dot_v1_dot_query__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n1spaceone/api/provisioning/v1/resource_group.proto\x12\x1cspaceone.api.provisioning.v1\x1a\x1cgoogle/api/annotations.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a spaceone/api/core/v1/query.proto\"\x8b\x01\n\x12ResourceGroupQuery\x12*\n\x05query\x18\x01 \x01(\x0b\x32\x1b.spaceone.api.core.v1.Query\x12\x19\n\x11resource_group_id\x18\x02 \x01(\t\x12\x1b\n\x13resource_group_name\x18\x03 \x01(\t\x12\x11\n\tdomain_id\x18\x04 \x01(\t\"M\n\x1a\x43reateResourceGroupRequest\x12\x1b\n\x13resource_group_name\x18\x01 \x01(\t\x12\x12\n\nsort_order\x18\x02 \x01(\t\"h\n\x1aUpdateResourceGroupRequest\x12\x19\n\x11resource_group_id\x18\x01 \x01(\t\x12\x1b\n\x13resource_group_name\x18\x02 \x01(\t\x12\x12\n\nsort_order\x18\x03 \x01(\x05\"D\n\x14ResourceGroupRequest\x12\x19\n\x11resource_group_id\x18\x01 \x01(\t\x12\x11\n\tdomain_id\x18\x02 \x01(\t\"a\n\x16ResourceGroupStatQuery\x12\x34\n\x05query\x18\x01 \x01(\x0b\x32%.spaceone.api.core.v1.StatisticsQuery\x12\x11\n\tdomain_id\x18\x02 \x01(\t\"\x9a\x01\n\x11ResourceGroupInfo\x12\x11\n\tdomain_id\x18\x01 \x01(\t\x12\x19\n\x11resource_group_id\x18\x02 \x01(\t\x12\x1b\n\x13resource_group_name\x18\x03 \x01(\t\x12\x12\n\nsort_order\x18\x04 \x01(\x05\x12\x12\n\ncreated_at\x18\x05 \x01(\t\x12\x12\n\nupdated_at\x18\x06 \x01(\t\"k\n\x12ResourceGroupsInfo\x12@\n\x07results\x18\x01 \x03(\x0b\x32/.spaceone.api.provisioning.v1.ResourceGroupInfo\x12\x13\n\x0btotal_count\x18\x02 \x01(\x05\x32\x9e\x08\n\rResourceGroup\x12\xab\x01\n\x15\x63reate_resource_group\x12\x38.spaceone.api.provisioning.v1.CreateResourceGroupRequest\x1a/.spaceone.api.provisioning.v1.ResourceGroupInfo\"\'\x82\xd3\xe4\x93\x02!\"\x1f/provisioning/v1/resource-group\x12\xce\x01\n\x13get_resource_groups\x12\x30.spaceone.api.provisioning.v1.ResourceGroupQuery\x1a\x30.spaceone.api.provisioning.v1.ResourceGroupsInfo\"S\x82\xd3\xe4\x93\x02M\x12 /provisioning/v1/resource-groupsZ)\"\'/provisioning/v1/resource-groups/search\x12\xb6\x01\n\x12get_resource_group\x12\x32.spaceone.api.provisioning.v1.ResourceGroupRequest\x1a/.spaceone.api.provisioning.v1.ResourceGroupInfo\";\x82\xd3\xe4\x93\x02\x35\x12\x33/provisioning/v1/resource-group/{resource_group_id}\x12\xab\x01\n\x15update_resource_group\x12\x38.spaceone.api.provisioning.v1.UpdateResourceGroupRequest\x1a/.spaceone.api.provisioning.v1.ResourceGroupInfo\"\'\x82\xd3\xe4\x93\x02!\x1a\x1f/provisioning/v1/resource-group\x12\xa0\x01\n\x15\x64\x65lete_resource_group\x12\x32.spaceone.api.provisioning.v1.ResourceGroupRequest\x1a\x16.google.protobuf.Empty\";\x82\xd3\xe4\x93\x02\x35*3/provisioning/v1/resource-group/{resource_group_id}\x12\x83\x01\n\x04stat\x12\x34.spaceone.api.provisioning.v1.ResourceGroupStatQuery\x1a\x17.google.protobuf.Struct\",\x82\xd3\xe4\x93\x02&\"$/provisioning/v1/resource-group/statb\x06proto3')



_RESOURCEGROUPQUERY = DESCRIPTOR.message_types_by_name['ResourceGroupQuery']
_CREATERESOURCEGROUPREQUEST = DESCRIPTOR.message_types_by_name['CreateResourceGroupRequest']
_UPDATERESOURCEGROUPREQUEST = DESCRIPTOR.message_types_by_name['UpdateResourceGroupRequest']
_RESOURCEGROUPREQUEST = DESCRIPTOR.message_types_by_name['ResourceGroupRequest']
_RESOURCEGROUPSTATQUERY = DESCRIPTOR.message_types_by_name['ResourceGroupStatQuery']
_RESOURCEGROUPINFO = DESCRIPTOR.message_types_by_name['ResourceGroupInfo']
_RESOURCEGROUPSINFO = DESCRIPTOR.message_types_by_name['ResourceGroupsInfo']
ResourceGroupQuery = _reflection.GeneratedProtocolMessageType('ResourceGroupQuery', (_message.Message,), {
  'DESCRIPTOR' : _RESOURCEGROUPQUERY,
  '__module__' : 'spaceone.api.provisioning.v1.resource_group_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.provisioning.v1.ResourceGroupQuery)
  })
_sym_db.RegisterMessage(ResourceGroupQuery)

CreateResourceGroupRequest = _reflection.GeneratedProtocolMessageType('CreateResourceGroupRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATERESOURCEGROUPREQUEST,
  '__module__' : 'spaceone.api.provisioning.v1.resource_group_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.provisioning.v1.CreateResourceGroupRequest)
  })
_sym_db.RegisterMessage(CreateResourceGroupRequest)

UpdateResourceGroupRequest = _reflection.GeneratedProtocolMessageType('UpdateResourceGroupRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATERESOURCEGROUPREQUEST,
  '__module__' : 'spaceone.api.provisioning.v1.resource_group_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.provisioning.v1.UpdateResourceGroupRequest)
  })
_sym_db.RegisterMessage(UpdateResourceGroupRequest)

ResourceGroupRequest = _reflection.GeneratedProtocolMessageType('ResourceGroupRequest', (_message.Message,), {
  'DESCRIPTOR' : _RESOURCEGROUPREQUEST,
  '__module__' : 'spaceone.api.provisioning.v1.resource_group_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.provisioning.v1.ResourceGroupRequest)
  })
_sym_db.RegisterMessage(ResourceGroupRequest)

ResourceGroupStatQuery = _reflection.GeneratedProtocolMessageType('ResourceGroupStatQuery', (_message.Message,), {
  'DESCRIPTOR' : _RESOURCEGROUPSTATQUERY,
  '__module__' : 'spaceone.api.provisioning.v1.resource_group_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.provisioning.v1.ResourceGroupStatQuery)
  })
_sym_db.RegisterMessage(ResourceGroupStatQuery)

ResourceGroupInfo = _reflection.GeneratedProtocolMessageType('ResourceGroupInfo', (_message.Message,), {
  'DESCRIPTOR' : _RESOURCEGROUPINFO,
  '__module__' : 'spaceone.api.provisioning.v1.resource_group_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.provisioning.v1.ResourceGroupInfo)
  })
_sym_db.RegisterMessage(ResourceGroupInfo)

ResourceGroupsInfo = _reflection.GeneratedProtocolMessageType('ResourceGroupsInfo', (_message.Message,), {
  'DESCRIPTOR' : _RESOURCEGROUPSINFO,
  '__module__' : 'spaceone.api.provisioning.v1.resource_group_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.provisioning.v1.ResourceGroupsInfo)
  })
_sym_db.RegisterMessage(ResourceGroupsInfo)

_RESOURCEGROUP = DESCRIPTOR.services_by_name['ResourceGroup']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _RESOURCEGROUP.methods_by_name['create_resource_group']._options = None
  _RESOURCEGROUP.methods_by_name['create_resource_group']._serialized_options = b'\202\323\344\223\002!\"\037/provisioning/v1/resource-group'
  _RESOURCEGROUP.methods_by_name['get_resource_groups']._options = None
  _RESOURCEGROUP.methods_by_name['get_resource_groups']._serialized_options = b'\202\323\344\223\002M\022 /provisioning/v1/resource-groupsZ)\"\'/provisioning/v1/resource-groups/search'
  _RESOURCEGROUP.methods_by_name['get_resource_group']._options = None
  _RESOURCEGROUP.methods_by_name['get_resource_group']._serialized_options = b'\202\323\344\223\0025\0223/provisioning/v1/resource-group/{resource_group_id}'
  _RESOURCEGROUP.methods_by_name['update_resource_group']._options = None
  _RESOURCEGROUP.methods_by_name['update_resource_group']._serialized_options = b'\202\323\344\223\002!\032\037/provisioning/v1/resource-group'
  _RESOURCEGROUP.methods_by_name['delete_resource_group']._options = None
  _RESOURCEGROUP.methods_by_name['delete_resource_group']._serialized_options = b'\202\323\344\223\0025*3/provisioning/v1/resource-group/{resource_group_id}'
  _RESOURCEGROUP.methods_by_name['stat']._options = None
  _RESOURCEGROUP.methods_by_name['stat']._serialized_options = b'\202\323\344\223\002&\"$/provisioning/v1/resource-group/stat'
  _RESOURCEGROUPQUERY._serialized_start=207
  _RESOURCEGROUPQUERY._serialized_end=346
  _CREATERESOURCEGROUPREQUEST._serialized_start=348
  _CREATERESOURCEGROUPREQUEST._serialized_end=425
  _UPDATERESOURCEGROUPREQUEST._serialized_start=427
  _UPDATERESOURCEGROUPREQUEST._serialized_end=531
  _RESOURCEGROUPREQUEST._serialized_start=533
  _RESOURCEGROUPREQUEST._serialized_end=601
  _RESOURCEGROUPSTATQUERY._serialized_start=603
  _RESOURCEGROUPSTATQUERY._serialized_end=700
  _RESOURCEGROUPINFO._serialized_start=703
  _RESOURCEGROUPINFO._serialized_end=857
  _RESOURCEGROUPSINFO._serialized_start=859
  _RESOURCEGROUPSINFO._serialized_end=966
  _RESOURCEGROUP._serialized_start=969
  _RESOURCEGROUP._serialized_end=2023
# @@protoc_insertion_point(module_scope)
