# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: spaceone/api/notification/v1/project_channel.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from spaceone.api.core.v1 import query_pb2 as spaceone_dot_api_dot_core_dot_v1_dot_query__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n2spaceone/api/notification/v1/project_channel.proto\x12\x1cspaceone.api.notification.v1\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1cgoogle/api/annotations.proto\x1a spaceone/api/core/v1/query.proto\"\xe9\x01\n\x16ProjectChannelSchedule\x12S\n\x0b\x64\x61y_of_week\x18\x01 \x03(\x0e\x32>.spaceone.api.notification.v1.ProjectChannelSchedule.DayOfWeek\x12\x12\n\nstart_hour\x18\x02 \x01(\x05\x12\x10\n\x08\x65nd_hour\x18\x03 \x01(\x05\"T\n\tDayOfWeek\x12\x08\n\x04NONE\x10\x00\x12\x07\n\x03MON\x10\x01\x12\x07\n\x03TUE\x10\x02\x12\x07\n\x03WED\x10\x03\x12\x07\n\x03THU\x10\x04\x12\x07\n\x03\x46RI\x10\x05\x12\x07\n\x03SAT\x10\x06\x12\x07\n\x03SUN\x10\x07\"\x8d\x03\n\x1b\x43reateProjectChannelRequest\x12\x13\n\x0bprotocol_id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12%\n\x04\x64\x61ta\x18\x03 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x14\n\x0cis_subscribe\x18\x04 \x01(\x08\x12\x15\n\rsubscriptions\x18\x05 \x03(\t\x12K\n\x12notification_level\x18\x06 \x01(\x0e\x32/.spaceone.api.notification.v1.NotificationLevel\x12\x14\n\x0cis_scheduled\x18\x07 \x01(\x08\x12\x46\n\x08schedule\x18\x08 \x01(\x0b\x32\x34.spaceone.api.notification.v1.ProjectChannelSchedule\x12%\n\x04tags\x18\t \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x12\n\nproject_id\x18\x15 \x01(\t\x12\x11\n\tdomain_id\x18\x16 \x01(\t\"\xf5\x01\n\x1bUpdateProjectChannelRequest\x12\x1a\n\x12project_channel_id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12%\n\x04\x64\x61ta\x18\x03 \x01(\x0b\x32\x17.google.protobuf.Struct\x12K\n\x12notification_level\x18\x05 \x01(\x0e\x32/.spaceone.api.notification.v1.NotificationLevel\x12%\n\x04tags\x18\x07 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x11\n\tdomain_id\x18\x0b \x01(\t\"\xb2\x01\n#UpdateProjectChannelScheduleRequest\x12\x1a\n\x12project_channel_id\x18\x01 \x01(\t\x12\x14\n\x0cis_scheduled\x18\x02 \x01(\x08\x12\x46\n\x08schedule\x18\x03 \x01(\x0b\x32\x34.spaceone.api.notification.v1.ProjectChannelSchedule\x12\x11\n\tdomain_id\x18\x04 \x01(\t\"\x85\x01\n\'UpdateProjectChannelSubscriptionRequest\x12\x1a\n\x12project_channel_id\x18\x01 \x01(\t\x12\x14\n\x0cis_subscribe\x18\x02 \x01(\x08\x12\x15\n\rsubscriptions\x18\x03 \x03(\t\x12\x11\n\tdomain_id\x18\x04 \x01(\t\"F\n\x15ProjectChannelRequest\x12\x1a\n\x12project_channel_id\x18\x01 \x01(\t\x12\x11\n\tdomain_id\x18\x02 \x01(\t\"W\n\x18GetProjectChannelRequest\x12\x1a\n\x12project_channel_id\x18\x01 \x01(\t\x12\x11\n\tdomain_id\x18\x02 \x01(\t\x12\x0c\n\x04only\x18\x03 \x03(\t\"\x99\x03\n\x13ProjectChannelQuery\x12*\n\x05query\x18\x01 \x01(\x0b\x32\x1b.spaceone.api.core.v1.Query\x12\x1a\n\x12project_channel_id\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12T\n\x05state\x18\x04 \x01(\x0e\x32\x45.spaceone.api.notification.v1.ProjectChannelQuery.ProjectChannelState\x12\x11\n\tsecret_id\x18\x05 \x01(\t\x12K\n\x12notification_level\x18\x06 \x01(\x0e\x32/.spaceone.api.notification.v1.NotificationLevel\x12\x13\n\x0bprotocol_id\x18\x0b \x01(\t\x12\x12\n\nproject_id\x18\x0c \x01(\t\x12\x11\n\tdomain_id\x18\r \x01(\t\":\n\x13ProjectChannelState\x12\x08\n\x04NONE\x10\x00\x12\x0b\n\x07\x45NABLED\x10\x01\x12\x0c\n\x08\x44ISABLED\x10\x02\"\xd8\x04\n\x12ProjectChannelInfo\x12\x1a\n\x12project_channel_id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12S\n\x05state\x18\x03 \x01(\x0e\x32\x44.spaceone.api.notification.v1.ProjectChannelInfo.ProjectChannelState\x12%\n\x04\x64\x61ta\x18\x04 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x11\n\tsecret_id\x18\x05 \x01(\t\x12\x14\n\x0cis_subscribe\x18\x06 \x01(\x08\x12\x15\n\rsubscriptions\x18\x07 \x03(\t\x12K\n\x12notification_level\x18\x08 \x01(\x0e\x32/.spaceone.api.notification.v1.NotificationLevel\x12\x14\n\x0cis_scheduled\x18\t \x01(\x08\x12\x46\n\x08schedule\x18\n \x01(\x0b\x32\x34.spaceone.api.notification.v1.ProjectChannelSchedule\x12%\n\x04tags\x18\x0b \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x13\n\x0bprotocol_id\x18\x15 \x01(\t\x12\x12\n\nproject_id\x18\x16 \x01(\t\x12\x11\n\tdomain_id\x18\x17 \x01(\t\x12\x12\n\ncreated_at\x18\x1f \x01(\t\":\n\x13ProjectChannelState\x12\x08\n\x04NONE\x10\x00\x12\x0b\n\x07\x45NABLED\x10\x01\x12\x0c\n\x08\x44ISABLED\x10\x02\"m\n\x13ProjectChannelsInfo\x12\x41\n\x07results\x18\x01 \x03(\x0b\x32\x30.spaceone.api.notification.v1.ProjectChannelInfo\x12\x13\n\x0btotal_count\x18\x02 \x01(\x05\"b\n\x17ProjectChannelStatQuery\x12\x34\n\x05query\x18\x01 \x01(\x0b\x32%.spaceone.api.core.v1.StatisticsQuery\x12\x11\n\tdomain_id\x18\x02 \x01(\t*J\n\x11NotificationLevel\x12\x08\n\x04NONE\x10\x00\x12\x07\n\x03LV1\x10\x01\x12\x07\n\x03LV2\x10\x02\x12\x07\n\x03LV3\x10\x03\x12\x07\n\x03LV4\x10\x04\x12\x07\n\x03LV5\x10\x05\x32\x9b\x0e\n\x0eProjectChannel\x12\xa0\x01\n\x06\x63reate\x12\x39.spaceone.api.notification.v1.CreateProjectChannelRequest\x1a\x30.spaceone.api.notification.v1.ProjectChannelInfo\")\x82\xd3\xe4\x93\x02#\"!/notification/v1/project-channels\x12\xb4\x01\n\x06update\x12\x39.spaceone.api.notification.v1.UpdateProjectChannelRequest\x1a\x30.spaceone.api.notification.v1.ProjectChannelInfo\"=\x82\xd3\xe4\x93\x02\x37\x1a\x35/notification/v1/project-channel/{project_channel_id}\x12\xcb\x01\n\x0cset_schedule\x12\x41.spaceone.api.notification.v1.UpdateProjectChannelScheduleRequest\x1a\x30.spaceone.api.notification.v1.ProjectChannelInfo\"F\x82\xd3\xe4\x93\x02@\x1a>/notification/v1/project-channel/{project_channel_id}/schedule\x12\xd7\x01\n\x10set_subscription\x12\x45.spaceone.api.notification.v1.UpdateProjectChannelSubscriptionRequest\x1a\x30.spaceone.api.notification.v1.ProjectChannelInfo\"J\x82\xd3\xe4\x93\x02\x44\x1a\x42/notification/v1/project-channel/{project_channel_id}/subscription\x12\xb5\x01\n\x06\x65nable\x12\x33.spaceone.api.notification.v1.ProjectChannelRequest\x1a\x30.spaceone.api.notification.v1.ProjectChannelInfo\"D\x82\xd3\xe4\x93\x02>\x1a</notification/v1/project-channel/{project_channel_id}/enable\x12\xb7\x01\n\x07\x64isable\x12\x33.spaceone.api.notification.v1.ProjectChannelRequest\x1a\x30.spaceone.api.notification.v1.ProjectChannelInfo\"E\x82\xd3\xe4\x93\x02?\x1a=/notification/v1/project-channel/{project_channel_id}/disable\x12\x94\x01\n\x06\x64\x65lete\x12\x33.spaceone.api.notification.v1.ProjectChannelRequest\x1a\x16.google.protobuf.Empty\"=\x82\xd3\xe4\x93\x02\x37*5/notification/v1/project-channel/{project_channel_id}\x12\xae\x01\n\x03get\x12\x36.spaceone.api.notification.v1.GetProjectChannelRequest\x1a\x30.spaceone.api.notification.v1.ProjectChannelInfo\"=\x82\xd3\xe4\x93\x02\x37\x12\x35/notification/v1/project-channel/{project_channel_id}\x12\xc3\x01\n\x04list\x12\x31.spaceone.api.notification.v1.ProjectChannelQuery\x1a\x31.spaceone.api.notification.v1.ProjectChannelsInfo\"U\x82\xd3\xe4\x93\x02O\x12!/notification/v1/project-channelsZ*\"(/notification/v1/project-channels/search\x12\x86\x01\n\x04stat\x12\x35.spaceone.api.notification.v1.ProjectChannelStatQuery\x1a\x17.google.protobuf.Struct\".\x82\xd3\xe4\x93\x02(\"&/notification/v1/project-channels/statb\x06proto3')

_NOTIFICATIONLEVEL = DESCRIPTOR.enum_types_by_name['NotificationLevel']
NotificationLevel = enum_type_wrapper.EnumTypeWrapper(_NOTIFICATIONLEVEL)
NONE = 0
LV1 = 1
LV2 = 2
LV3 = 3
LV4 = 4
LV5 = 5


_PROJECTCHANNELSCHEDULE = DESCRIPTOR.message_types_by_name['ProjectChannelSchedule']
_CREATEPROJECTCHANNELREQUEST = DESCRIPTOR.message_types_by_name['CreateProjectChannelRequest']
_UPDATEPROJECTCHANNELREQUEST = DESCRIPTOR.message_types_by_name['UpdateProjectChannelRequest']
_UPDATEPROJECTCHANNELSCHEDULEREQUEST = DESCRIPTOR.message_types_by_name['UpdateProjectChannelScheduleRequest']
_UPDATEPROJECTCHANNELSUBSCRIPTIONREQUEST = DESCRIPTOR.message_types_by_name['UpdateProjectChannelSubscriptionRequest']
_PROJECTCHANNELREQUEST = DESCRIPTOR.message_types_by_name['ProjectChannelRequest']
_GETPROJECTCHANNELREQUEST = DESCRIPTOR.message_types_by_name['GetProjectChannelRequest']
_PROJECTCHANNELQUERY = DESCRIPTOR.message_types_by_name['ProjectChannelQuery']
_PROJECTCHANNELINFO = DESCRIPTOR.message_types_by_name['ProjectChannelInfo']
_PROJECTCHANNELSINFO = DESCRIPTOR.message_types_by_name['ProjectChannelsInfo']
_PROJECTCHANNELSTATQUERY = DESCRIPTOR.message_types_by_name['ProjectChannelStatQuery']
_PROJECTCHANNELSCHEDULE_DAYOFWEEK = _PROJECTCHANNELSCHEDULE.enum_types_by_name['DayOfWeek']
_PROJECTCHANNELQUERY_PROJECTCHANNELSTATE = _PROJECTCHANNELQUERY.enum_types_by_name['ProjectChannelState']
_PROJECTCHANNELINFO_PROJECTCHANNELSTATE = _PROJECTCHANNELINFO.enum_types_by_name['ProjectChannelState']
ProjectChannelSchedule = _reflection.GeneratedProtocolMessageType('ProjectChannelSchedule', (_message.Message,), {
  'DESCRIPTOR' : _PROJECTCHANNELSCHEDULE,
  '__module__' : 'spaceone.api.notification.v1.project_channel_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.notification.v1.ProjectChannelSchedule)
  })
_sym_db.RegisterMessage(ProjectChannelSchedule)

CreateProjectChannelRequest = _reflection.GeneratedProtocolMessageType('CreateProjectChannelRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEPROJECTCHANNELREQUEST,
  '__module__' : 'spaceone.api.notification.v1.project_channel_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.notification.v1.CreateProjectChannelRequest)
  })
_sym_db.RegisterMessage(CreateProjectChannelRequest)

UpdateProjectChannelRequest = _reflection.GeneratedProtocolMessageType('UpdateProjectChannelRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEPROJECTCHANNELREQUEST,
  '__module__' : 'spaceone.api.notification.v1.project_channel_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.notification.v1.UpdateProjectChannelRequest)
  })
_sym_db.RegisterMessage(UpdateProjectChannelRequest)

UpdateProjectChannelScheduleRequest = _reflection.GeneratedProtocolMessageType('UpdateProjectChannelScheduleRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEPROJECTCHANNELSCHEDULEREQUEST,
  '__module__' : 'spaceone.api.notification.v1.project_channel_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.notification.v1.UpdateProjectChannelScheduleRequest)
  })
_sym_db.RegisterMessage(UpdateProjectChannelScheduleRequest)

UpdateProjectChannelSubscriptionRequest = _reflection.GeneratedProtocolMessageType('UpdateProjectChannelSubscriptionRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEPROJECTCHANNELSUBSCRIPTIONREQUEST,
  '__module__' : 'spaceone.api.notification.v1.project_channel_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.notification.v1.UpdateProjectChannelSubscriptionRequest)
  })
_sym_db.RegisterMessage(UpdateProjectChannelSubscriptionRequest)

ProjectChannelRequest = _reflection.GeneratedProtocolMessageType('ProjectChannelRequest', (_message.Message,), {
  'DESCRIPTOR' : _PROJECTCHANNELREQUEST,
  '__module__' : 'spaceone.api.notification.v1.project_channel_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.notification.v1.ProjectChannelRequest)
  })
_sym_db.RegisterMessage(ProjectChannelRequest)

GetProjectChannelRequest = _reflection.GeneratedProtocolMessageType('GetProjectChannelRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETPROJECTCHANNELREQUEST,
  '__module__' : 'spaceone.api.notification.v1.project_channel_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.notification.v1.GetProjectChannelRequest)
  })
_sym_db.RegisterMessage(GetProjectChannelRequest)

ProjectChannelQuery = _reflection.GeneratedProtocolMessageType('ProjectChannelQuery', (_message.Message,), {
  'DESCRIPTOR' : _PROJECTCHANNELQUERY,
  '__module__' : 'spaceone.api.notification.v1.project_channel_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.notification.v1.ProjectChannelQuery)
  })
_sym_db.RegisterMessage(ProjectChannelQuery)

ProjectChannelInfo = _reflection.GeneratedProtocolMessageType('ProjectChannelInfo', (_message.Message,), {
  'DESCRIPTOR' : _PROJECTCHANNELINFO,
  '__module__' : 'spaceone.api.notification.v1.project_channel_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.notification.v1.ProjectChannelInfo)
  })
_sym_db.RegisterMessage(ProjectChannelInfo)

ProjectChannelsInfo = _reflection.GeneratedProtocolMessageType('ProjectChannelsInfo', (_message.Message,), {
  'DESCRIPTOR' : _PROJECTCHANNELSINFO,
  '__module__' : 'spaceone.api.notification.v1.project_channel_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.notification.v1.ProjectChannelsInfo)
  })
_sym_db.RegisterMessage(ProjectChannelsInfo)

ProjectChannelStatQuery = _reflection.GeneratedProtocolMessageType('ProjectChannelStatQuery', (_message.Message,), {
  'DESCRIPTOR' : _PROJECTCHANNELSTATQUERY,
  '__module__' : 'spaceone.api.notification.v1.project_channel_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.notification.v1.ProjectChannelStatQuery)
  })
_sym_db.RegisterMessage(ProjectChannelStatQuery)

_PROJECTCHANNEL = DESCRIPTOR.services_by_name['ProjectChannel']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _PROJECTCHANNEL.methods_by_name['create']._options = None
  _PROJECTCHANNEL.methods_by_name['create']._serialized_options = b'\202\323\344\223\002#\"!/notification/v1/project-channels'
  _PROJECTCHANNEL.methods_by_name['update']._options = None
  _PROJECTCHANNEL.methods_by_name['update']._serialized_options = b'\202\323\344\223\0027\0325/notification/v1/project-channel/{project_channel_id}'
  _PROJECTCHANNEL.methods_by_name['set_schedule']._options = None
  _PROJECTCHANNEL.methods_by_name['set_schedule']._serialized_options = b'\202\323\344\223\002@\032>/notification/v1/project-channel/{project_channel_id}/schedule'
  _PROJECTCHANNEL.methods_by_name['set_subscription']._options = None
  _PROJECTCHANNEL.methods_by_name['set_subscription']._serialized_options = b'\202\323\344\223\002D\032B/notification/v1/project-channel/{project_channel_id}/subscription'
  _PROJECTCHANNEL.methods_by_name['enable']._options = None
  _PROJECTCHANNEL.methods_by_name['enable']._serialized_options = b'\202\323\344\223\002>\032</notification/v1/project-channel/{project_channel_id}/enable'
  _PROJECTCHANNEL.methods_by_name['disable']._options = None
  _PROJECTCHANNEL.methods_by_name['disable']._serialized_options = b'\202\323\344\223\002?\032=/notification/v1/project-channel/{project_channel_id}/disable'
  _PROJECTCHANNEL.methods_by_name['delete']._options = None
  _PROJECTCHANNEL.methods_by_name['delete']._serialized_options = b'\202\323\344\223\0027*5/notification/v1/project-channel/{project_channel_id}'
  _PROJECTCHANNEL.methods_by_name['get']._options = None
  _PROJECTCHANNEL.methods_by_name['get']._serialized_options = b'\202\323\344\223\0027\0225/notification/v1/project-channel/{project_channel_id}'
  _PROJECTCHANNEL.methods_by_name['list']._options = None
  _PROJECTCHANNEL.methods_by_name['list']._serialized_options = b'\202\323\344\223\002O\022!/notification/v1/project-channelsZ*\"(/notification/v1/project-channels/search'
  _PROJECTCHANNEL.methods_by_name['stat']._options = None
  _PROJECTCHANNEL.methods_by_name['stat']._serialized_options = b'\202\323\344\223\002(\"&/notification/v1/project-channels/stat'
  _NOTIFICATIONLEVEL._serialized_start=2795
  _NOTIFICATIONLEVEL._serialized_end=2869
  _PROJECTCHANNELSCHEDULE._serialized_start=208
  _PROJECTCHANNELSCHEDULE._serialized_end=441
  _PROJECTCHANNELSCHEDULE_DAYOFWEEK._serialized_start=357
  _PROJECTCHANNELSCHEDULE_DAYOFWEEK._serialized_end=441
  _CREATEPROJECTCHANNELREQUEST._serialized_start=444
  _CREATEPROJECTCHANNELREQUEST._serialized_end=841
  _UPDATEPROJECTCHANNELREQUEST._serialized_start=844
  _UPDATEPROJECTCHANNELREQUEST._serialized_end=1089
  _UPDATEPROJECTCHANNELSCHEDULEREQUEST._serialized_start=1092
  _UPDATEPROJECTCHANNELSCHEDULEREQUEST._serialized_end=1270
  _UPDATEPROJECTCHANNELSUBSCRIPTIONREQUEST._serialized_start=1273
  _UPDATEPROJECTCHANNELSUBSCRIPTIONREQUEST._serialized_end=1406
  _PROJECTCHANNELREQUEST._serialized_start=1408
  _PROJECTCHANNELREQUEST._serialized_end=1478
  _GETPROJECTCHANNELREQUEST._serialized_start=1480
  _GETPROJECTCHANNELREQUEST._serialized_end=1567
  _PROJECTCHANNELQUERY._serialized_start=1570
  _PROJECTCHANNELQUERY._serialized_end=1979
  _PROJECTCHANNELQUERY_PROJECTCHANNELSTATE._serialized_start=1921
  _PROJECTCHANNELQUERY_PROJECTCHANNELSTATE._serialized_end=1979
  _PROJECTCHANNELINFO._serialized_start=1982
  _PROJECTCHANNELINFO._serialized_end=2582
  _PROJECTCHANNELINFO_PROJECTCHANNELSTATE._serialized_start=1921
  _PROJECTCHANNELINFO_PROJECTCHANNELSTATE._serialized_end=1979
  _PROJECTCHANNELSINFO._serialized_start=2584
  _PROJECTCHANNELSINFO._serialized_end=2693
  _PROJECTCHANNELSTATQUERY._serialized_start=2695
  _PROJECTCHANNELSTATQUERY._serialized_end=2793
  _PROJECTCHANNEL._serialized_start=2872
  _PROJECTCHANNEL._serialized_end=4691
# @@protoc_insertion_point(module_scope)
