# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: spaceone/api/provisioning/v1/catalog_group.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from spaceone.api.core.v1 import query_pb2 as spaceone_dot_api_dot_core_dot_v1_dot_query__pb2
from spaceone.api.identity.v1 import role_pb2 as spaceone_dot_api_dot_identity_dot_v1_dot_role__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n0spaceone/api/provisioning/v1/catalog_group.proto\x12\x1cspaceone.api.provisioning.v1\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1cgoogle/api/annotations.proto\x1a spaceone/api/core/v1/query.proto\x1a#spaceone/api/identity/v1/role.proto\"\xb8\x02\n\x10\x43\x61talogGroupInfo\x12\x18\n\x10\x63\x61talog_group_id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12%\n\x04tags\x18\x03 \x01(\x0b\x32\x17.google.protobuf.Struct\x12Q\n\x19parent_catalog_group_info\x18\x04 \x01(\x0b\x32..spaceone.api.provisioning.v1.CatalogGroupInfo\x12\x1f\n\x17parent_catalog_group_id\x18\x05 \x01(\t\x12\x11\n\tdomain_id\x18\x0b \x01(\t\x12\x12\n\ncreated_by\x18\x15 \x01(\t\x12\x12\n\ncreated_at\x18\x16 \x01(\t\x12\x12\n\nupdated_by\x18\x17 \x01(\t\x12\x12\n\nupdated_at\x18\x18 \x01(\t\"]\n\x19\x43reateCatalogGroupRequest\x12\x11\n\tdomain_id\x18\x01 \x01(\t\x12\x1f\n\x17parent_catalog_group_id\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\"\xc4\x01\n\x19UpdateCatalogGroupRequest\x12\x18\n\x10\x63\x61talog_group_id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x1f\n\x17parent_catalog_group_id\x18\x03 \x01(\t\x12$\n\x1crelease_parent_catalog_group\x18\x04 \x01(\x08\x12%\n\x04tags\x18\x05 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x11\n\tdomain_id\x18\x06 \x01(\t\"B\n\x13\x43\x61talogGroupRequest\x12\x18\n\x10\x63\x61talog_group_id\x18\x01 \x01(\t\x12\x11\n\tdomain_id\x18\x02 \x01(\t\"S\n\x16GetCatalogGroupRequest\x12\x18\n\x10\x63\x61talog_group_id\x18\x01 \x01(\t\x12\x11\n\tdomain_id\x18\x02 \x01(\t\x12\x0c\n\x04only\x18\x03 \x03(\t\"\xd0\x01\n\x11\x43\x61talogGroupQuery\x12*\n\x05query\x18\x01 \x01(\x0b\x32\x1b.spaceone.api.core.v1.Query\x12\x18\n\x10\x63\x61talog_group_id\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x1c\n\x14parent_catalog_group\x18\x04 \x01(\t\x12\x15\n\rauthor_within\x18\x05 \x01(\x08\x12\x11\n\tdomain_id\x18\x06 \x01(\t\x12\x1f\n\x17parent_catalog_group_id\x18\x07 \x01(\t\"i\n\x11\x43\x61talogGroupsInfo\x12?\n\x07results\x18\x01 \x03(\x0b\x32..spaceone.api.provisioning.v1.CatalogGroupInfo\x12\x13\n\x0btotal_count\x18\x02 \x01(\x05\x32\x97\x07\n\x0c\x43\x61talogGroup\x12\xa7\x01\n\x14\x63reate_catalog_group\x12\x37.spaceone.api.provisioning.v1.CreateCatalogGroupRequest\x1a..spaceone.api.provisioning.v1.CatalogGroupInfo\"&\x82\xd3\xe4\x93\x02 \"\x1e/provisioning/v1/catalog-group\x12\xba\x01\n\x14update_catalog_group\x12\x37.spaceone.api.provisioning.v1.UpdateCatalogGroupRequest\x1a..spaceone.api.provisioning.v1.CatalogGroupInfo\"9\x82\xd3\xe4\x93\x02\x33\x1a\x31/provisioning/v1/catalog-group/{catalog_group_id}\x12\x9c\x01\n\x14\x64\x65lete_catalog_group\x12\x31.spaceone.api.provisioning.v1.CatalogGroupRequest\x1a\x16.google.protobuf.Empty\"9\x82\xd3\xe4\x93\x02\x33*1/provisioning/v1/catalog-group/{catalog_group_id}\x12\xb4\x01\n\x11get_catalog_group\x12\x34.spaceone.api.provisioning.v1.GetCatalogGroupRequest\x1a..spaceone.api.provisioning.v1.CatalogGroupInfo\"9\x82\xd3\xe4\x93\x02\x33\x12\x31/provisioning/v1/catalog-group/{catalog_group_id}\x12\xc9\x01\n\x12get_catalog_groups\x12/.spaceone.api.provisioning.v1.CatalogGroupQuery\x1a/.spaceone.api.provisioning.v1.CatalogGroupsInfo\"Q\x82\xd3\xe4\x93\x02K\x12\x1f/provisioning/v1/catalog-groupsZ(\"&/provisioning/v1/catalog-groups/searchb\x06proto3')



_CATALOGGROUPINFO = DESCRIPTOR.message_types_by_name['CatalogGroupInfo']
_CREATECATALOGGROUPREQUEST = DESCRIPTOR.message_types_by_name['CreateCatalogGroupRequest']
_UPDATECATALOGGROUPREQUEST = DESCRIPTOR.message_types_by_name['UpdateCatalogGroupRequest']
_CATALOGGROUPREQUEST = DESCRIPTOR.message_types_by_name['CatalogGroupRequest']
_GETCATALOGGROUPREQUEST = DESCRIPTOR.message_types_by_name['GetCatalogGroupRequest']
_CATALOGGROUPQUERY = DESCRIPTOR.message_types_by_name['CatalogGroupQuery']
_CATALOGGROUPSINFO = DESCRIPTOR.message_types_by_name['CatalogGroupsInfo']
CatalogGroupInfo = _reflection.GeneratedProtocolMessageType('CatalogGroupInfo', (_message.Message,), {
  'DESCRIPTOR' : _CATALOGGROUPINFO,
  '__module__' : 'spaceone.api.provisioning.v1.catalog_group_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.provisioning.v1.CatalogGroupInfo)
  })
_sym_db.RegisterMessage(CatalogGroupInfo)

CreateCatalogGroupRequest = _reflection.GeneratedProtocolMessageType('CreateCatalogGroupRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATECATALOGGROUPREQUEST,
  '__module__' : 'spaceone.api.provisioning.v1.catalog_group_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.provisioning.v1.CreateCatalogGroupRequest)
  })
_sym_db.RegisterMessage(CreateCatalogGroupRequest)

UpdateCatalogGroupRequest = _reflection.GeneratedProtocolMessageType('UpdateCatalogGroupRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATECATALOGGROUPREQUEST,
  '__module__' : 'spaceone.api.provisioning.v1.catalog_group_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.provisioning.v1.UpdateCatalogGroupRequest)
  })
_sym_db.RegisterMessage(UpdateCatalogGroupRequest)

CatalogGroupRequest = _reflection.GeneratedProtocolMessageType('CatalogGroupRequest', (_message.Message,), {
  'DESCRIPTOR' : _CATALOGGROUPREQUEST,
  '__module__' : 'spaceone.api.provisioning.v1.catalog_group_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.provisioning.v1.CatalogGroupRequest)
  })
_sym_db.RegisterMessage(CatalogGroupRequest)

GetCatalogGroupRequest = _reflection.GeneratedProtocolMessageType('GetCatalogGroupRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETCATALOGGROUPREQUEST,
  '__module__' : 'spaceone.api.provisioning.v1.catalog_group_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.provisioning.v1.GetCatalogGroupRequest)
  })
_sym_db.RegisterMessage(GetCatalogGroupRequest)

CatalogGroupQuery = _reflection.GeneratedProtocolMessageType('CatalogGroupQuery', (_message.Message,), {
  'DESCRIPTOR' : _CATALOGGROUPQUERY,
  '__module__' : 'spaceone.api.provisioning.v1.catalog_group_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.provisioning.v1.CatalogGroupQuery)
  })
_sym_db.RegisterMessage(CatalogGroupQuery)

CatalogGroupsInfo = _reflection.GeneratedProtocolMessageType('CatalogGroupsInfo', (_message.Message,), {
  'DESCRIPTOR' : _CATALOGGROUPSINFO,
  '__module__' : 'spaceone.api.provisioning.v1.catalog_group_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.provisioning.v1.CatalogGroupsInfo)
  })
_sym_db.RegisterMessage(CatalogGroupsInfo)

_CATALOGGROUP = DESCRIPTOR.services_by_name['CatalogGroup']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _CATALOGGROUP.methods_by_name['create_catalog_group']._options = None
  _CATALOGGROUP.methods_by_name['create_catalog_group']._serialized_options = b'\202\323\344\223\002 \"\036/provisioning/v1/catalog-group'
  _CATALOGGROUP.methods_by_name['update_catalog_group']._options = None
  _CATALOGGROUP.methods_by_name['update_catalog_group']._serialized_options = b'\202\323\344\223\0023\0321/provisioning/v1/catalog-group/{catalog_group_id}'
  _CATALOGGROUP.methods_by_name['delete_catalog_group']._options = None
  _CATALOGGROUP.methods_by_name['delete_catalog_group']._serialized_options = b'\202\323\344\223\0023*1/provisioning/v1/catalog-group/{catalog_group_id}'
  _CATALOGGROUP.methods_by_name['get_catalog_group']._options = None
  _CATALOGGROUP.methods_by_name['get_catalog_group']._serialized_options = b'\202\323\344\223\0023\0221/provisioning/v1/catalog-group/{catalog_group_id}'
  _CATALOGGROUP.methods_by_name['get_catalog_groups']._options = None
  _CATALOGGROUP.methods_by_name['get_catalog_groups']._serialized_options = b'\202\323\344\223\002K\022\037/provisioning/v1/catalog-groupsZ(\"&/provisioning/v1/catalog-groups/search'
  _CATALOGGROUPINFO._serialized_start=243
  _CATALOGGROUPINFO._serialized_end=555
  _CREATECATALOGGROUPREQUEST._serialized_start=557
  _CREATECATALOGGROUPREQUEST._serialized_end=650
  _UPDATECATALOGGROUPREQUEST._serialized_start=653
  _UPDATECATALOGGROUPREQUEST._serialized_end=849
  _CATALOGGROUPREQUEST._serialized_start=851
  _CATALOGGROUPREQUEST._serialized_end=917
  _GETCATALOGGROUPREQUEST._serialized_start=919
  _GETCATALOGGROUPREQUEST._serialized_end=1002
  _CATALOGGROUPQUERY._serialized_start=1005
  _CATALOGGROUPQUERY._serialized_end=1213
  _CATALOGGROUPSINFO._serialized_start=1215
  _CATALOGGROUPSINFO._serialized_end=1320
  _CATALOGGROUP._serialized_start=1323
  _CATALOGGROUP._serialized_end=2242
# @@protoc_insertion_point(module_scope)
