# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: spaceone/api/identity/v1/token.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$spaceone/api/identity/v1/token.proto\x12\x18spaceone.api.identity.v1\x1a\x1cgoogle/api/annotations.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1cgoogle/protobuf/struct.proto\"\xa0\x01\n\x11IssueTokenRequest\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12,\n\x0b\x63redentials\x18\x02 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x11\n\tuser_type\x18\x03 \x01(\t\x12\x11\n\tdomain_id\x18\x04 \x01(\t\x12\x0f\n\x07timeout\x18\x05 \x01(\x05\x12\x15\n\rrefresh_count\x18\x06 \x01(\x05\"8\n\tTokenInfo\x12\x14\n\x0c\x61\x63\x63\x65ss_token\x18\x01 \x01(\t\x12\x15\n\rrefresh_token\x18\x02 \x01(\t2\xf0\x01\n\x05Token\x12{\n\x05issue\x12+.spaceone.api.identity.v1.IssueTokenRequest\x1a#.spaceone.api.identity.v1.TokenInfo\" \x82\xd3\xe4\x93\x02\x1a\"\x18/identity/v1/token/issue\x12j\n\x07refresh\x12\x16.google.protobuf.Empty\x1a#.spaceone.api.identity.v1.TokenInfo\"\"\x82\xd3\xe4\x93\x02\x1c\"\x1a/identity/v1/token/refreshb\x06proto3')



_ISSUETOKENREQUEST = DESCRIPTOR.message_types_by_name['IssueTokenRequest']
_TOKENINFO = DESCRIPTOR.message_types_by_name['TokenInfo']
IssueTokenRequest = _reflection.GeneratedProtocolMessageType('IssueTokenRequest', (_message.Message,), {
  'DESCRIPTOR' : _ISSUETOKENREQUEST,
  '__module__' : 'spaceone.api.identity.v1.token_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.identity.v1.IssueTokenRequest)
  })
_sym_db.RegisterMessage(IssueTokenRequest)

TokenInfo = _reflection.GeneratedProtocolMessageType('TokenInfo', (_message.Message,), {
  'DESCRIPTOR' : _TOKENINFO,
  '__module__' : 'spaceone.api.identity.v1.token_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.identity.v1.TokenInfo)
  })
_sym_db.RegisterMessage(TokenInfo)

_TOKEN = DESCRIPTOR.services_by_name['Token']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _TOKEN.methods_by_name['issue']._options = None
  _TOKEN.methods_by_name['issue']._serialized_options = b'\202\323\344\223\002\032\"\030/identity/v1/token/issue'
  _TOKEN.methods_by_name['refresh']._options = None
  _TOKEN.methods_by_name['refresh']._serialized_options = b'\202\323\344\223\002\034\"\032/identity/v1/token/refresh'
  _ISSUETOKENREQUEST._serialized_start=156
  _ISSUETOKENREQUEST._serialized_end=316
  _TOKENINFO._serialized_start=318
  _TOKENINFO._serialized_end=374
  _TOKEN._serialized_start=377
  _TOKEN._serialized_end=617
# @@protoc_insertion_point(module_scope)
