# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: spaceone/api/monitoring/plugin/webhook.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n,spaceone/api/monitoring/plugin/webhook.proto\x12\x1espaceone.api.monitoring.plugin\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1cgoogle/protobuf/struct.proto\">\n\x12WebhookInitRequest\x12(\n\x07options\x18\x01 \x01(\x0b\x32\x17.google.protobuf.Struct\"F\n\x1aWebhookPluginVerifyRequest\x12(\n\x07options\x18\x01 \x01(\x0b\x32\x17.google.protobuf.Struct\">\n\x11WebhookPluginInfo\x12)\n\x08metadata\x18\x01 \x01(\x0b\x32\x17.google.protobuf.Struct2\xda\x01\n\x07Webhook\x12o\n\x04init\x12\x32.spaceone.api.monitoring.plugin.WebhookInitRequest\x1a\x31.spaceone.api.monitoring.plugin.WebhookPluginInfo\"\x00\x12^\n\x06verify\x12:.spaceone.api.monitoring.plugin.WebhookPluginVerifyRequest\x1a\x16.google.protobuf.Empty\"\x00\x62\x06proto3')



_WEBHOOKINITREQUEST = DESCRIPTOR.message_types_by_name['WebhookInitRequest']
_WEBHOOKPLUGINVERIFYREQUEST = DESCRIPTOR.message_types_by_name['WebhookPluginVerifyRequest']
_WEBHOOKPLUGININFO = DESCRIPTOR.message_types_by_name['WebhookPluginInfo']
WebhookInitRequest = _reflection.GeneratedProtocolMessageType('WebhookInitRequest', (_message.Message,), {
  'DESCRIPTOR' : _WEBHOOKINITREQUEST,
  '__module__' : 'spaceone.api.monitoring.plugin.webhook_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.monitoring.plugin.WebhookInitRequest)
  })
_sym_db.RegisterMessage(WebhookInitRequest)

WebhookPluginVerifyRequest = _reflection.GeneratedProtocolMessageType('WebhookPluginVerifyRequest', (_message.Message,), {
  'DESCRIPTOR' : _WEBHOOKPLUGINVERIFYREQUEST,
  '__module__' : 'spaceone.api.monitoring.plugin.webhook_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.monitoring.plugin.WebhookPluginVerifyRequest)
  })
_sym_db.RegisterMessage(WebhookPluginVerifyRequest)

WebhookPluginInfo = _reflection.GeneratedProtocolMessageType('WebhookPluginInfo', (_message.Message,), {
  'DESCRIPTOR' : _WEBHOOKPLUGININFO,
  '__module__' : 'spaceone.api.monitoring.plugin.webhook_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.monitoring.plugin.WebhookPluginInfo)
  })
_sym_db.RegisterMessage(WebhookPluginInfo)

_WEBHOOK = DESCRIPTOR.services_by_name['Webhook']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _WEBHOOKINITREQUEST._serialized_start=139
  _WEBHOOKINITREQUEST._serialized_end=201
  _WEBHOOKPLUGINVERIFYREQUEST._serialized_start=203
  _WEBHOOKPLUGINVERIFYREQUEST._serialized_end=273
  _WEBHOOKPLUGININFO._serialized_start=275
  _WEBHOOKPLUGININFO._serialized_end=337
  _WEBHOOK._serialized_start=340
  _WEBHOOK._serialized_end=558
# @@protoc_insertion_point(module_scope)
