# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: spaceone/api/repository/v1/schema.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from spaceone.api.core.v1 import query_pb2 as spaceone_dot_api_dot_core_dot_v1_dot_query__pb2
from spaceone.api.repository.v1 import repository_pb2 as spaceone_dot_api_dot_repository_dot_v1_dot_repository__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\'spaceone/api/repository/v1/schema.proto\x12\x1aspaceone.api.repository.v1\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1cgoogle/api/annotations.proto\x1a spaceone/api/core/v1/query.proto\x1a+spaceone/api/repository/v1/repository.proto\"\xef\x01\n\x13\x43reateSchemaRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x14\n\x0cservice_type\x18\x02 \x01(\t\x12\x11\n\tschema_id\x18\x03 \x01(\t\x12\'\n\x06schema\x18\x0b \x01(\x0b\x32\x17.google.protobuf.Struct\x12*\n\x06labels\x18\x0c \x01(\x0b\x32\x1a.google.protobuf.ListValue\x12%\n\x04tags\x18\r \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x12\n\nproject_id\x18\x15 \x01(\t\x12\x11\n\tdomain_id\x18\x16 \x01(\t\"\xb2\x01\n\x13UpdateSchemaRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\'\n\x06schema\x18\x0b \x01(\x0b\x32\x17.google.protobuf.Struct\x12*\n\x06labels\x18\x0c \x01(\x0b\x32\x1a.google.protobuf.ListValue\x12%\n\x04tags\x18\r \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x11\n\tdomain_id\x18\x15 \x01(\t\"C\n\rSchemaRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x11\n\tdomain_id\x18\x02 \x01(\t\x12\x11\n\tschema_id\x18\x03 \x01(\t\"u\n\x1aGetRepositorySchemaRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x11\n\tdomain_id\x18\x02 \x01(\t\x12\x15\n\rrepository_id\x18\x03 \x01(\t\x12\x0c\n\x04only\x18\x04 \x03(\t\x12\x11\n\tschema_id\x18\x05 \x01(\t\"\x9a\x02\n\x0bSchemaQuery\x12*\n\x05query\x18\x01 \x01(\x0b\x32\x1b.spaceone.api.core.v1.Query\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x14\n\x0cservice_type\x18\x03 \x01(\t\x12\x12\n\nproject_id\x18\x04 \x01(\t\x12\x15\n\rrepository_id\x18\x05 \x01(\t\x12\x11\n\tdomain_id\x18\x06 \x01(\t\x12\x11\n\tschema_id\x18\x07 \x01(\t\x12<\n\x05state\x18\x08 \x01(\x0e\x32-.spaceone.api.repository.v1.SchemaQuery.State\",\n\x05State\x12\x08\n\x04NONE\x10\x00\x12\x0b\n\x07\x45NABLED\x10\x01\x12\x0c\n\x08\x44ISABLED\x10\x02\"\xd3\x02\n\nSchemaInfo\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x14\n\x0cservice_type\x18\x02 \x01(\t\x12\x11\n\tschema_id\x18\x03 \x01(\t\x12\'\n\x06schema\x18\x0b \x01(\x0b\x32\x17.google.protobuf.Struct\x12*\n\x06labels\x18\x0c \x01(\x0b\x32\x1a.google.protobuf.ListValue\x12%\n\x04tags\x18\r \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x43\n\x0frepository_info\x18\x15 \x01(\x0b\x32*.spaceone.api.repository.v1.RepositoryInfo\x12\x12\n\nproject_id\x18\x16 \x01(\t\x12\x11\n\tdomain_id\x18\x17 \x01(\t\x12\x12\n\ncreated_at\x18\x1f \x01(\t\x12\x12\n\nupdated_at\x18  \x01(\t\"[\n\x0bSchemasInfo\x12\x37\n\x07results\x18\x01 \x03(\x0b\x32&.spaceone.api.repository.v1.SchemaInfo\x12\x13\n\x0btotal_count\x18\x02 \x01(\x05\"q\n\x0fSchemaStatQuery\x12\x34\n\x05query\x18\x01 \x01(\x0b\x32%.spaceone.api.core.v1.StatisticsQuery\x12\x15\n\rrepository_id\x18\x02 \x01(\t\x12\x11\n\tdomain_id\x18\x03 \x01(\t2\xad\x06\n\x06Schema\x12\x81\x01\n\x06\x63reate\x12/.spaceone.api.repository.v1.CreateSchemaRequest\x1a&.spaceone.api.repository.v1.SchemaInfo\"\x1e\x82\xd3\xe4\x93\x02\x18\"\x16/repository/v1/schemas\x12\x89\x01\n\x06update\x12/.spaceone.api.repository.v1.UpdateSchemaRequest\x1a&.spaceone.api.repository.v1.SchemaInfo\"&\x82\xd3\xe4\x93\x02 \x1a\x1e/repository/v1/schema/{schema}\x12s\n\x06\x64\x65lete\x12).spaceone.api.repository.v1.SchemaRequest\x1a\x16.google.protobuf.Empty\"&\x82\xd3\xe4\x93\x02 *\x1e/repository/v1/schema/{schema}\x12\x8e\x01\n\x03get\x12\x36.spaceone.api.repository.v1.GetRepositorySchemaRequest\x1a&.spaceone.api.repository.v1.SchemaInfo\"\'\x82\xd3\xe4\x93\x02!\x12\x1f/repository/v1/schemas/{schema}\x12\x99\x01\n\x04list\x12\'.spaceone.api.repository.v1.SchemaQuery\x1a\'.spaceone.api.repository.v1.SchemasInfo\"?\x82\xd3\xe4\x93\x02\x39\x12\x16/repository/v1/schemasZ\x1f\"\x1d/repository/v1/schemas/search\x12q\n\x04stat\x12+.spaceone.api.repository.v1.SchemaStatQuery\x1a\x17.google.protobuf.Struct\"#\x82\xd3\xe4\x93\x02\x1d\"\x1b/repository/v1/schemas/statb\x06proto3')



_CREATESCHEMAREQUEST = DESCRIPTOR.message_types_by_name['CreateSchemaRequest']
_UPDATESCHEMAREQUEST = DESCRIPTOR.message_types_by_name['UpdateSchemaRequest']
_SCHEMAREQUEST = DESCRIPTOR.message_types_by_name['SchemaRequest']
_GETREPOSITORYSCHEMAREQUEST = DESCRIPTOR.message_types_by_name['GetRepositorySchemaRequest']
_SCHEMAQUERY = DESCRIPTOR.message_types_by_name['SchemaQuery']
_SCHEMAINFO = DESCRIPTOR.message_types_by_name['SchemaInfo']
_SCHEMASINFO = DESCRIPTOR.message_types_by_name['SchemasInfo']
_SCHEMASTATQUERY = DESCRIPTOR.message_types_by_name['SchemaStatQuery']
_SCHEMAQUERY_STATE = _SCHEMAQUERY.enum_types_by_name['State']
CreateSchemaRequest = _reflection.GeneratedProtocolMessageType('CreateSchemaRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATESCHEMAREQUEST,
  '__module__' : 'spaceone.api.repository.v1.schema_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.repository.v1.CreateSchemaRequest)
  })
_sym_db.RegisterMessage(CreateSchemaRequest)

UpdateSchemaRequest = _reflection.GeneratedProtocolMessageType('UpdateSchemaRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATESCHEMAREQUEST,
  '__module__' : 'spaceone.api.repository.v1.schema_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.repository.v1.UpdateSchemaRequest)
  })
_sym_db.RegisterMessage(UpdateSchemaRequest)

SchemaRequest = _reflection.GeneratedProtocolMessageType('SchemaRequest', (_message.Message,), {
  'DESCRIPTOR' : _SCHEMAREQUEST,
  '__module__' : 'spaceone.api.repository.v1.schema_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.repository.v1.SchemaRequest)
  })
_sym_db.RegisterMessage(SchemaRequest)

GetRepositorySchemaRequest = _reflection.GeneratedProtocolMessageType('GetRepositorySchemaRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETREPOSITORYSCHEMAREQUEST,
  '__module__' : 'spaceone.api.repository.v1.schema_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.repository.v1.GetRepositorySchemaRequest)
  })
_sym_db.RegisterMessage(GetRepositorySchemaRequest)

SchemaQuery = _reflection.GeneratedProtocolMessageType('SchemaQuery', (_message.Message,), {
  'DESCRIPTOR' : _SCHEMAQUERY,
  '__module__' : 'spaceone.api.repository.v1.schema_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.repository.v1.SchemaQuery)
  })
_sym_db.RegisterMessage(SchemaQuery)

SchemaInfo = _reflection.GeneratedProtocolMessageType('SchemaInfo', (_message.Message,), {
  'DESCRIPTOR' : _SCHEMAINFO,
  '__module__' : 'spaceone.api.repository.v1.schema_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.repository.v1.SchemaInfo)
  })
_sym_db.RegisterMessage(SchemaInfo)

SchemasInfo = _reflection.GeneratedProtocolMessageType('SchemasInfo', (_message.Message,), {
  'DESCRIPTOR' : _SCHEMASINFO,
  '__module__' : 'spaceone.api.repository.v1.schema_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.repository.v1.SchemasInfo)
  })
_sym_db.RegisterMessage(SchemasInfo)

SchemaStatQuery = _reflection.GeneratedProtocolMessageType('SchemaStatQuery', (_message.Message,), {
  'DESCRIPTOR' : _SCHEMASTATQUERY,
  '__module__' : 'spaceone.api.repository.v1.schema_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.repository.v1.SchemaStatQuery)
  })
_sym_db.RegisterMessage(SchemaStatQuery)

_SCHEMA = DESCRIPTOR.services_by_name['Schema']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _SCHEMA.methods_by_name['create']._options = None
  _SCHEMA.methods_by_name['create']._serialized_options = b'\202\323\344\223\002\030\"\026/repository/v1/schemas'
  _SCHEMA.methods_by_name['update']._options = None
  _SCHEMA.methods_by_name['update']._serialized_options = b'\202\323\344\223\002 \032\036/repository/v1/schema/{schema}'
  _SCHEMA.methods_by_name['delete']._options = None
  _SCHEMA.methods_by_name['delete']._serialized_options = b'\202\323\344\223\002 *\036/repository/v1/schema/{schema}'
  _SCHEMA.methods_by_name['get']._options = None
  _SCHEMA.methods_by_name['get']._serialized_options = b'\202\323\344\223\002!\022\037/repository/v1/schemas/{schema}'
  _SCHEMA.methods_by_name['list']._options = None
  _SCHEMA.methods_by_name['list']._serialized_options = b'\202\323\344\223\0029\022\026/repository/v1/schemasZ\037\"\035/repository/v1/schemas/search'
  _SCHEMA.methods_by_name['stat']._options = None
  _SCHEMA.methods_by_name['stat']._serialized_options = b'\202\323\344\223\002\035\"\033/repository/v1/schemas/stat'
  _CREATESCHEMAREQUEST._serialized_start=240
  _CREATESCHEMAREQUEST._serialized_end=479
  _UPDATESCHEMAREQUEST._serialized_start=482
  _UPDATESCHEMAREQUEST._serialized_end=660
  _SCHEMAREQUEST._serialized_start=662
  _SCHEMAREQUEST._serialized_end=729
  _GETREPOSITORYSCHEMAREQUEST._serialized_start=731
  _GETREPOSITORYSCHEMAREQUEST._serialized_end=848
  _SCHEMAQUERY._serialized_start=851
  _SCHEMAQUERY._serialized_end=1133
  _SCHEMAQUERY_STATE._serialized_start=1089
  _SCHEMAQUERY_STATE._serialized_end=1133
  _SCHEMAINFO._serialized_start=1136
  _SCHEMAINFO._serialized_end=1475
  _SCHEMASINFO._serialized_start=1477
  _SCHEMASINFO._serialized_end=1568
  _SCHEMASTATQUERY._serialized_start=1570
  _SCHEMASTATQUERY._serialized_end=1683
  _SCHEMA._serialized_start=1686
  _SCHEMA._serialized_end=2499
# @@protoc_insertion_point(module_scope)
