# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: spaceone/api/inventory/v1/resource_summary.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from spaceone.api.core.v1 import query_pb2 as spaceone_dot_api_dot_core_dot_v1_dot_query__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n0spaceone/api/inventory/v1/resource_summary.proto\x12\x19spaceone.api.inventory.v1\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1cgoogle/api/annotations.proto\x1a spaceone/api/core/v1/query.proto\"?\n\x16ResourceSummaryRequest\x12\x12\n\nsummary_id\x18\x01 \x01(\t\x12\x11\n\tdomain_id\x18\x02 \x01(\t\"P\n\x19GetResourceSummaryRequest\x12\x12\n\nsummary_id\x18\x01 \x01(\t\x12\x11\n\tdomain_id\x18\x02 \x01(\t\x12\x0c\n\x04only\x18\x03 \x03(\t\"\xff\x01\n\x14ResourceSummaryQuery\x12*\n\x05query\x18\x01 \x01(\x0b\x32\x1b.spaceone.api.core.v1.Query\x12\x12\n\nsummary_id\x18\x02 \x01(\t\x12\x10\n\x08provider\x18\x03 \x01(\t\x12\x12\n\nproject_id\x18\x04 \x01(\t\x12\x11\n\tdomain_id\x18\x05 \x01(\t\x12\x1b\n\x13\x63loud_service_group\x18\x06 \x01(\t\x12\x1a\n\x12\x63loud_service_type\x18\x07 \x01(\t\x12\x14\n\x0c\x63reated_date\x18\x08 \x01(\t\x12\x0f\n\x07\x61\x63\x63ount\x18\t \x01(\t\x12\x0e\n\x06region\x18\n \x01(\t\"\xdb\x02\n\x13ResourceSummaryInfo\x12\x12\n\nsummary_id\x18\x01 \x01(\t\x12\x12\n\nproject_id\x18\x02 \x01(\t\x12\x10\n\x08provider\x18\x03 \x01(\t\x12\x11\n\tdomain_id\x18\x04 \x01(\t\x12\x0f\n\x07\x61\x63\x63ount\x18\x05 \x01(\t\x12\x1b\n\x13\x63loud_service_group\x18\x06 \x01(\t\x12\x1a\n\x12\x63loud_service_type\x18\x07 \x01(\t\x12\r\n\x05state\x18\x08 \x01(\t\x12\x0c\n\x04size\x18\t \x01(\x01\x12\r\n\x05\x63ount\x18\n \x01(\x01\x12\x14\n\x0c\x63reated_date\x18\x0b \x01(\t\x12%\n\x04\x64\x61ta\x18\x0c \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x12\n\ncreated_at\x18\r \x01(\t\x12\x12\n\nupdated_at\x18\x0e \x01(\t\x12\x0c\n\x04type\x18\x0f \x01(\t\x12\x0e\n\x06region\x18\x10 \x01(\t\"m\n\x15ResourceSummariesInfo\x12?\n\x07results\x18\x01 \x03(\x0b\x32..spaceone.api.inventory.v1.ResourceSummaryInfo\x12\x13\n\x0btotal_count\x18\x02 \x01(\x05\"c\n\x18ResourceSummaryStatQuery\x12\x34\n\x05query\x18\x01 \x01(\x0b\x32%.spaceone.api.core.v1.StatisticsQuery\x12\x11\n\tdomain_id\x18\x02 \x01(\t2\xf9\x03\n\x0fResourceSummary\x12\x9e\x01\n\x03get\x12\x34.spaceone.api.inventory.v1.GetResourceSummaryRequest\x1a..spaceone.api.inventory.v1.ResourceSummaryInfo\"1\x82\xd3\xe4\x93\x02+\x12)/inventory/v1/resource-group/{summary_id}\x12\xbe\x01\n\x04list\x12/.spaceone.api.inventory.v1.ResourceSummaryQuery\x1a\x30.spaceone.api.inventory.v1.ResourceSummariesInfo\"S\x82\xd3\xe4\x93\x02M\x12 /inventory/v1/resource-summariesZ)\"\'/inventory/v1/resource-summaries/search\x12\x83\x01\n\x04stat\x12\x33.spaceone.api.inventory.v1.ResourceSummaryStatQuery\x1a\x17.google.protobuf.Struct\"-\x82\xd3\xe4\x93\x02\'\"%/inventory/v1/resource-summaries/statb\x06proto3')



_RESOURCESUMMARYREQUEST = DESCRIPTOR.message_types_by_name['ResourceSummaryRequest']
_GETRESOURCESUMMARYREQUEST = DESCRIPTOR.message_types_by_name['GetResourceSummaryRequest']
_RESOURCESUMMARYQUERY = DESCRIPTOR.message_types_by_name['ResourceSummaryQuery']
_RESOURCESUMMARYINFO = DESCRIPTOR.message_types_by_name['ResourceSummaryInfo']
_RESOURCESUMMARIESINFO = DESCRIPTOR.message_types_by_name['ResourceSummariesInfo']
_RESOURCESUMMARYSTATQUERY = DESCRIPTOR.message_types_by_name['ResourceSummaryStatQuery']
ResourceSummaryRequest = _reflection.GeneratedProtocolMessageType('ResourceSummaryRequest', (_message.Message,), {
  'DESCRIPTOR' : _RESOURCESUMMARYREQUEST,
  '__module__' : 'spaceone.api.inventory.v1.resource_summary_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.ResourceSummaryRequest)
  })
_sym_db.RegisterMessage(ResourceSummaryRequest)

GetResourceSummaryRequest = _reflection.GeneratedProtocolMessageType('GetResourceSummaryRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETRESOURCESUMMARYREQUEST,
  '__module__' : 'spaceone.api.inventory.v1.resource_summary_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.GetResourceSummaryRequest)
  })
_sym_db.RegisterMessage(GetResourceSummaryRequest)

ResourceSummaryQuery = _reflection.GeneratedProtocolMessageType('ResourceSummaryQuery', (_message.Message,), {
  'DESCRIPTOR' : _RESOURCESUMMARYQUERY,
  '__module__' : 'spaceone.api.inventory.v1.resource_summary_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.ResourceSummaryQuery)
  })
_sym_db.RegisterMessage(ResourceSummaryQuery)

ResourceSummaryInfo = _reflection.GeneratedProtocolMessageType('ResourceSummaryInfo', (_message.Message,), {
  'DESCRIPTOR' : _RESOURCESUMMARYINFO,
  '__module__' : 'spaceone.api.inventory.v1.resource_summary_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.ResourceSummaryInfo)
  })
_sym_db.RegisterMessage(ResourceSummaryInfo)

ResourceSummariesInfo = _reflection.GeneratedProtocolMessageType('ResourceSummariesInfo', (_message.Message,), {
  'DESCRIPTOR' : _RESOURCESUMMARIESINFO,
  '__module__' : 'spaceone.api.inventory.v1.resource_summary_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.ResourceSummariesInfo)
  })
_sym_db.RegisterMessage(ResourceSummariesInfo)

ResourceSummaryStatQuery = _reflection.GeneratedProtocolMessageType('ResourceSummaryStatQuery', (_message.Message,), {
  'DESCRIPTOR' : _RESOURCESUMMARYSTATQUERY,
  '__module__' : 'spaceone.api.inventory.v1.resource_summary_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.ResourceSummaryStatQuery)
  })
_sym_db.RegisterMessage(ResourceSummaryStatQuery)

_RESOURCESUMMARY = DESCRIPTOR.services_by_name['ResourceSummary']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _RESOURCESUMMARY.methods_by_name['get']._options = None
  _RESOURCESUMMARY.methods_by_name['get']._serialized_options = b'\202\323\344\223\002+\022)/inventory/v1/resource-group/{summary_id}'
  _RESOURCESUMMARY.methods_by_name['list']._options = None
  _RESOURCESUMMARY.methods_by_name['list']._serialized_options = b'\202\323\344\223\002M\022 /inventory/v1/resource-summariesZ)\"\'/inventory/v1/resource-summaries/search'
  _RESOURCESUMMARY.methods_by_name['stat']._options = None
  _RESOURCESUMMARY.methods_by_name['stat']._serialized_options = b'\202\323\344\223\002\'\"%/inventory/v1/resource-summaries/stat'
  _RESOURCESUMMARYREQUEST._serialized_start=202
  _RESOURCESUMMARYREQUEST._serialized_end=265
  _GETRESOURCESUMMARYREQUEST._serialized_start=267
  _GETRESOURCESUMMARYREQUEST._serialized_end=347
  _RESOURCESUMMARYQUERY._serialized_start=350
  _RESOURCESUMMARYQUERY._serialized_end=605
  _RESOURCESUMMARYINFO._serialized_start=608
  _RESOURCESUMMARYINFO._serialized_end=955
  _RESOURCESUMMARIESINFO._serialized_start=957
  _RESOURCESUMMARIESINFO._serialized_end=1066
  _RESOURCESUMMARYSTATQUERY._serialized_start=1068
  _RESOURCESUMMARYSTATQUERY._serialized_end=1167
  _RESOURCESUMMARY._serialized_start=1170
  _RESOURCESUMMARY._serialized_end=1675
# @@protoc_insertion_point(module_scope)
